@@ -1,10 +1,9 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc 12885 2013-12-19 11:43:30Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
 // Copyright (C) 2004,2005  Andrew Ross
-// Copyright (C) 2004  Alan W. Irwin
+// Copyright (C) 2004-2014 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -234,6 +233,51 @@ void cxx_pltr2::xform( PLFLT x, PLFLT y, PLFLT& tx, PLFLT& ty ) const
     }
 }
 
+//Callbacks
+
+// Callback for plfill. This will just call the C plfill function
+
+void plcallback::fill( PLINT n, const PLFLT *x, const PLFLT *y )
+{
+    plfill( n, x, y );
+}
+
+// Transformation routines
+
+// Identity transformation.
+
+void plcallback::tr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
+                      PLPointer pltr_data )
+{
+    pltr0( x, y, tx, ty, pltr_data );
+}
+
+// Does linear interpolation from singly dimensioned coord arrays.
+
+void plcallback::tr1( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
+                      PLPointer pltr_data )
+{
+    pltr1( x, y, tx, ty, pltr_data );
+}
+
+// Does linear interpolation from doubly dimensioned coord arrays
+// (column dominant, as per normal C 2d arrays).
+
+void plcallback::tr2( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
+                      PLPointer pltr_data )
+{
+    pltr2( x, y, tx, ty, pltr_data );
+}
+
+// Just like pltr2() but uses pointer arithmetic to get coordinates from
+// 2d grid tables.
+
+void plcallback::tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
+                       PLPointer pltr_data )
+{
+    pltr2p( x, y, tx, ty, pltr_data );
+}
+
 PLINT plstream::active_streams = 0;
 
 plstream::plstream()
@@ -248,7 +292,7 @@ plstream::plstream ( PLS::stream_id sid, PLINT strm /*=0*/ )
     switch ( sid )
     {
     case PLS::Next:
-//	throw( "plstream ctor option not implemented." );
+//      throw( "plstream ctor option not implemented." );
         break;
 
     case PLS::Current:
@@ -260,7 +304,7 @@ plstream::plstream ( PLS::stream_id sid, PLINT strm /*=0*/ )
         break;
 
     default:
-//	throw( "plstream ctor option not implemented." );
+//      throw( "plstream ctor option not implemented." );
         break;
     }
 }
@@ -330,8 +374,7 @@ plstream::arc( PLFLT x, PLFLT y, PLFLT a, PLFLT b, PLFLT angle1, PLFLT angle2,
 
 void
 plstream::vect( const PLFLT * const *u, const PLFLT * const *v, PLINT nx, PLINT ny, PLFLT scale,
-                void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                PLPointer pltr_data )
+                PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -471,7 +514,7 @@ void plstream::col( PLFLT c )
     set_stream();
 
     cerr <<
-    "plstream::col(PLFLT c) : function deprecated. Use plstream::col1(PLFLT c) instead"
+        "plstream::col(PLFLT c) : function deprecated. Use plstream::col1(PLFLT c) instead"
          << endl;
 
     plcol1( c );
@@ -497,8 +540,7 @@ void plstream::configtime( PLFLT scale, PLFLT offset1, PLFLT offset2,
 
 void plstream::cont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
                      PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
-                     void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                     PLPointer pltr_data )
+                     PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -514,8 +556,7 @@ void plstream::fcont( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                       PLPointer f2eval_data,
                       PLINT nx, PLINT ny, PLINT kx, PLINT lx,
                       PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
-                      void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                      PLPointer pltr_data )
+                      PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -652,7 +693,7 @@ void plstream::famadv()
 
 void plstream::fill( PLINT n, const PLFLT *x, const PLFLT *y )
 {
-    //set_stream();
+    set_stream();
 
     plfill( n, x, y );
 }
@@ -661,7 +702,7 @@ void plstream::fill( PLINT n, const PLFLT *x, const PLFLT *y )
 
 void plstream::fill3( PLINT n, const PLFLT *x, const PLFLT *y, const PLFLT *z )
 {
-    //set_stream();
+    set_stream();
 
     plfill3( n, x, y, z );
 }
@@ -843,7 +884,7 @@ void plstream::gra()
 
 void plstream::gradient( PLINT n, const PLFLT *x, const PLFLT *y, PLFLT angle )
 {
-    //set_stream();
+    set_stream();
 
     plgradient( n, x, y, angle );
 }
@@ -1070,20 +1111,66 @@ void plstream::lsty( PLINT lin )
     pllsty( lin );
 }
 
-// plot continental outline in world coordinates
+// Plot continental outline in world coordinates
 
-void plstream::map( void ( *mapform )( PLINT, PLFLT *, PLFLT * ),
-                    const char *type, PLFLT minlong, PLFLT maxlong,
-                    PLFLT minlat, PLFLT maxlat )
+void plstream::map( PLMAPFORM_callback mapform,
+                    const char *name, PLFLT minx, PLFLT maxx,
+                    PLFLT miny, PLFLT maxy )
 {
     set_stream();
 
-    plmap( mapform, type, minlong, maxlong, minlat, maxlat );
+    plmap( mapform, name, minx, maxx, miny, maxy );
+}
+
+// Plot map lines
+
+void plstream::mapline( PLMAPFORM_callback mapform, const char *name,
+                        PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                        const PLINT *plotentries, PLINT nplotentries )
+{
+    set_stream();
+
+    plmapline( mapform, name, minx, maxx, miny, maxy, plotentries, nplotentries );
+}
+
+// Plot map points
+
+void plstream::mapstring( PLMAPFORM_callback mapform,
+                          const char *name, const char *string,
+                          PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                          const PLINT *plotentries, PLINT nplotentries )
+{
+    set_stream();
+
+    plmapstring( mapform, name, string, minx, maxx, miny, maxy, plotentries, nplotentries );
+}
+
+// Plot map text
+
+void plstream::maptex( PLMAPFORM_callback mapform,
+                       const char *name, PLFLT dx, PLFLT dy, PLFLT just, const char *text,
+                       PLFLT minx, PLFLT maxx, PLFLT miny, PLFLT maxy,
+                       PLINT plotentry )
+{
+    set_stream();
+
+    plmaptex( mapform, name, dx, dy, just, text, minx, maxx, miny, maxy, plotentry );
+}
+
+// Plot map fills
+
+void plstream::mapfill( PLMAPFORM_callback mapform,
+                        const char *name, PLFLT minx, PLFLT maxx, PLFLT miny,
+                        PLFLT maxy, const PLINT *plotentries, PLINT nplotentries )
+{
+    set_stream();
+
+    plmapfill( mapform, name, minx, maxx, miny, maxy, plotentries, nplotentries );
 }
 
 // Plot the latitudes and longitudes on the background.
 
-void plstream::meridians( void ( *mapform )( PLINT, PLFLT *, PLFLT * ),
+void plstream::meridians( PLMAPFORM_callback mapform,
                           PLFLT dlong, PLFLT dlat,
                           PLFLT minlong, PLFLT maxlong,
                           PLFLT minlat, PLFLT maxlat )
@@ -1216,7 +1303,7 @@ void plstream::plot3dcl( const PLFLT *x, const PLFLT *y, const PLFLT * const *z,
 
 // Process options list using current options info.
 
-int plstream::parseopts( int *p_argc, const char **argv, PLINT mode )
+PLINT plstream::parseopts( int *p_argc, char **argv, PLINT mode )
 {
     set_stream();
 
@@ -1334,6 +1421,15 @@ void plstream::ptex3( PLFLT wx, PLFLT wy, PLFLT wz,
     plptex3( wx, wy, wz, dx, dy, dz, sx, sy, sz, just, text );
 }
 
+// Get the world coordinates associated with device coordinates
+
+PLINT plstream::translatecursor( PLGraphicsIn *gin )
+{
+    set_stream();
+
+    return plTranslateCursor( gin );
+}
+
 // Replays contents of plot buffer to current device/file.
 
 void plstream::replot()
@@ -1706,6 +1802,15 @@ void plstream::sfnam( const char *fnam )
     plsfnam( fnam );
 }
 
+// Set the pointer to the data used in driver initialisation
+
+void plstream::sdevdata( void *data )
+{
+    set_stream();
+
+    plsdevdata( data );
+}
+
 // Set the current font family, style and weight
 
 void plstream::sfont( PLINT family, PLINT style, PLINT weight )
@@ -1719,15 +1824,14 @@ void plstream::sfont( PLINT family, PLINT style, PLINT weight )
 
 void
 plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
-                 PLINT ( *defined )( PLFLT, PLFLT ),
+                 PLDEFINED_callback defined,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data )
+                 PLFILL_callback fill, bool rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1741,15 +1845,14 @@ plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
 // Deprecated version using PLINT instead of bool
 void
 plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
-                 PLINT ( *defined )( PLFLT, PLFLT ),
+                 PLDEFINED_callback defined,
                  PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data )
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1762,13 +1865,12 @@ plstream::shade( const PLFLT * const *a, PLINT nx, PLINT ny,
 
 void
 plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
-                  PLINT ( *defined )( PLFLT, PLFLT ),
+                  PLDEFINED_callback defined,
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                   const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
                   PLINT cont_color, PLFLT cont_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, bool rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1780,13 +1882,12 @@ plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
 // Deprecated version using PLINT instead of bool
 void
 plstream::shades( const PLFLT * const *a, PLINT nx, PLINT ny,
-                  PLINT ( *defined )( PLFLT, PLFLT ),
+                  PLDEFINED_callback defined,
                   PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                   const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
                   PLINT cont_color, PLFLT cont_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, PLINT rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1816,7 +1917,7 @@ plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
             xmin, xmax, ymin, ymax, shade_min, shade_max,
             sh_cmap, sh_color, sh_width,
             min_color, min_width, max_color, max_width,
-            ::plfill, rectangular,
+            plcallback::fill, rectangular,
             Coord_Xform_evaluator, pcxf );
     else
         ::plfshade( Contourable_Data_evaluator, &d,
@@ -1825,7 +1926,7 @@ plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
             xmin, xmax, ymin, ymax, shade_min, shade_max,
             sh_cmap, sh_color, sh_width,
             min_color, min_width, max_color, max_width,
-            ::plfill, rectangular,
+            plcallback::fill, rectangular,
             NULL, NULL );
 }
 
@@ -1850,21 +1951,20 @@ plstream::shade( Contourable_Data & d, PLFLT xmin, PLFLT xmax,
         xmin, xmax, ymin, ymax, shade_min, shade_max,
         sh_cmap, sh_color, sh_width,
         min_color, min_width, max_color, max_width,
-        ::plfill, rectangular != 0,
+        plcallback::fill, rectangular != 0,
         Coord_Xform_evaluator, pcxf );
 }
 
 void
 plstream::shade1( const PLFLT *a, PLINT nx, PLINT ny,
-                  PLINT ( *defined )( PLFLT, PLFLT ),
+                  PLDEFINED_callback defined,
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
                   PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                   PLINT min_color, PLFLT min_width,
                   PLINT max_color, PLFLT max_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, bool rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1879,15 +1979,14 @@ plstream::shade1( const PLFLT *a, PLINT nx, PLINT ny,
 // Deprecated version using PLINT not bool
 void
 plstream::shade1( const PLFLT *a, PLINT nx, PLINT ny,
-                  PLINT ( *defined )( PLFLT, PLFLT ),
+                  PLDEFINED_callback defined,
                   PLFLT left, PLFLT right, PLFLT bottom, PLFLT top,
                   PLFLT shade_min, PLFLT shade_max,
                   PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                   PLINT min_color, PLFLT min_width,
                   PLINT max_color, PLFLT max_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, PLINT rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1910,9 +2009,8 @@ plstream::fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                   PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                   PLINT min_color, PLFLT min_width,
                   PLINT max_color, PLFLT max_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), bool rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, bool rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1937,9 +2035,8 @@ plstream::fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
                   PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                   PLINT min_color, PLFLT min_width,
                   PLINT max_color, PLFLT max_width,
-                  void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                  void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                  PLPointer pltr_data )
+                  PLFILL_callback fill, PLINT rectangular,
+                  PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -1954,8 +2051,7 @@ plstream::fshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 
 // Setup a user-provided custom labeling function
 
-void plstream::slabelfunc( void ( *label_func )( PLINT, PLFLT, char *, PLINT, PLPointer ),
-                           PLPointer label_data )
+void plstream::slabelfunc( PLLABEL_FUNC_callback label_func, PLPointer label_data )
 {
     set_stream();
 
@@ -2099,8 +2195,7 @@ void plstream::start( const char *devname, PLINT nx, PLINT ny )
 
 // Set the coordinate transform
 
-void plstream::stransform( void ( *coordinate_transform )( PLFLT, PLFLT, PLFLT*, PLFLT*, PLPointer ),
-                           PLPointer coordinate_transform_data )
+void plstream::stransform( PLTRANSFORM_callback coordinate_transform, PLPointer coordinate_transform_data )
 {
     set_stream();
 
@@ -2203,8 +2298,7 @@ void plstream::image( const PLFLT * const *data, PLINT nx, PLINT ny,
 void plstream::imagefr( const PLFLT * const *data, PLINT nx, PLINT ny, PLFLT xmin, PLFLT xmax,
                         PLFLT ymin, PLFLT ymax, PLFLT zmin, PLFLT zmax,
                         PLFLT valuemin, PLFLT valuemax,
-                        void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                        PLPointer pltr_data )
+                        PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     set_stream();
 
@@ -2446,42 +2540,6 @@ void plstream::sexit( int ( *handler )( const char * ) )
     plsexit( handler );
 }
 
-// Transformation routines
-
-// Identity transformation.
-
-void plstream::tr0( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
-                    PLPointer pltr_data )
-{
-    pltr0( x, y, tx, ty, pltr_data );
-}
-
-// Does linear interpolation from singly dimensioned coord arrays.
-
-void plstream::tr1( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
-                    PLPointer pltr_data )
-{
-    pltr1( x, y, tx, ty, pltr_data );
-}
-
-// Does linear interpolation from doubly dimensioned coord arrays
-// (column dominant, as per normal C 2d arrays).
-
-void plstream::tr2( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
-                    PLPointer pltr_data )
-{
-    pltr2( x, y, tx, ty, pltr_data );
-}
-
-// Just like pltr2() but uses pointer arithmetic to get coordinates from
-// 2d grid tables.
-
-void plstream::tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
-                     PLPointer pltr_data )
-{
-    pltr2p( x, y, tx, ty, pltr_data );
-}
-
 // We obviously won't be using this object from Fortran...
 // // Identity transformation for plots from Fortran.
 
@@ -2566,8 +2624,8 @@ void plstream::ResetOpts()
 
 // Merge user option table into internal info structure.
 
-int plstream::MergeOpts( PLOptionTable *options, const char *name,
-                         const char **notes )
+PLINT plstream::MergeOpts( PLOptionTable *options, const char *name,
+                           const char **notes )
 {
     set_stream();
 
@@ -2585,14 +2643,14 @@ void plstream::SetUsage( char *program_string, char *usage_string )
 
 // Process input strings, treating them as an option and argument pair.
 
-int plstream::setopt( const char *opt, const char *optarg )
+PLINT plstream::setopt( const char *opt, const char *optarg )
 {
     set_stream();
 
     return ::plsetopt( opt, optarg );
 }
 
-// Depreciated version - use setopt instead.
+// Deprecated version - use setopt instead.
 #ifdef PL_DEPRECATED
 int plstream::SetOpt( const char *opt, const char *optarg )
 {
@@ -2652,7 +2710,7 @@ void plstream::cmd( PLINT op, void *ptr )
 
 // Return full pathname for given file if executable
 
-int plstream::FindName( char *p )
+PLINT plstream::FindName( char *p )
 {
     set_stream();
 
@@ -2746,7 +2804,7 @@ void plstream::rgbhls( PLFLT r, PLFLT g, PLFLT b, PLFLT *p_h, PLFLT *p_l,
 
 // Wait for right button mouse event and translate to world coordinates
 
-int plstream::GetCursor( PLGraphicsIn *gin )
+PLINT plstream::GetCursor( PLGraphicsIn *gin )
 {
     set_stream();
 
