@@ -1,11 +1,10 @@
 // -*-C++-*-
-// $Id: tclMatrix.h 12078 2011-11-30 22:09:07Z andrewross $
-//
 //  Copyright 1994, 1995
 //  Maurice LeBrun			mjl@dino.ph.utexas.edu
 //  Institute for Fusion Studies	University of Texas at Austin
 //
-//  Copyright (C) 2004  Maurice LeBrun
+//  Copyright (C) 2004 Maurice LeBrun
+//  Copyright (C) 2016 Alan W. Irwin
 //
 //  This file is part of PLplot.
 //
@@ -62,7 +61,11 @@ enum { TYPE_FLOAT, TYPE_INT };
 
 typedef struct
 {
-    int        type;             // Data type
+    int type;                    // Data type
+    // It is tempting to declare the next 3 as size_t, but the second
+    // limit on slices must be -1 for one particular case (negative
+    // step with second limit of -1 corresponding to actual index of
+    // 0) so it is better to keep all these as int to reduce casting.
     int        len;              // Total length of array
     int        dim;              // Number of dimensions
     int        n[MAX_ARRAY_DIM]; // Holds array length in each dimension
@@ -75,10 +78,17 @@ typedef struct
 
     Tcl_Interp *interp;          // Interpreter where command is installed
 
-// These do the put/get operations for each supported type
+    // These do the put/get operations for each supported type
 
     void ( *put )( ClientData clientData, Tcl_Interp* interp, int index, const char *string );
     void ( *get )( ClientData clientData, Tcl_Interp* interp, int index, char *string );
+    // number of indices that will be either put or get.  If indices is NULL, this
+    // should be set to the product of the (MAX_ARRAY_DIM=3) values in the above n array.
+    int nindices;
+    // Array of those indices (malloc'ed if used, NULL if all raw indices
+    // are used in the normal C [row-major] order without reference to the indices
+    // array).
+    int *indices;
 } tclMatrix;
 
 // Function prototypes
