@@ -37,20 +37,22 @@ template <class WXWINDOW>
 class wxPLplotwindow : public WXWINDOW
 {
 public:
-    wxPLplotwindow( bool useGraphicsContext = true );                       //!< Constructor.
-    ~wxPLplotwindow( void );                                                //!< Destructor.
+    wxPLplotwindow( bool useGraphicsContext = true, wxSize clientSize = wxDefaultSize ); //!< Constructor.
+    virtual ~wxPLplotwindow( void );                                                     //!< Destructor.
 
-    void RenewPlot( void );                                                 //!< Redo plot.
-    bool SavePlot( const wxString& driver, const wxString& filename );      //!< Save plot using a different driver.
-    wxPLplotstream* GetStream()  { return m_created ? &m_stream : NULL; }   //!< Get pointer to wxPLplotstream of this widget.
+    void RenewPlot( void );                                                              //!< Redo plot.
+    bool SavePlot( const wxString& driver, const wxString& filename );                   //!< Save plot using a different driver.
+    wxPLplotstream* GetStream()  { return m_created ? &m_stream : NULL; }                //!< Get pointer to wxPLplotstream of this widget.
     void setUseGraphicsContext( bool useGraphicsContext );
     void setCanvasColour( const wxColour &colour );
+    bool IsReady() { return GetStream() != NULL; }
 
 protected:
     virtual void OnPaint( wxPaintEvent& event );         //!< Paint event
     virtual void OnSize( wxSizeEvent & event );          //!< Size event
     virtual void OnErase( wxEraseEvent &event );         //!< Background erase event
     virtual void OnCreate( wxWindowCreateEvent &event ); //!< Window created event
+    void OnMouse( wxMouseEvent &event );                 //!< Mouse events
     wxPLplotstream m_stream;                             //!< The wxPLplotstream which belongs to this plot widget
     bool           m_created;                            //!< Flag to indicate the window has been Created
 
@@ -62,10 +64,12 @@ private:
     //resized because reusing either of these causes problems
     //for rendering on a wxGCDC - at least on Windows.
     wxMemoryDC *m_memoryDc;
+    wxSize     m_initialSize;
 #ifdef wxUSE_GRAPHICS_CONTEXT
     wxGCDC     *m_gcDc;
 #endif
     wxColour   m_canvasColour;
+    virtual void OnLocate( const PLGraphicsIn &graphicsIn ){}
 };
 
 
@@ -73,10 +77,11 @@ private:
 // methods with events. The WXWINDOW default constructor is used.
 //
 template<class WXWINDOW>
-wxPLplotwindow<WXWINDOW>::wxPLplotwindow( bool useGraphicsContext )
-    : m_created( false )
+wxPLplotwindow<WXWINDOW>::wxPLplotwindow( bool useGraphicsContext, wxSize clientSize )
+    : m_created( false ), m_initialSize( clientSize )
 
 {
+    PLPLOT_wxLogDebug( "wxPLplotwindow::wxPLplotwindow" );
     m_memoryDc = NULL;
 #ifdef wxUSE_GRAPHICS_CONTEXT
     m_gcDc = NULL;
@@ -90,8 +95,10 @@ wxPLplotwindow<WXWINDOW>::wxPLplotwindow( bool useGraphicsContext )
     WXWINDOW::Connect( wxEVT_PAINT, wxPaintEventHandler( wxPLplotwindow<WXWINDOW>::OnPaint ) );
     WXWINDOW::Connect( wxEVT_ERASE_BACKGROUND, wxEraseEventHandler( wxPLplotwindow<WXWINDOW>::OnErase ) );
     WXWINDOW::Connect( wxEVT_CREATE, wxWindowCreateEventHandler( wxPLplotwindow<WXWINDOW>::OnCreate ) );
-    //Bind( wxEVT_SIZE, &wxPLplotwindow<WXWINDOW>::OnSize, this );
-    //Bind( wxEVT_PAINT, &wxPLplotwindow<WXWINDOW>::OnPaint, this );
+    WXWINDOW::Connect( wxEVT_MOTION, wxMouseEventHandler( wxPLplotwindow<WXWINDOW>::OnMouse ) );
+    WXWINDOW::Connect( wxEVT_LEFT_UP, wxMouseEventHandler( wxPLplotwindow<WXWINDOW>::OnMouse ) );
+    WXWINDOW::Connect( wxEVT_MIDDLE_UP, wxMouseEventHandler( wxPLplotwindow<WXWINDOW>::OnMouse ) );
+    WXWINDOW::Connect( wxEVT_RIGHT_UP, wxMouseEventHandler( wxPLplotwindow<WXWINDOW>::OnMouse ) );
 }
 
 
@@ -106,7 +113,6 @@ wxPLplotwindow<WXWINDOW>::~wxPLplotwindow( void )
         delete m_gcDc;
 }
 
-
 //! In the OnPaint Method we check if the Windows was resized (will be moved to OnSize() sometimes
 //  later), we also implement our own double buffering here (since the PLplot wxWidgets driver draws
 //  into a wxMemoryDC)
@@ -147,10 +153,12 @@ void wxPLplotwindow<WXWINDOW>::OnPaint( wxPaintEvent &WXUNUSED( event ) )
             drawDc = m_gcDc;
         }
 #endif
-        m_stream.SetDC( drawDc );
+        if ( IsReady() )
+            m_stream.SetDC( drawDc );
         drawDc->SetBackground( wxBrush( m_canvasColour ) );
         drawDc->Clear();
-        m_stream.SetSize( width, height );
+        if ( IsReady() )
+            m_stream.SetSize( width, height );
     }
 
     paintDc.Blit( 0, 0, width, height, m_memoryDc, 0, 0 );
@@ -180,8 +188,12 @@ void wxPLplotwindow<WXWINDOW>::OnErase( wxEraseEvent& WXUNUSED( event ) )
 template<class WXWINDOW>
 void wxPLplotwindow<WXWINDOW>::OnCreate( wxWindowCreateEvent &event )
 {
+    PLPLOT_wxLogDebug( "wxPLplotwindow::OnCreate" );
     if ( !m_created )
     {
+        //set the client size if requested
+        if ( m_initialSize != wxDefaultSize )
+            WXWINDOW::SetClientSize( m_initialSize );
         //create the stream
         int width  = WXWINDOW::GetClientSize().GetWidth();
         int height = WXWINDOW::GetClientSize().GetHeight();
@@ -212,6 +224,77 @@ void wxPLplotwindow<WXWINDOW>::OnCreate( wxWindowCreateEvent &event )
     }
 }
 
+//Capture Mouse events and pass the
+template<class WXWINDOW>
+void wxPLplotwindow<WXWINDOW>::OnMouse( wxMouseEvent &event )
+{
+    PLGraphicsIn graphicsIn;
+    wxPoint      cursorPosition = event.GetPosition();
+    wxSize       clientSize     = WXWINDOW::GetClientSize();
+
+    graphicsIn.pX        = cursorPosition.x;
+    graphicsIn.pY        = cursorPosition.y;
+    graphicsIn.dX        = PLFLT( cursorPosition.x + 0.5 ) / PLFLT( clientSize.GetWidth() );
+    graphicsIn.dY        = 1.0 - PLFLT( cursorPosition.y + 0.5 ) / PLFLT( clientSize.GetHeight() );
+    graphicsIn.keysym    = 0x20;
+    graphicsIn.state     = 0;
+    graphicsIn.subwindow = -1;
+    graphicsIn.type      = 0;
+    graphicsIn.string[0] = '\0';
+    if ( event.LeftUp() )
+    {
+        graphicsIn.button = 1;
+        graphicsIn.state |= PL_MASK_BUTTON1;
+    }
+    else if ( event.MiddleUp() )
+    {
+        graphicsIn.button = 2;
+        graphicsIn.state |= PL_MASK_BUTTON2;
+    }
+    else if ( event.RightUp() )
+    {
+        graphicsIn.button = 3;
+        graphicsIn.state |= PL_MASK_BUTTON3;
+    }
+    else if ( event.Aux1Up() )
+    {
+        graphicsIn.button = 4;
+        graphicsIn.state |= PL_MASK_BUTTON4;
+    }
+    else if ( event.Aux2Up() )
+    {
+        graphicsIn.button = 5;
+        graphicsIn.state |= PL_MASK_BUTTON5;
+    }
+    else
+    {
+        //If we get here we have just captured motion
+        //not a click
+        graphicsIn.button = 0;
+        graphicsIn.state  = 0;
+        graphicsIn.keysym = 0;
+    }
+
+    if ( wxGetKeyState( WXK_SHIFT ) )
+        graphicsIn.state |= PL_MASK_SHIFT;
+    if ( wxGetKeyState( WXK_CAPITAL ) )
+        graphicsIn.state |= PL_MASK_CAPS;
+    if ( wxGetKeyState( WXK_ALT ) && wxGetKeyState( WXK_CONTROL ) )
+        graphicsIn.state |= PL_MASK_ALTGR;
+    else if ( wxGetKeyState( WXK_CONTROL ) )
+        graphicsIn.state |= PL_MASK_CONTROL;
+    else if ( wxGetKeyState( WXK_ALT ) )
+        graphicsIn.state |= PL_MASK_ALT;
+    if ( wxGetKeyState( WXK_NUMLOCK ) )
+        graphicsIn.state |= PL_MASK_NUM;
+    if ( wxGetKeyState( WXK_SCROLL ) )
+        graphicsIn.state |= PL_MASK_SCROLL;
+    //Note I can't find a way to catch the windows key
+
+    if ( IsReady() )
+        m_stream.translatecursor( &graphicsIn );
+    this->OnLocate( graphicsIn );
+}
 
 //! Redo the whole plot, only if the window has been Created
 //
@@ -273,7 +356,7 @@ void wxPLplotwindow<WXWINDOW>::setUseGraphicsContext( bool useGraphicsContext )
     drawDc = &m_memoryDc;
     m_useGraphicsContext = false;
 #endif
-    if ( m_created )
+    if ( IsReady() )
     {
         m_stream.SetDC( drawDc );
         RenewPlot();
