@@ -1,110 +1,155 @@
 var classplplot =
 [
+    [ "pl_setcontlabelformat", "interfaceplplot_1_1pl__setcontlabelformat.html", "interfaceplplot_1_1pl__setcontlabelformat" ],
     [ "pladv", "interfaceplplot_1_1pladv.html", "interfaceplplot_1_1pladv" ],
-    [ "plbin", "interfaceplplot_1_1plbin.html", "interfaceplplot_1_1plbin" ],
     [ "plbop", "interfaceplplot_1_1plbop.html", "interfaceplplot_1_1plbop" ],
-    [ "plbtime", "interfaceplplot_1_1plbtime.html", "interfaceplplot_1_1plbtime" ],
-    [ "plcalc_world", "interfaceplplot_1_1plcalc__world.html", "interfaceplplot_1_1plcalc__world" ],
     [ "plclear", "interfaceplplot_1_1plclear.html", "interfaceplplot_1_1plclear" ],
     [ "plcol0", "interfaceplplot_1_1plcol0.html", "interfaceplplot_1_1plcol0" ],
-    [ "plcol1", "interfaceplplot_1_1plcol1.html", "interfaceplplot_1_1plcol1" ],
-    [ "plcolorbar", "interfaceplplot_1_1plcolorbar.html", "interfaceplplot_1_1plcolorbar" ],
-    [ "plconfigtime", "interfaceplplot_1_1plconfigtime.html", "interfaceplplot_1_1plconfigtime" ],
     [ "plcpstrm", "interfaceplplot_1_1plcpstrm.html", "interfaceplplot_1_1plcpstrm" ],
-    [ "plctime", "interfaceplplot_1_1plctime.html", "interfaceplplot_1_1plctime" ],
+    [ "plend", "interfaceplplot_1_1plend.html", "interfaceplplot_1_1plend" ],
     [ "plend1", "interfaceplplot_1_1plend1.html", "interfaceplplot_1_1plend1" ],
-    [ "plenv", "interfaceplplot_1_1plenv.html", "interfaceplplot_1_1plenv" ],
     [ "pleop", "interfaceplplot_1_1pleop.html", "interfaceplplot_1_1pleop" ],
-    [ "plerrx", "interfaceplplot_1_1plerrx.html", "interfaceplplot_1_1plerrx" ],
-    [ "plerry", "interfaceplplot_1_1plerry.html", "interfaceplplot_1_1plerry" ],
     [ "plfamadv", "interfaceplplot_1_1plfamadv.html", "interfaceplplot_1_1plfamadv" ],
-    [ "plfill", "interfaceplplot_1_1plfill.html", "interfaceplplot_1_1plfill" ],
-    [ "plfill3", "interfaceplplot_1_1plfill3.html", "interfaceplplot_1_1plfill3" ],
     [ "plflush", "interfaceplplot_1_1plflush.html", "interfaceplplot_1_1plflush" ],
     [ "plfont", "interfaceplplot_1_1plfont.html", "interfaceplplot_1_1plfont" ],
     [ "plfontld", "interfaceplplot_1_1plfontld.html", "interfaceplplot_1_1plfontld" ],
-    [ "plgchr", "interfaceplplot_1_1plgchr.html", "interfaceplplot_1_1plgchr" ],
-    [ "plgcmap1_range", "interfaceplplot_1_1plgcmap1__range.html", "interfaceplplot_1_1plgcmap1__range" ],
     [ "plgcol0", "interfaceplplot_1_1plgcol0.html", "interfaceplplot_1_1plgcol0" ],
-    [ "plgcol0a", "interfaceplplot_1_1plgcol0a.html", "interfaceplplot_1_1plgcol0a" ],
     [ "plgcolbg", "interfaceplplot_1_1plgcolbg.html", "interfaceplplot_1_1plgcolbg" ],
-    [ "plgcolbga", "interfaceplplot_1_1plgcolbga.html", "interfaceplplot_1_1plgcolbga" ],
     [ "plgcompression", "interfaceplplot_1_1plgcompression.html", "interfaceplplot_1_1plgcompression" ],
-    [ "plgdidev", "interfaceplplot_1_1plgdidev.html", "interfaceplplot_1_1plgdidev" ],
-    [ "plgdiori", "interfaceplplot_1_1plgdiori.html", "interfaceplplot_1_1plgdiori" ],
-    [ "plgdiplt", "interfaceplplot_1_1plgdiplt.html", "interfaceplplot_1_1plgdiplt" ],
-    [ "plgetcursor", "interfaceplplot_1_1plgetcursor.html", "interfaceplplot_1_1plgetcursor" ],
+    [ "plgdev", "interfaceplplot_1_1plgdev.html", "interfaceplplot_1_1plgdev" ],
+    [ "plgdrawmode", "interfaceplplot_1_1plgdrawmode.html", "interfaceplplot_1_1plgdrawmode" ],
     [ "plgfam", "interfaceplplot_1_1plgfam.html", "interfaceplplot_1_1plgfam" ],
     [ "plgfci", "interfaceplplot_1_1plgfci.html", "interfaceplplot_1_1plgfci" ],
+    [ "plgfnam", "interfaceplplot_1_1plgfnam.html", "interfaceplplot_1_1plgfnam" ],
     [ "plgfont", "interfaceplplot_1_1plgfont.html", "interfaceplplot_1_1plgfont" ],
     [ "plglevel", "interfaceplplot_1_1plglevel.html", "interfaceplplot_1_1plglevel" ],
-    [ "plgpage", "interfaceplplot_1_1plgpage.html", "interfaceplplot_1_1plgpage" ],
     [ "plgra", "interfaceplplot_1_1plgra.html", "interfaceplplot_1_1plgra" ],
-    [ "plgradient", "interfaceplplot_1_1plgradient.html", "interfaceplplot_1_1plgradient" ],
-    [ "plgriddata", "interfaceplplot_1_1plgriddata.html", "interfaceplplot_1_1plgriddata" ],
-    [ "plgspa", "interfaceplplot_1_1plgspa.html", "interfaceplplot_1_1plgspa" ],
     [ "plgstrm", "interfaceplplot_1_1plgstrm.html", "interfaceplplot_1_1plgstrm" ],
-    [ "plgvpd", "interfaceplplot_1_1plgvpd.html", "interfaceplplot_1_1plgvpd" ],
-    [ "plgvpw", "interfaceplplot_1_1plgvpw.html", "interfaceplplot_1_1plgvpw" ],
+    [ "plgver", "interfaceplplot_1_1plgver.html", "interfaceplplot_1_1plgver" ],
     [ "plgxax", "interfaceplplot_1_1plgxax.html", "interfaceplplot_1_1plgxax" ],
     [ "plgyax", "interfaceplplot_1_1plgyax.html", "interfaceplplot_1_1plgyax" ],
     [ "plgzax", "interfaceplplot_1_1plgzax.html", "interfaceplplot_1_1plgzax" ],
-    [ "plhist", "interfaceplplot_1_1plhist.html", "interfaceplplot_1_1plhist" ],
-    [ "plhls", "interfaceplplot_1_1plhls.html", "interfaceplplot_1_1plhls" ],
-    [ "plhlsrgb", "interfaceplplot_1_1plhlsrgb.html", "interfaceplplot_1_1plhlsrgb" ],
     [ "plinit", "interfaceplplot_1_1plinit.html", "interfaceplplot_1_1plinit" ],
-    [ "pljoin", "interfaceplplot_1_1pljoin.html", "interfaceplplot_1_1pljoin" ],
-    [ "pllegend", "interfaceplplot_1_1pllegend.html", "interfaceplplot_1_1pllegend" ],
-    [ "pllightsource", "interfaceplplot_1_1pllightsource.html", "interfaceplplot_1_1pllightsource" ],
-    [ "plline", "interfaceplplot_1_1plline.html", "interfaceplplot_1_1plline" ],
-    [ "plline3", "interfaceplplot_1_1plline3.html", "interfaceplplot_1_1plline3" ],
+    [ "pllab", "interfaceplplot_1_1pllab.html", "interfaceplplot_1_1pllab" ],
     [ "pllsty", "interfaceplplot_1_1pllsty.html", "interfaceplplot_1_1pllsty" ],
-    [ "plmap", "interfaceplplot_1_1plmap.html", "interfaceplplot_1_1plmap" ],
-    [ "plmapfill", "interfaceplplot_1_1plmapfill.html", "interfaceplplot_1_1plmapfill" ],
-    [ "plmapline", "interfaceplplot_1_1plmapline.html", "interfaceplplot_1_1plmapline" ],
-    [ "plmapstring", "interfaceplplot_1_1plmapstring.html", "interfaceplplot_1_1plmapstring" ],
-    [ "plmaptex", "interfaceplplot_1_1plmaptex.html", "interfaceplplot_1_1plmaptex" ],
-    [ "plmeridians", "interfaceplplot_1_1plmeridians.html", "interfaceplplot_1_1plmeridians" ],
-    [ "plmesh", "interfaceplplot_1_1plmesh.html", "interfaceplplot_1_1plmesh" ],
-    [ "plmeshc", "interfaceplplot_1_1plmeshc.html", "interfaceplplot_1_1plmeshc" ],
     [ "plmkstrm", "interfaceplplot_1_1plmkstrm.html", "interfaceplplot_1_1plmkstrm" ],
-    [ "plot3d", "interfaceplplot_1_1plot3d.html", "interfaceplplot_1_1plot3d" ],
-    [ "plot3dc", "interfaceplplot_1_1plot3dc.html", "interfaceplplot_1_1plot3dc" ],
+    [ "plparseopts", "interfaceplplot_1_1plparseopts.html", "interfaceplplot_1_1plparseopts" ],
     [ "plpat", "interfaceplplot_1_1plpat.html", "interfaceplplot_1_1plpat" ],
-    [ "plpath", "interfaceplplot_1_1plpath.html", "interfaceplplot_1_1plpath" ],
-    [ "plpoin", "interfaceplplot_1_1plpoin.html", "interfaceplplot_1_1plpoin" ],
-    [ "plpoin3", "interfaceplplot_1_1plpoin3.html", "interfaceplplot_1_1plpoin3" ],
-    [ "plpoly3", "interfaceplplot_1_1plpoly3.html", "interfaceplplot_1_1plpoly3" ],
     [ "plprec", "interfaceplplot_1_1plprec.html", "interfaceplplot_1_1plprec" ],
     [ "plpsty", "interfaceplplot_1_1plpsty.html", "interfaceplplot_1_1plpsty" ],
     [ "plreplot", "interfaceplplot_1_1plreplot.html", "interfaceplplot_1_1plreplot" ],
-    [ "plrgb", "interfaceplplot_1_1plrgb.html", "interfaceplplot_1_1plrgb" ],
-    [ "plrgb1", "interfaceplplot_1_1plrgb1.html", "interfaceplplot_1_1plrgb1" ],
-    [ "plrgbhls", "interfaceplplot_1_1plrgbhls.html", "interfaceplplot_1_1plrgbhls" ],
-    [ "plschr", "interfaceplplot_1_1plschr.html", "interfaceplplot_1_1plschr" ],
     [ "plscmap0", "interfaceplplot_1_1plscmap0.html", "interfaceplplot_1_1plscmap0" ],
-    [ "plscmap0a", "interfaceplplot_1_1plscmap0a.html", "interfaceplplot_1_1plscmap0a" ],
     [ "plscmap0n", "interfaceplplot_1_1plscmap0n.html", "interfaceplplot_1_1plscmap0n" ],
     [ "plscmap1", "interfaceplplot_1_1plscmap1.html", "interfaceplplot_1_1plscmap1" ],
-    [ "plscmap1_range", "interfaceplplot_1_1plscmap1__range.html", "interfaceplplot_1_1plscmap1__range" ],
-    [ "plscmap1a", "interfaceplplot_1_1plscmap1a.html", "interfaceplplot_1_1plscmap1a" ],
-    [ "plscmap1l", "interfaceplplot_1_1plscmap1l.html", "interfaceplplot_1_1plscmap1l" ],
-    [ "plscmap1la", "interfaceplplot_1_1plscmap1la.html", "interfaceplplot_1_1plscmap1la" ],
     [ "plscmap1n", "interfaceplplot_1_1plscmap1n.html", "interfaceplplot_1_1plscmap1n" ],
     [ "plscol0", "interfaceplplot_1_1plscol0.html", "interfaceplplot_1_1plscol0" ],
-    [ "plscol0a", "interfaceplplot_1_1plscol0a.html", "interfaceplplot_1_1plscol0a" ],
     [ "plscolbg", "interfaceplplot_1_1plscolbg.html", "interfaceplplot_1_1plscolbg" ],
-    [ "plscolbga", "interfaceplplot_1_1plscolbga.html", "interfaceplplot_1_1plscolbga" ],
     [ "plscolor", "interfaceplplot_1_1plscolor.html", "interfaceplplot_1_1plscolor" ],
     [ "plscompression", "interfaceplplot_1_1plscompression.html", "interfaceplplot_1_1plscompression" ],
-    [ "plsdidev", "interfaceplplot_1_1plsdidev.html", "interfaceplplot_1_1plsdidev" ],
-    [ "plsdimap", "interfaceplplot_1_1plsdimap.html", "interfaceplplot_1_1plsdimap" ],
-    [ "plsdiori", "interfaceplplot_1_1plsdiori.html", "interfaceplplot_1_1plsdiori" ],
-    [ "plsdiplt", "interfaceplplot_1_1plsdiplt.html", "interfaceplplot_1_1plsdiplt" ],
-    [ "plsdiplz", "interfaceplplot_1_1plsdiplz.html", "interfaceplplot_1_1plsdiplz" ],
+    [ "plsdev", "interfaceplplot_1_1plsdev.html", "interfaceplplot_1_1plsdev" ],
+    [ "plsdrawmode", "interfaceplplot_1_1plsdrawmode.html", "interfaceplplot_1_1plsdrawmode" ],
     [ "plseed", "interfaceplplot_1_1plseed.html", "interfaceplplot_1_1plseed" ],
     [ "plsesc", "interfaceplplot_1_1plsesc.html", "interfaceplplot_1_1plsesc" ],
-    [ "plsetmapformc", "interfaceplplot_1_1plsetmapformc.html", "interfaceplplot_1_1plsetmapformc" ],
+    [ "plsetopt", "interfaceplplot_1_1plsetopt.html", "interfaceplplot_1_1plsetopt" ],
+    [ "plsfam", "interfaceplplot_1_1plsfam.html", "interfaceplplot_1_1plsfam" ],
+    [ "plsfci", "interfaceplplot_1_1plsfci.html", "interfaceplplot_1_1plsfci" ],
+    [ "plsfnam", "interfaceplplot_1_1plsfnam.html", "interfaceplplot_1_1plsfnam" ],
+    [ "plsfont", "interfaceplplot_1_1plsfont.html", "interfaceplplot_1_1plsfont" ],
+    [ "plsmem", "interfaceplplot_1_1plsmem.html", "interfaceplplot_1_1plsmem" ],
+    [ "plsmema", "interfaceplplot_1_1plsmema.html", "interfaceplplot_1_1plsmema" ],
+    [ "plsori", "interfaceplplot_1_1plsori.html", "interfaceplplot_1_1plsori" ],
+    [ "plspal0", "interfaceplplot_1_1plspal0.html", "interfaceplplot_1_1plspal0" ],
+    [ "plspal1", "interfaceplplot_1_1plspal1.html", "interfaceplplot_1_1plspal1" ],
+    [ "plspause", "interfaceplplot_1_1plspause.html", "interfaceplplot_1_1plspause" ],
+    [ "plsstrm", "interfaceplplot_1_1plsstrm.html", "interfaceplplot_1_1plsstrm" ],
+    [ "plssub", "interfaceplplot_1_1plssub.html", "interfaceplplot_1_1plssub" ],
+    [ "plstar", "interfaceplplot_1_1plstar.html", "interfaceplplot_1_1plstar" ],
+    [ "plstart", "interfaceplplot_1_1plstart.html", "interfaceplplot_1_1plstart" ],
+    [ "plstripd", "interfaceplplot_1_1plstripd.html", "interfaceplplot_1_1plstripd" ],
+    [ "plstyl", "interfaceplplot_1_1plstyl.html", "interfaceplplot_1_1plstyl" ],
+    [ "plsvect", "interfaceplplot_1_1plsvect.html", "interfaceplplot_1_1plsvect" ],
+    [ "plsxax", "interfaceplplot_1_1plsxax.html", "interfaceplplot_1_1plsxax" ],
+    [ "plsyax", "interfaceplplot_1_1plsyax.html", "interfaceplplot_1_1plsyax" ],
+    [ "plszax", "interfaceplplot_1_1plszax.html", "interfaceplplot_1_1plszax" ],
+    [ "pltext", "interfaceplplot_1_1pltext.html", "interfaceplplot_1_1pltext" ],
+    [ "pltimefmt", "interfaceplplot_1_1pltimefmt.html", "interfaceplplot_1_1pltimefmt" ],
+    [ "plvsta", "interfaceplplot_1_1plvsta.html", "interfaceplplot_1_1plvsta" ],
+    [ "plxormod", "interfaceplplot_1_1plxormod.html", "interfaceplplot_1_1plxormod" ],
+    [ "pl_setcontlabelformat_impl", "classplplot.html#ac41618acbbb71d22152d6664ed7ea8f8", null ],
+    [ "pladv_impl", "classplplot.html#a5626fb76d37465da38a57c20ab0a0a7b", null ],
+    [ "plbop_impl", "classplplot.html#acf34437c2142d1cc040fdbd6adab86f1", null ],
+    [ "plclear_impl", "classplplot.html#a115044b2ac5ae152f3f114db61d714c7", null ],
+    [ "plcol0_impl", "classplplot.html#ad2067a9f4dce8ac54994d599ec758c54", null ],
+    [ "plcpstrm_impl", "classplplot.html#a921622c2d988b9c833f1a52708c1f015", null ],
+    [ "plend1_impl", "classplplot.html#a63166bebdbf632724bd6f43b1139e776", null ],
+    [ "plend_impl", "classplplot.html#a5e1e92483394ad7558c605e7b94eb356", null ],
+    [ "pleop_impl", "classplplot.html#ae89f3a4f182e0e481074eead72e15ab3", null ],
+    [ "plfamadv_impl", "classplplot.html#ad4a2b85be5f1e80765f70da069dc403f", null ],
+    [ "plflush_impl", "classplplot.html#a61cc00600844d98180281c641358f5e5", null ],
+    [ "plfont_impl", "classplplot.html#a2a7c9b45bdb8faeb3605060e83bc4411", null ],
+    [ "plfontld_impl", "classplplot.html#ae3994eef5f5aa2f3b34f5e47b4a5ead4", null ],
+    [ "plgcol0_impl", "classplplot.html#ab02353684d43e3ffc72308ae0e62eb22", null ],
+    [ "plgcolbg_impl", "classplplot.html#a54864386f276494f28386bd5c64b3a06", null ],
+    [ "plgcompression_impl", "classplplot.html#af7b37c19ff64c92200ebad46ce2adc7f", null ],
+    [ "plgdev_impl", "classplplot.html#a7d7587223ace15e979c085fb2a91a039", null ],
+    [ "plgdrawmode_impl", "classplplot.html#aa9d0322efdd93095bccd769640103bae", null ],
+    [ "plgfam_impl", "classplplot.html#a1ae7159a0bde310740d4a8a753b7c425", null ],
+    [ "plgfci_impl", "classplplot.html#adbd2ca3fd56fc0f9f785b5c83a3bd201", null ],
+    [ "plgfnam_impl", "classplplot.html#a7a236472d225006caf8cde33a6e1f6b7", null ],
+    [ "plgfont_impl", "classplplot.html#a306e53a422d275981911acc402e5ca35", null ],
+    [ "plglevel_impl", "classplplot.html#a5cbadc93aa90ab42404dc62c0263694c", null ],
+    [ "plgra_impl", "classplplot.html#a54575f8d30fdc1259ad0d25f6ec1e38e", null ],
+    [ "plgstrm_impl", "classplplot.html#a52da94cf3588e84ab46ea0a3d18ae506", null ],
+    [ "plgver_impl", "classplplot.html#a49bab9579649caf970dbb6bd28205d9b", null ],
+    [ "plgxax_impl", "classplplot.html#a08ab61e48b23b314aee3d0e2aab052b7", null ],
+    [ "plgyax_impl", "classplplot.html#a7062ed1a9200c24101abce45a09fd72b", null ],
+    [ "plgzax_impl", "classplplot.html#aac0315657170bdd7a8954759c218be8a", null ],
+    [ "plinit_impl", "classplplot.html#a59f4e6cd4a3602b9df90429b48c50a60", null ],
+    [ "pllab_impl", "classplplot.html#a601a7c14557336d7c45b1fcff7e558c9", null ],
+    [ "pllsty_impl", "classplplot.html#aba027f7c0ddfbc8c39154cca7c47ede5", null ],
+    [ "plmkstrm_impl", "classplplot.html#a007f51cbfec504e13383305a8f0f7e5c", null ],
+    [ "plparseopts_impl", "classplplot.html#a767023057cd5adad7661ea9b2d135d25", null ],
+    [ "plpat_impl", "classplplot.html#a7e60cf8a8395dd3a3b184da92978fa52", null ],
+    [ "plprec_impl", "classplplot.html#a34dba1bd6e83d35b2ddc70a2fcb58c6f", null ],
+    [ "plpsty_impl", "classplplot.html#a5e9df072c358261f8133d7302d1e02d2", null ],
+    [ "plreplot_impl", "classplplot.html#a9434f40473c5c1fb541a77bc41a286fb", null ],
+    [ "plscmap0_impl", "classplplot.html#a8d8d661d818cf4b57c82d84a789f88ac", null ],
+    [ "plscmap0n_impl", "classplplot.html#a5b1451b7264b90bc4d2d31cd6d50d2a0", null ],
+    [ "plscmap1_impl", "classplplot.html#aab374afd917a62aaa5b771e6d93b7ab5", null ],
+    [ "plscmap1n_impl", "classplplot.html#ac3c7ce7a87041a0d25bd5118f3e54bdc", null ],
+    [ "plscol0_impl", "classplplot.html#a7037fdfc9842c5eedd62fbc94d565b87", null ],
+    [ "plscolbg_impl", "classplplot.html#a70f3c1ac3250c861cca7f6c9db9f2ad3", null ],
+    [ "plscolor_impl", "classplplot.html#a4e8ef93cbc4b1803b89b33a0be4149f0", null ],
+    [ "plscompression_impl", "classplplot.html#af37209f7f15669f222b0fbca705f5cde", null ],
+    [ "plsdev_impl", "classplplot.html#a272485216ae6961b486af03cfb15e0db", null ],
+    [ "plsdrawmode_impl", "classplplot.html#aa758a41cbab9ad3f26e659dd79a01692", null ],
+    [ "plseed_impl", "classplplot.html#a61126eaaf6eef4bd979f961786bd957f", null ],
+    [ "plsesc_impl", "classplplot.html#aa5475b3fad5c942e1f3124719c9326b5", null ],
+    [ "plsetopt_impl", "classplplot.html#ae52661db4f45e6f2b38b99216474955f", null ],
+    [ "plsfam_impl", "classplplot.html#a08a81cb9d3806819f313db97d72c21fe", null ],
+    [ "plsfci_impl", "classplplot.html#a6908a2cf04f7187b0ac12088a7409669", null ],
+    [ "plsfnam_impl", "classplplot.html#a95a5f4be0fcae34ae78aabe0d554a2f6", null ],
+    [ "plsfont_impl", "classplplot.html#aebb5c3a17c9d6ed2c5b2446d9c0fa702", null ],
+    [ "plsmem_impl", "classplplot.html#adc7808752a9159f1695f697aa2f18dd2", null ],
+    [ "plsmema_impl", "classplplot.html#a54f9cc4cbe56a1b587c087e761486f19", null ],
+    [ "plsori_impl", "classplplot.html#abf4f5e1a1c361f103d486ee7ff4d2660", null ],
+    [ "plspal0_impl", "classplplot.html#a4066219818d7a8cfa57f60581c9a8553", null ],
+    [ "plspal1_impl", "classplplot.html#ac02394e9f183f33cfc7ab934805fb9af", null ],
+    [ "plspause_impl", "classplplot.html#a1f97486742a0baa17dfd03143233fcb9", null ],
+    [ "plsstrm_impl", "classplplot.html#a85d62a0e04b8080b1a64c3806e88b367", null ],
+    [ "plssub_impl", "classplplot.html#a440cd4237bb0a2962b734bca83dbc116", null ],
+    [ "plstar_impl", "classplplot.html#a4baedfe010f8df623904984a8e4b3b8e", null ],
+    [ "plstart_impl", "classplplot.html#a78af68a6ffa0d167ee3fe5dec961bbd8", null ],
+    [ "plstripd_impl", "classplplot.html#a78dad702d1ed0b3a197a36b0dff07f64", null ],
+    [ "plstyl_impl", "classplplot.html#afecf2a6a27df8b46180bb9ff1011f390", null ],
+    [ "plsvect_none", "classplplot.html#a37b98577d4ed055b1cdc69ab9efa2053", null ],
+    [ "plsxax_impl", "classplplot.html#aa6805d490e36adfa911d53f8246eca94", null ],
+    [ "plsyax_impl", "classplplot.html#a6947089338ce0e313d567668d09ed8ca", null ],
+    [ "plszax_impl", "classplplot.html#a514a734c0374a29b9d8977823e766e51", null ],
+    [ "pltext_impl", "classplplot.html#a47c66102c440ad8e94c697a6d8aee94f", null ],
+    [ "pltimefmt_impl", "classplplot.html#a8810dc14da396d2a584ac2fb431f6254", null ],
+    [ "plvsta_impl", "classplplot.html#ab88ae02d5f8053dcd1a5b93872c18cef", null ],
+    [ "plxormod_impl", "classplplot.html#a81076e05e1b05629dc39e8e48dc59b85", null ],
     [ "__pad0__", "classplplot.html#a99e3a2f7f971b4759590ff8f417e4d4e", null ],
     [ "Alloc2dGrid", "classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876", null ],
     [ "BASE_CONT", "classplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6", null ],
@@ -123,6 +168,7 @@ var classplplot =
     [ "GRID_NNIDW", "classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1", null ],
     [ "GRID_NNLI", "classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5", null ],
     [ "MAG_COLOR", "classplplot.html#ac50f05d8a58f2960cfe2a496d11fcad0", null ],
+    [ "maxlen", "classplplot.html#a0771bb612935378464fba135a16618b8", null ],
     [ "MESH", "classplplot.html#a0a7a72416f1a62cbc7d6ed176f0889a0", null ],
     [ "MinMax2dGrid", "classplplot.html#a22297be3066bb6e8e6330143ac0d00e4", null ],
     [ "ONEW2B", "classplplot.html#a682ba4d7edb5b72c8768df356142ebb0", null ],
@@ -148,6 +194,7 @@ var classplplot =
     [ "PL_COLORBAR_ORIENT_TOP", "classplplot.html#ada262759b3f6373dcbb2c0a268f26428", null ],
     [ "PL_COLORBAR_SHADE", "classplplot.html#a8913e33754cfef14eff15beb1bf46a5c", null ],
     [ "PL_COLORBAR_SHADE_LABEL", "classplplot.html#ae9c45984e846d89e6311b679ebe5defe", null ],
+    [ "pl_end_of_string", "classplplot.html#ac0b4623331c1704fba8ab480d3ed938c", null ],
     [ "PL_FCI_BOLD", "classplplot.html#ad5c19171b3782b2b1c76d3b6dbe4e41c", null ],
     [ "PL_FCI_FAMILY", "classplplot.html#af00dc4a620e90ffd9481790fc7396ce7", null ],
     [ "PL_FCI_HEXDIGIT_MASK", "classplplot.html#a6e2bbc3ec109f773d0b9d6ff6c6c4110", null ],
@@ -211,6 +258,7 @@ var classplplot =
     [ "PL_POSITION_VIEWPORT", "classplplot.html#afdb08ad07520cbae622ca660e4e39c92", null ],
     [ "pl_setcontlabelformat", "classplplot.html#a4bb455a23067a0a31054fbbd2df9a803", null ],
     [ "pl_setcontlabelparam", "classplplot.html#a67f9326e173007cd7320aa90afc682a4", null ],
+    [ "pl_test_flt", "classplplot.html#aa8a085057363aec3c1f87b6201b6dc6e", null ],
     [ "PL_X_AXIS", "classplplot.html#a9c778b860f2871a585009497787919e6", null ],
     [ "PL_Y_AXIS", "classplplot.html#ae2114d3d365951b2982495ea8c5d74bc", null ],
     [ "PL_Z_AXIS", "classplplot.html#a3db3b59a6a597a00ad7d5e3cd8189e6c", null ],
@@ -270,6 +318,7 @@ var classplplot =
     [ "plfamadv", "classplplot.html#accb5fc9efe774fac0c27ade42896fa3c", null ],
     [ "PLfGrid", "classplplot.html#a8ad11f18fef6acd1ac3d69c59d681ea2", null ],
     [ "PLfGrid2", "classplplot.html#a375e738f3a47becf6b450e4d4095f13a", null ],
+    [ "plflt", "classplplot.html#af4efe2eb24aa2b34e81343c5e44c8fb2", null ],
     [ "plflush", "classplplot.html#a1bd7e4bce7e66986a3bfd8020a00d400", null ],
     [ "plfont", "classplplot.html#a143cde9cd53a8fc88bd715d6874078a0", null ],
     [ "plfontld", "classplplot.html#a3ac96186aa875aa8f8b4018d8857ec97", null ],
