@@ -1,10 +1,13 @@
 var classwxPLplotwindow =
 [
-    [ "wxPLplotwindow", "classwxPLplotwindow.html#aa1d1a9dc96341c115360dead33d6be18", null ],
+    [ "wxPLplotwindow", "classwxPLplotwindow.html#a04e9404bd092d669e9eb69d8fcf41699", null ],
     [ "~wxPLplotwindow", "classwxPLplotwindow.html#ad9ca072bd52da411d42224523496c81b", null ],
     [ "GetStream", "classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa", null ],
+    [ "IsReady", "classwxPLplotwindow.html#a4a49b4d5858afbe931550601e3d0eada", null ],
     [ "OnCreate", "classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684", null ],
     [ "OnErase", "classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c", null ],
+    [ "OnLocate", "classwxPLplotwindow.html#ae608afb8eef92ad95814e7242b9726dc", null ],
+    [ "OnMouse", "classwxPLplotwindow.html#af2547b13630e6f3cabdedd5520749a2a", null ],
     [ "OnPaint", "classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594", null ],
     [ "OnSize", "classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb", null ],
     [ "RenewPlot", "classwxPLplotwindow.html#a0f746b49cc3f84810c303129910bfd5f", null ],
@@ -14,6 +17,7 @@ var classwxPLplotwindow =
     [ "m_bitmap", "classwxPLplotwindow.html#a448fc7b678fe9300e09a0ec4845aceb6", null ],
     [ "m_canvasColour", "classwxPLplotwindow.html#a56a3fc5e70ab0b4288d405eba3221103", null ],
     [ "m_created", "classwxPLplotwindow.html#ae146662e19866daab2746062529f6da6", null ],
+    [ "m_initialSize", "classwxPLplotwindow.html#a0c105bec0e7cdf1c4431b3c9eb2c4e3c", null ],
     [ "m_memoryDc", "classwxPLplotwindow.html#a431044cf4a70a2aa3802a7ca585590f7", null ],
     [ "m_stream", "classwxPLplotwindow.html#a4a24892a8539fcbe23dfa2f22c886798", null ],
     [ "m_useGraphicsContext", "classwxPLplotwindow.html#af4600d45758ea7ade4dda619782431be", null ]
