@@ -1,9 +1,8 @@
 var namespaceplplot =
 [
-    [ "core", "namespaceplplot_1_1core.html", "namespaceplplot_1_1core" ],
-    [ "PLcGrid", "structplplot_1_1PLcGrid.html", "structplplot_1_1PLcGrid" ],
-    [ "PLcGrid2", "structplplot_1_1PLcGrid2.html", "structplplot_1_1PLcGrid2" ],
     [ "_N1", "structplplot_1_1__N1.html", "structplplot_1_1__N1" ],
+    [ "_N10", "structplplot_1_1__N10.html", "structplplot_1_1__N10" ],
+    [ "_N11", "structplplot_1_1__N11.html", "structplplot_1_1__N11" ],
     [ "_N2", "structplplot_1_1__N2.html", "structplplot_1_1__N2" ],
     [ "_N3", "structplplot_1_1__N3.html", "structplplot_1_1__N3" ],
     [ "_N4", "structplplot_1_1__N4.html", "structplplot_1_1__N4" ],
@@ -12,6 +11,6 @@ var namespaceplplot =
     [ "_N7", "structplplot_1_1__N7.html", "structplplot_1_1__N7" ],
     [ "_N8", "structplplot_1_1__N8.html", "structplplot_1_1__N8" ],
     [ "_N9", "structplplot_1_1__N9.html", "structplplot_1_1__N9" ],
-    [ "_N10", "structplplot_1_1__N10.html", "structplplot_1_1__N10" ],
-    [ "_N11", "structplplot_1_1__N11.html", "structplplot_1_1__N11" ]
+    [ "PLcGrid", "structplplot_1_1PLcGrid.html", "structplplot_1_1PLcGrid" ],
+    [ "PLcGrid2", "structplplot_1_1PLcGrid2.html", "structplplot_1_1PLcGrid2" ]
 ];
\ No newline at end of file
