@@ -2,9 +2,9 @@ var namespaces =
 [
     [ "makedocstrings", "namespacemakedocstrings.html", null ],
     [ "plcallback", "namespaceplcallback.html", null ],
-    [ "Plframe", "namespacePlframe.html", null ],
     [ "plplot", "namespaceplplot.html", null ],
     [ "plplotc", "namespaceplplotc.html", null ],
+    [ "plplotc_fixed", "namespaceplplotc__fixed.html", null ],
     [ "Swig", "namespaceSwig.html", null ],
     [ "TclSup", "namespaceTclSup.html", null ]
 ];
\ No newline at end of file
