@@ -38,54 +38,50 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"PLCallbackCT_8java.html",
-"cd_8c.html",
-"classPLNamedMutex.html#acbf03b1fe516befb93fc6b239c802e8b",
-"classplplot.html#a3fbb9171d73f5670d2ebf52797775966",
-"classplplot_1_1core_1_1PLStream.html#a0bd1b46d3ca7426c84a138c9767d828b",
-"classplplot_1_1core_1_1plplotjavac.html#a7d9b3d28fcc84d93e8889c61b273752c",
-"classplplot_1_1core_1_1plplotjavacJNI.html#a6c3bc04d8eb036621189c5614059441b",
-"classplplotc_1_1PLGraphicsIn.html",
-"classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1",
-"disptab_8h.html#a6deaecb817eab46142ebb2eac119ff44",
-"globals_func_0x70.html",
-"interfaceplplot_1_1plbin.html#a6c68cffd9481d74c0a95e9750d5141a2",
-"interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html#a207be70365602666dba8474dbc468139",
-"namespacemakedocstrings.html",
-"pdfutils_8c.html#a8b2e2133ddc387df8b1e6c3ed882ad7c",
-"plbuf_8c.html#a6e3e586984481314f86de46295eea6f7",
-"plcore_8h.html#ad1deefa41120df540fc35a5f37877212",
-"plevent_8h.html#abd9540b5c13eeafacc4373a40c7c6f8a",
-"plimage_8c.html#a34468d6826e119f4cb5218452e9bbdf3",
-"plplotP_8h.html#a26b65cc5d4ef0a9184e846eae3d11cff",
-"plplot_8d.html#a42479faafba4397a48eb085714c715a8",
-"plplot_8h.html#a0b36e6a122fbc4a47ff8ad9964f8623e",
-"plplot_8h.html#a7bfcd88ba0586868b1e6a306416d9f64",
-"plplot_8h.html#aea8b2357c54cbeb5684fd5dc07969f81",
-"plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004",
-"plplot__octaveOCTAVE__wrap_8cxx.html#a70e41eebfacedae630ffb0f6830da98d",
-"plplot__octaveOCTAVE__wrap_8cxx.html#ad29fd467771471a5291b05fb9d38b53f",
-"plplotc_8py.html#a4b4963c66abfe6a3524bf1ce73a579a5",
-"plplotc_8py.html#afc6c6d9d92c1b411d0d578599666b51e",
-"plplotcmodulePYTHON__wrap_8c.html#a6fea38d61cc362fd7b67a9fa56b33307",
-"plplotcmodulePYTHON__wrap_8c.html#adccbcbf6df87e38c5a227a9b5c7f70e4",
-"plplotjavacJAVA__wrap_8c.html#a69e9e7083a1122604384a269911c2b28",
-"plplotjavacJAVA__wrap_8c.html#afff14b44f5960bb76a5936330a7238b9",
-"plplotluacLUA__wrap_8c.html#a96a75364a5f20fd525bb603440f698d3",
-"plplotter_8c.html#a8c15b9e762184f103dfb8db1e75e3bb9",
-"plstubs_8h.html#a2cded6c634e046be1bba801e854d4a6d",
-"pltime_8c_source.html",
-"sccont_8c.html#a16c148062c4da36976913095089a42e6",
-"structEscText.html",
-"structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1",
-"structPLStrip.html#ae271e5c050c41c2e2f4458de756f99c0",
-"structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1",
-"structht__bucket.html#a29f598025fca935a60c2720c004bd690",
-"structswig__octave__class.html#af6c5e0b035923e4489939936e82fa15c",
-"tclMatrix_8h.html#abf562e3a618ffccdb8f7064fd715ad7b",
-"tclgen_8h.html#abf4a7d6d0fac5730e81c1395635d845b"
+"Plplotter__Init_8c.html",
+"cd_8h.html#acda6912c19c2eb65c3d37031ee115844",
+"classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2",
+"classplplot.html#a70f3c1ac3250c861cca7f6c9db9f2ad3",
+"classplstream.html#a115a82090b4005cba6c4603e3db014fe",
+"classwxPLDevice.html#a86093029f824890e931904a6aea05319",
+"drivers_8h.html#a3356f1609c863412f0ef0c9519249011",
+"globals_vars_y.html",
+"ltdl__win32_8h.html#a2b4aade23de5404819ba28542e1ece8a",
+"ntk_8c.html#a404b3535fdd386e5d96b157652b7b559",
+"plargs_8c.html#ad4432c090465deb00ff4bbe564245822",
+"plcore_8c.html#aca45ddfcca5aed11ab19be6911e4ebc1",
+"plevent_8h.html#a43a862fc778964aee8a84ab23bccc453",
+"plframe_8c.html#abebd7ec681497127fc6ea9ce684d65f8",
+"plot3d_8c.html#af6dfaf4bf98f307129151a4fd29a1764",
+"plplot_8d.html#a0d57569295ec0852f57d72c33d9c6c5f",
+"plplot_8d.html#aec97625786c16fb8de98d167bc88f44d",
+"plplot_8h.html#a56a2e7aff93cc40a833762f13d95e5a1",
+"plplot_8h.html#ac40cfbf950fe5727d3de6d31abc6c189",
+"plplot__impl_8c.html#a5863eb3a4fa34fdb0b247c44c2266808",
+"plplot__octaveOCTAVE__wrap_8cxx.html#a4f6f5e0444e44e48aef51f6620438a5f",
+"plplot__octaveOCTAVE__wrap_8cxx.html#aa974c1ed408faed8f0c2d36ccceb45bd",
+"plplotc_8py.html#a0277fab4399d9fd6f0fe282e0a590673",
+"plplotc_8py.html#ab1b848a62c75c8f0e27275b06138042c",
+"plplotc__fixed_8py.html#a52342f55be732d38cf0dd7f662ae01fe",
+"plplotcmodulePYTHON__wrap_8c.html#a01ff9379ead152cc27db42716b5aed9f",
+"plplotcmodulePYTHON__wrap_8c.html#a727eb104e49fa97ed1f193341009bc41",
+"plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796",
+"plplotluacLUA__wrap_8c.html#a6f3c8e1ef48fe42610667adde377998f",
+"plplotluacLUA__wrap_8c.html#af6a25edb9ad2ab838e1b1fa3e4450121",
+"plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba556650aa9f007ea0239e66d3ddf26759",
+"qsastime_8c.html#a782cabb15675eec0cb0b3e5b6f7fe15e",
+"structPLGraphicsIn.html#a21b1933fd85acc870381e8a8a176b259",
+"structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23",
+"structPlFrame.html#aceaba949a67a76f868e08ae274b44949",
+"struct__state.html#a855b9fc8275e51f42ca108dc6b69a28d",
+"structplplot_1_1__N5.html#aef93c76a75ca48e587e1aaf0b3052fab",
+"tclAPI_8c.html#a04f3effbd8fc6a0e7671a5e2c5f69c74",
+"tclgen_8c.html#aa6b28a14562408b80c57913e011d686f",
+"wxPLplot__nanosec_8h_source.html"
 ];
 
+var SYNCONMSG = 'click to disable panel synchronisation';
+var SYNCOFFMSG = 'click to enable panel synchronisation';
 var navTreeSubIndices = new Array();
 
 function getData(varName)
@@ -108,11 +104,32 @@ function stripPath2(uri)
   return m ? uri.substring(i-6) : s;
 }
 
+function hashValue()
+{
+  return $(location).attr('hash').substring(1).replace(/[^\w\-]/g,'');
+}
+
+function hashUrl()
+{
+  return '#'+hashValue();
+}
+
+function pathName()
+{
+  return $(location).attr('pathname').replace(/[^-A-Za-z0-9+&@#/%?=~_|!:,.;\(\)]/g, '');
+}
+
 function localStorageSupported()
 {
-  return 'localStorage' in window && window['localStorage'] !== null;
+  try {
+    return 'localStorage' in window && window['localStorage'] !== null && window.localStorage.getItem;
+  }
+  catch(e) {
+    return false;
+  }
 }
 
+
 function storeLink(link)
 {
   if (!$("#nav-sync").hasClass('sync') && localStorageSupported()) {
@@ -124,7 +141,7 @@ function deleteLink()
 {
   if (localStorageSupported()) {
     window.localStorage.setItem('navpath','');
-  } 
+  }
 }
 
 function cachedLink()
@@ -145,7 +162,7 @@ function getScript(scriptName,func,show)
   script.onload = func; 
   script.src = scriptName+'.js'; 
   if ($.browser.msie && $.browser.version<=8) { 
-    // script.onload does work with older versions of IE
+    // script.onload does not work with older versions of IE
     script.onreadystatechange = function() {
       if (script.readyState=='complete' || script.readyState=='loaded') { 
         func(); if (show) showRoot(); 
@@ -157,24 +174,22 @@ function getScript(scriptName,func,show)
 
 function createIndent(o,domNode,node,level)
 {
-  if (node.parentNode && node.parentNode.parentNode) {
-    createIndent(o,domNode,node.parentNode,level+1);
-  }
-  var imgNode = document.createElement("img");
-  imgNode.width = 16;
-  imgNode.height = 22;
-  if (level==0 && node.childrenData) {
+  var level=-1;
+  var n = node;
+  while (n.parentNode) { level++; n=n.parentNode; }
+  if (node.childrenData) {
+    var imgNode = document.createElement("img");
+    imgNode.style.paddingLeft=(16*level).toString()+'px';
+    imgNode.width  = 16;
+    imgNode.height = 22;
+    imgNode.border = 0;
     node.plus_img = imgNode;
     node.expandToggle = document.createElement("a");
     node.expandToggle.href = "javascript:void(0)";
     node.expandToggle.onclick = function() {
       if (node.expanded) {
         $(node.getChildrenUL()).slideUp("fast");
-        if (node.isLast) {
-          node.plus_img.src = node.relpath+"ftv2plastnode.png";
-        } else {
-          node.plus_img.src = node.relpath+"ftv2pnode.png";
-        }
+        node.plus_img.src = node.relpath+"ftv2pnode.png";
         node.expanded = false;
       } else {
         expandNode(o, node, false, false);
@@ -182,33 +197,45 @@ function createIndent(o,domNode,node,level)
     }
     node.expandToggle.appendChild(imgNode);
     domNode.appendChild(node.expandToggle);
+    imgNode.src = node.relpath+"ftv2pnode.png";
   } else {
-    domNode.appendChild(imgNode);
+    var span = document.createElement("span");
+    span.style.display = 'inline-block';
+    span.style.width   = 16*(level+1)+'px';
+    span.style.height  = '22px';
+    span.innerHTML = '&#160;';
+    domNode.appendChild(span);
+  } 
+}
+
+var animationInProgress = false;
+
+function gotoAnchor(anchor,aname,updateLocation)
+{
+  var pos, docContent = $('#doc-content');
+  var ancParent = $(anchor.parent());
+  if (ancParent.hasClass('memItemLeft') ||
+      ancParent.hasClass('fieldname') ||
+      ancParent.hasClass('fieldtype') ||
+      ancParent.is(':header'))
+  {
+    pos = ancParent.position().top;
+  } else if (anchor.position()) {
+    pos = anchor.position().top;
   }
-  if (level==0) {
-    if (node.isLast) {
-      if (node.childrenData) {
-        imgNode.src = node.relpath+"ftv2plastnode.png";
-      } else {
-        imgNode.src = node.relpath+"ftv2lastnode.png";
-        domNode.appendChild(imgNode);
-      }
-    } else {
-      if (node.childrenData) {
-        imgNode.src = node.relpath+"ftv2pnode.png";
-      } else {
-        imgNode.src = node.relpath+"ftv2node.png";
-        domNode.appendChild(imgNode);
-      }
-    }
-  } else {
-    if (node.isLast) {
-      imgNode.src = node.relpath+"ftv2blank.png";
-    } else {
-      imgNode.src = node.relpath+"ftv2vertline.png";
-    }
+  if (pos) {
+    var dist = Math.abs(Math.min(
+               pos-docContent.offset().top,
+               docContent[0].scrollHeight-
+               docContent.height()-docContent.scrollTop()));
+    animationInProgress=true;
+    docContent.animate({
+      scrollTop: pos + docContent.scrollTop() - docContent.offset().top
+    },Math.max(50,Math.min(500,dist)),function(){
+      if (updateLocation) window.location.href=aname;
+      animationInProgress=false;
+    });
   }
-  imgNode.border = "0";
 }
 
 function newNode(o, po, text, link, childrenData, lastNode)
@@ -250,9 +277,9 @@ function newNode(o, po, text, link, childrenData, lastNode)
     a.className = stripPath(link.replace('#',':'));
     if (link.indexOf('#')!=-1) {
       var aname = '#'+link.split('#')[1];
-      var srcPage = stripPath($(location).attr('pathname'));
+      var srcPage = stripPath(pathName());
       var targetPage = stripPath(link.split('#')[0]);
-      a.href = srcPage!=targetPage ? url : '#';
+      a.href = srcPage!=targetPage ? url : "javascript:void(0)"; 
       a.onclick = function(){
         storeLink(link);
         if (!$(a).parent().parent().hasClass('selected'))
@@ -262,23 +289,8 @@ function newNode(o, po, text, link, childrenData, lastNode)
           $(a).parent().parent().addClass('selected');
           $(a).parent().parent().attr('id','selected');
         }
-        var pos, anchor = $(aname), docContent = $('#doc-content');
-        if (anchor.parent().attr('class')=='memItemLeft') {
-          pos = anchor.parent().position().top;
-        } else if (anchor.position()) {
-          pos = anchor.position().top;
-        }
-        if (pos) {
-          var dist = Math.abs(Math.min(
-                     pos-docContent.offset().top,
-                     docContent[0].scrollHeight-
-                     docContent.height()-docContent.scrollTop()));
-          docContent.animate({
-            scrollTop: pos + docContent.scrollTop() - docContent.offset().top
-          },Math.max(50,Math.min(500,dist)),function(){
-            window.location.replace(aname);
-          });
-        }
+        var anchor = $(aname);
+        gotoAnchor(anchor,aname,true);
       };
     } else {
       a.href = url;
@@ -359,13 +371,13 @@ function glowEffect(n,duration)
 
 function highlightAnchor()
 {
-  var anchor = $($(location).attr('hash'));
+  var aname = hashUrl();
+  var anchor = $(aname);
   if (anchor.parent().attr('class')=='memItemLeft'){
-    var rows = $('.memberdecls tr[class$="'+
-               window.location.hash.substring(1)+'"]');
+    var rows = $('.memberdecls tr[class$="'+hashValue()+'"]');
     glowEffect(rows.children(),300); // member without details
-  } else if (anchor.parents().slice(2).prop('tagName')=='TR') {
-    glowEffect(anchor.parents('div.memitem'),1000); // enum value
+  } else if (anchor.parent().attr('class')=='fieldname'){
+    glowEffect(anchor.parent().parent(),1000); // enum value
   } else if (anchor.parent().attr('class')=='fieldtype'){
     glowEffect(anchor.parent().parent(),1000); // struct field
   } else if (anchor.parent().is(":header")) {
@@ -373,13 +385,14 @@ function highlightAnchor()
   } else {
     glowEffect(anchor.next(),1000); // normal member
   }
+  gotoAnchor(anchor,aname,false);
 }
 
 function selectAndHighlight(hash,n)
 {
   var a;
   if (hash) {
-    var link=stripPath($(location).attr('pathname'))+':'+hash.substring(1);
+    var link=stripPath(pathName())+':'+hash.substring(1);
     a=$('.item a[class$="'+link+'"]');
   }
   if (a && a.length) {
@@ -390,6 +403,11 @@ function selectAndHighlight(hash,n)
     $(n.itemDiv).addClass('selected');
     $(n.itemDiv).attr('id','selected');
   }
+  if ($('#nav-tree-contents .item:first').hasClass('selected')) {
+    $('#nav-sync').css('top','30px');
+  } else {
+    $('#nav-sync').css('top','5px');
+  }
   showRoot();
 }
 
@@ -406,7 +424,7 @@ function showNode(o, node, index, hash)
       if (!node.childrenVisited) {
         getNode(o, node);
       }
-      $(node.getChildrenUL()).show();
+      $(node.getChildrenUL()).css({'display':'block'});
       if (node.isLast) {
         node.plus_img.src = node.relpath+"ftv2mlastnode.png";
       } else {
@@ -426,7 +444,7 @@ function showNode(o, node, index, hash)
           },true);
         } else {
           var rootBase = stripPath(o.toroot.replace(/\..+$/, ''));
-          if (rootBase=="index" || rootBase=="pages") {
+          if (rootBase=="index" || rootBase=="pages" || rootBase=="search") {
             expandNode(o, n, true, true);
           }
           selectAndHighlight(hash,n);
@@ -438,8 +456,22 @@ function showNode(o, node, index, hash)
   }
 }
 
+function removeToInsertLater(element) {
+  var parentNode = element.parentNode;
+  var nextSibling = element.nextSibling;
+  parentNode.removeChild(element);
+  return function() {
+    if (nextSibling) {
+      parentNode.insertBefore(element, nextSibling);
+    } else {
+      parentNode.appendChild(element);
+    }
+  };
+}
+
 function getNode(o, po)
 {
+  var insertFunction = removeToInsertLater(po.li);
   po.childrenVisited = true;
   var l = po.childrenData.length-1;
   for (var i in po.childrenData) {
@@ -447,6 +479,7 @@ function getNode(o, po)
     po.children[i] = newNode(o, po, nodeData[0], nodeData[1], nodeData[2],
       i==l);
   }
+  insertFunction();
 }
 
 function gotoNode(o,subIndex,root,hash,relpath)
@@ -470,23 +503,18 @@ function navTo(o,root,hash,relpath)
   if (link) {
     var parts = link.split('#');
     root = parts[0];
-    if (parts.length>1) hash = '#'+parts[1];
+    if (parts.length>1) hash = '#'+parts[1].replace(/[^\w\-]/g,'');
     else hash='';
   }
-  if (root==NAVTREE[0][1]) {
-    $('#nav-sync').css('top','30px');
-  } else {
-    $('#nav-sync').css('top','5px');
-  }
   if (hash.match(/^#l\d+$/)) {
     var anchor=$('a[name='+hash.substring(1)+']');
     glowEffect(anchor.parent(),1000); // line number
     hash=''; // strip line number anchors
-    //root=root.replace(/_source\./,'.'); // source link to doc link
   }
   var url=root+hash;
   var i=-1;
   while (NAVTREEINDEX[i+1]<=url) i++;
+  if (i==-1) { i=0; root=NAVTREE[0][1]; } // fallback: show index
   if (navTreeSubIndices[i]) {
     gotoNode(o,i,root,hash,relpath)
   } else {
@@ -499,16 +527,26 @@ function navTo(o,root,hash,relpath)
   }
 }
 
+function showSyncOff(n,relpath)
+{
+    n.html('<img src="'+relpath+'sync_off.png" title="'+SYNCOFFMSG+'"/>');
+}
+
+function showSyncOn(n,relpath)
+{
+    n.html('<img src="'+relpath+'sync_on.png" title="'+SYNCONMSG+'"/>');
+}
+
 function toggleSyncButton(relpath)
 {
   var navSync = $('#nav-sync');
   if (navSync.hasClass('sync')) {
     navSync.removeClass('sync');
-    navSync.html('<img src="'+relpath+'sync_off.png"/>');
-    storeLink(stripPath2($(location).attr('pathname'))+$(location).attr('hash'));
+    showSyncOff(navSync,relpath);
+    storeLink(stripPath2(pathName())+hashUrl());
   } else {
     navSync.addClass('sync');
-    navSync.html('<img src="'+relpath+'sync_on.png"/>');
+    showSyncOn(navSync,relpath);
     deleteLink();
   }
 }
@@ -536,33 +574,38 @@ function initNavTree(toroot,relpath)
   if (localStorageSupported()) {
     var navSync = $('#nav-sync');
     if (cachedLink()) {
-      navSync.html('<img src="'+relpath+'sync_off.png"/>');
+      showSyncOff(navSync,relpath);
       navSync.removeClass('sync');
     } else {
-      navSync.html('<img src="'+relpath+'sync_on.png"/>');
+      showSyncOn(navSync,relpath);
     }
     navSync.click(function(){ toggleSyncButton(relpath); });
   }
 
-  navTo(o,toroot,window.location.hash,relpath);
+  $(window).load(function(){
+    navTo(o,toroot,hashUrl(),relpath);
+    showRoot();
+  });
 
   $(window).bind('hashchange', function(){
      if (window.location.hash && window.location.hash.length>1){
        var a;
        if ($(location).attr('hash')){
-         var clslink=stripPath($(location).attr('pathname'))+':'+
-                               $(location).attr('hash').substring(1);
-         a=$('.item a[class$="'+clslink+'"]');
+         var clslink=stripPath(pathName())+':'+hashValue();
+         a=$('.item a[class$="'+clslink.replace(/</g,'\\3c ')+'"]');
        }
        if (a==null || !$(a).parent().parent().hasClass('selected')){
          $('.item').removeClass('selected');
          $('.item').removeAttr('id');
        }
-       var link=stripPath2($(location).attr('pathname'));
-       navTo(o,link,$(location).attr('hash'),relpath);
+       var link=stripPath2(pathName());
+       navTo(o,link,hashUrl(),relpath);
+     } else if (!animationInProgress) {
+       $('#doc-content').scrollTop(0);
+       $('.item').removeClass('selected');
+       $('.item').removeAttr('id');
+       navTo(o,toroot,hashUrl(),relpath);
      }
   })
-
-  $(window).load(showRoot);
 }
 
