@@ -14,6 +14,8 @@ var pldll_8h =
     [ "PLDLLIMPEXP_PLPLOT_MODULE_DATA", "pldll_8h.html#a56029a7e57892da9b7e1768b404864cd", null ],
     [ "PLDLLIMPEXP_PYQT4", "pldll_8h.html#a87f5399c8969b2cce703051418a4c2ee", null ],
     [ "PLDLLIMPEXP_PYQT4_DATA", "pldll_8h.html#aae6c49bfd5cf09716169dc21a4756977", null ],
+    [ "PLDLLIMPEXP_PYQT5", "pldll_8h.html#ad965cc839f8e4aa18b9b47a617faf266", null ],
+    [ "PLDLLIMPEXP_PYQT5_DATA", "pldll_8h.html#a2dabc847a1b02ebb075ee3aefb10be41", null ],
     [ "PLDLLIMPEXP_QT", "pldll_8h.html#a6915811b91eb46629689336b388f65f2", null ],
     [ "PLDLLIMPEXP_QT_DATA", "pldll_8h.html#af40a3f217ca0a8ae5ddaab86ee0b41ff", null ],
     [ "PLDLLIMPEXP_TCLMAT", "pldll_8h.html#a9914f90ab83c9a6e3beb39d2a95260d2", null ],
