@@ -87,6 +87,19 @@ var plplot_8h =
     [ "PL_LEGEND_ROW_MAJOR", "plplot_8h.html#a67acdb622747723dd63d61c8db77ec3f", null ],
     [ "PL_LEGEND_SYMBOL", "plplot_8h.html#af9035c908614e1db71828eb2de742597", null ],
     [ "PL_LEGEND_TEXT_LEFT", "plplot_8h.html#ae8e673b57f1894dce563b5e3680f04d9", null ],
+    [ "PL_MASK_ALT", "plplot_8h.html#aa1eb47846f1cc3d98bc83d94cad2eb7c", null ],
+    [ "PL_MASK_ALTGR", "plplot_8h.html#acb2a51b6a28457d628c8c578ce05172d", null ],
+    [ "PL_MASK_BUTTON1", "plplot_8h.html#a878d1870831513e95e4ae7f384cd4518", null ],
+    [ "PL_MASK_BUTTON2", "plplot_8h.html#a0393ee301b2a7cfd750e8ec98446cbd8", null ],
+    [ "PL_MASK_BUTTON3", "plplot_8h.html#ad1b4ee99616d467a0dc88faab30b5a9d", null ],
+    [ "PL_MASK_BUTTON4", "plplot_8h.html#a8c6c90f372ce2e839bea9238d9381a6f", null ],
+    [ "PL_MASK_BUTTON5", "plplot_8h.html#a1a098f5c7cbb862e3654afa6a97fc18b", null ],
+    [ "PL_MASK_CAPS", "plplot_8h.html#ac671965b731d43a6e8c4724f457a2521", null ],
+    [ "PL_MASK_CONTROL", "plplot_8h.html#af9fc96a84fc9dee9edf56ed7e0d39390", null ],
+    [ "PL_MASK_NUM", "plplot_8h.html#abae1bea515c5890690d8044ee9078b9c", null ],
+    [ "PL_MASK_SCROLL", "plplot_8h.html#a68518829448f461ef0b35a9be67a1567", null ],
+    [ "PL_MASK_SHIFT", "plplot_8h.html#a514e51ab93bdea1c653fac78e59dda74", null ],
+    [ "PL_MASK_WIN", "plplot_8h.html#a86730139aea11188477badb9d38d66b5", null ],
     [ "PL_MAXKEY", "plplot_8h.html#a44c035ac35674a4596e8e8ab9f01a556", null ],
     [ "PL_MAXWINDOWS", "plplot_8h.html#ad4c0f054dbc15c9e5478c857912c35f8", null ],
     [ "PL_NOTSET", "plplot_8h.html#a33abbe5268cf992ac1a9ed78c169d630", null ],
@@ -354,123 +367,148 @@ var plplot_8h =
     [ "TOP_CONT", "plplot_8h.html#acb12e9a8db273a14ab03715241e88f1a", null ],
     [ "ZEROW2B", "plplot_8h.html#a71153fa058b1bcf36903c89f7b4b2a3f", null ],
     [ "ZEROW2D", "plplot_8h.html#a002b0cf69472088a40a625edb532fd52", null ],
+    [ "PL_GENERIC_POINTER", "plplot_8h.html#a21588374a5b688a980d98e822d8d0ea9", null ],
+    [ "PL_NC_GENERIC_POINTER", "plplot_8h.html#a092f8fffc00287378bc54f50a9edf27d", null ],
     [ "PLBOOL", "plplot_8h.html#aeaedd6596f4fb4446c7fd5ad8f0e9673", null ],
+    [ "PLBOOL_NC_SCALAR", "plplot_8h.html#ac129fb5e615fd75097cd6d387a2b2d23", null ],
+    [ "PLBOOL_VECTOR", "plplot_8h.html#abedf6e0648c1ab84fd0092b85b2a3853", null ],
+    [ "PLCHAR_MATRIX", "plplot_8h.html#a888f37cbad3cf274bd6e346fe9633e32", null ],
+    [ "PLCHAR_NC_MATRIX", "plplot_8h.html#af702cf66883379fbc3f483350f920867", null ],
+    [ "PLCHAR_NC_SCALAR", "plplot_8h.html#aee8b6ca2305f2e90b458dfd81ac3c2c0", null ],
+    [ "PLCHAR_NC_VECTOR", "plplot_8h.html#aa5d13797fb9bcacfabb250bb5c200cf0", null ],
+    [ "PLCHAR_VECTOR", "plplot_8h.html#a4451db36651890dcf3b5d5a34c464477", null ],
+    [ "PLDEFINED_callback", "plplot_8h.html#aeb02c9a1f1e330d07c8921554a33d847", null ],
+    [ "PLF2EVAL_callback", "plplot_8h.html#a7a8ddbe7468aa3f0466ed6338307c150", null ],
     [ "PLF2OPS", "plplot_8h.html#a8073ceeb1a43c3988d0f750cbf080c1c", null ],
+    [ "PLFILL_callback", "plplot_8h.html#a974a88ed8c3be19b244d6d917a30efb0", null ],
     [ "PLFLT", "plplot_8h.html#a245c0090f1fa5e95a4ed3522975dcbf3", null ],
+    [ "PLFLT_FE_POINTER", "plplot_8h.html#abc0828b1dd38bb3139012de4329e3175", null ],
+    [ "PLFLT_MATRIX", "plplot_8h.html#a67b918cc9af5885167a80fd9247f104a", null ],
+    [ "PLFLT_NC_FE_POINTER", "plplot_8h.html#a511843577d8f015e87bad347996d1549", null ],
+    [ "PLFLT_NC_MATRIX", "plplot_8h.html#a8c9260680120bb940f1674993e6475f5", null ],
+    [ "PLFLT_NC_SCALAR", "plplot_8h.html#a284b03b374fffe9f3268acf953567d73", null ],
+    [ "PLFLT_NC_VECTOR", "plplot_8h.html#ac89ba8a98a4fc3dd1caad21b76002064", null ],
+    [ "PLFLT_VECTOR", "plplot_8h.html#a5cacbcce57b8b6cd79709ab7369d1fc6", null ],
     [ "PLINT", "plplot_8h.html#ad703d3a4f671fdd34ec71f3480f6af2d", null ],
     [ "PLINT64", "plplot_8h.html#a75b290585084690535ae97d74b07b570", null ],
-    [ "PLPointer", "plplot_8h.html#ae1d5cf832d1a16ecbacbf5eb4bf5e8f1", null ],
+    [ "PLINT_NC_SCALAR", "plplot_8h.html#aa39c2fe094bf9b6a9f2c80ca1353441b", null ],
+    [ "PLINT_VECTOR", "plplot_8h.html#a8a5cd9170553853e6ac277367d9f87b9", null ],
+    [ "PLLABEL_FUNC_callback", "plplot_8h.html#a00650ed62638edc0275992c7ccb80d61", null ],
+    [ "PLMAPFORM_callback", "plplot_8h.html#a1a4035af0ab6181ae7af11d2b6d250ae", null ],
+    [ "PLPointer", "plplot_8h.html#af1b355a4504738bc8a73a9f06c0769a9", null ],
+    [ "PLTRANSFORM_callback", "plplot_8h.html#a81f4fb534e9de73812eef4e25e439686", null ],
     [ "PLUINT", "plplot_8h.html#a6d6b24fb8596cddc72a21a37cbda14e2", null ],
     [ "PLUNICODE", "plplot_8h.html#a1d3c883be63b6e7855f5bc7ad5212915", null ],
+    [ "PLUNICODE_NC_SCALAR", "plplot_8h.html#a44726b7856581214252163dbe1a130cd", null ],
     [ "c_pl_setcontlabelformat", "plplot_8h.html#ab92ad7ccd9f1667f27dbc4a9d07f8864", null ],
     [ "c_pl_setcontlabelparam", "plplot_8h.html#a487a1e2265297e29a1538db001744f83", null ],
     [ "c_pladv", "plplot_8h.html#a8a327be272177954338a43a173a8fdb5", null ],
     [ "c_plarc", "plplot_8h.html#aa4edd532f3768f7d88bf4643e448d203", null ],
-    [ "c_plaxes", "plplot_8h.html#a78ccbb94e7ab8f2af90acad87088a8af", null ],
-    [ "c_plbin", "plplot_8h.html#aa78836f3e7b2d7290a890e46d109052d", null ],
+    [ "c_plaxes", "plplot_8h.html#a8d985a901ee2b4dd3319ecef684398f6", null ],
+    [ "c_plbin", "plplot_8h.html#a589a2ad1201ccedc14ff36a92689c9f3", null ],
     [ "c_plbop", "plplot_8h.html#accdeaeb65542509d2b8f827266b54982", null ],
-    [ "c_plbox", "plplot_8h.html#ac4e2f3dfbff816b3c5fd52197a6453e5", null ],
-    [ "c_plbox3", "plplot_8h.html#adcf09a37f50a8044cece162ed5fe9f88", null ],
-    [ "c_plbtime", "plplot_8h.html#a4b6bc27aa31006f5a3d48afa09e72e95", null ],
-    [ "c_plcalc_world", "plplot_8h.html#a833b008651bdec96a0283f232564eb89", null ],
+    [ "c_plbox", "plplot_8h.html#a1d345aa0791565ca6ffcf3ea23355474", null ],
+    [ "c_plbox3", "plplot_8h.html#a0da7c3be9cd6853133c2676d1b987042", null ],
+    [ "c_plbtime", "plplot_8h.html#a08d30a801c0153367b9913e5ec64b04d", null ],
+    [ "c_plcalc_world", "plplot_8h.html#a25d48293a603d07e811c04b9477faf94", null ],
     [ "c_plclear", "plplot_8h.html#a91c77a69b1de6d6dea80a8b57f1c3292", null ],
     [ "c_plcol0", "plplot_8h.html#a56f6ef6a76c18a7b7b9d2c891d1467be", null ],
     [ "c_plcol1", "plplot_8h.html#a5ada6ff695ce184c11be47def6dae0a6", null ],
-    [ "c_plcolorbar", "plplot_8h.html#ac50232f7a090cdafbb8513b4fd717d2c", null ],
+    [ "c_plcolorbar", "plplot_8h.html#a46c03ffbe85b2a03a5f8597188e0e488", null ],
     [ "c_plconfigtime", "plplot_8h.html#a5f35b5400d68ae1ebe6418c5bec5052c", null ],
-    [ "c_plcont", "plplot_8h.html#a03a658413a59fa7a234ef095bd7a56bd", null ],
+    [ "c_plcont", "plplot_8h.html#acff127342bc923c604b70008009859b8", null ],
     [ "c_plcpstrm", "plplot_8h.html#ad16c39cffa39e594adba42654a95b698", null ],
-    [ "c_plctime", "plplot_8h.html#a963faaa11f0287a0760a6d2f6440be9d", null ],
+    [ "c_plctime", "plplot_8h.html#afc0c95bf532e98f61c0da1e8933bf6f6", null ],
     [ "c_plend", "plplot_8h.html#a4ab1fe008a7495add8bb292f79806ead", null ],
     [ "c_plend1", "plplot_8h.html#a1a5146bbedba53c0ce7fd661d0424f61", null ],
     [ "c_plenv", "plplot_8h.html#a23b6e27e49270223a087483456992753", null ],
     [ "c_plenv0", "plplot_8h.html#adb576c92128ae8b6b031c12ac15a5e1b", null ],
     [ "c_pleop", "plplot_8h.html#a8859fcac8c131dfc61b767b13540387d", null ],
-    [ "c_plerrx", "plplot_8h.html#a5ede5a31b97e055407d25bcc0b62bb83", null ],
-    [ "c_plerry", "plplot_8h.html#a0907c0cb5767bbe13e24703cc5532ec2", null ],
+    [ "c_plerrx", "plplot_8h.html#a89c4133449bd7b2d4998bcae6a04c698", null ],
+    [ "c_plerry", "plplot_8h.html#ab363162751ee6ef6e21d77ce54874af9", null ],
     [ "c_plfamadv", "plplot_8h.html#a02ad120a9efe2cb42033f3a3f4aa1ce9", null ],
-    [ "c_plfill", "plplot_8h.html#a4914542b590fa82badc11bbac6e18dbc", null ],
-    [ "c_plfill3", "plplot_8h.html#a9a3ed081aff3bb99f79b07280b6f6888", null ],
+    [ "c_plfill", "plplot_8h.html#a44ab2b3b469771116a4db95b2e5fd27c", null ],
+    [ "c_plfill3", "plplot_8h.html#a702dd1b227e02ca5d812cadf8cdfcfb1", null ],
     [ "c_plflush", "plplot_8h.html#a97beafec282968a52d99a75b93accc29", null ],
     [ "c_plfont", "plplot_8h.html#ab314b1eb2abdc661c87b988cf1862a88", null ],
     [ "c_plfontld", "plplot_8h.html#ab1801dd8db40f4262d7265a15710d987", null ],
-    [ "c_plgchr", "plplot_8h.html#af31374783fde33b7e3fa15b6679e15fb", null ],
-    [ "c_plgcmap1_range", "plplot_8h.html#ad8f614c4935c2b774b8aa4fb28f71486", null ],
-    [ "c_plgcol0", "plplot_8h.html#a38283d88f36f8dbe8d942d60d5227d8e", null ],
-    [ "c_plgcol0a", "plplot_8h.html#af1bafa6196b1dfc71364dc9c1040d855", null ],
-    [ "c_plgcolbg", "plplot_8h.html#a5fd0418a0e3335ee28f5a984e3104e2c", null ],
-    [ "c_plgcolbga", "plplot_8h.html#a21bcaa00e35eb1a65e309a56b6a56baf", null ],
-    [ "c_plgcompression", "plplot_8h.html#a8abdea275f7a74f24f507d07835b87df", null ],
-    [ "c_plgdev", "plplot_8h.html#a7bfcd88ba0586868b1e6a306416d9f64", null ],
-    [ "c_plgdidev", "plplot_8h.html#aa7e7def3ecb7f2a9fb725c41f47b48b9", null ],
-    [ "c_plgdiori", "plplot_8h.html#aabb741c2faedfbdd90a829acd8902bef", null ],
-    [ "c_plgdiplt", "plplot_8h.html#a5f22415724d01e7a214bb2725aeb6305", null ],
+    [ "c_plgchr", "plplot_8h.html#aa34129723151f735bccb7235100d25f7", null ],
+    [ "c_plgcmap1_range", "plplot_8h.html#a97756af8171ea76ebc95c0fe747f0bf0", null ],
+    [ "c_plgcol0", "plplot_8h.html#a29d0b83353fd7e9f5e428671755e5213", null ],
+    [ "c_plgcol0a", "plplot_8h.html#af98e10d22b67d3ba93d3ec2f243aa4a3", null ],
+    [ "c_plgcolbg", "plplot_8h.html#a3a708627395ec9e605b856d681ce10f8", null ],
+    [ "c_plgcolbga", "plplot_8h.html#ae4759b661af4b185e35bf92749bab3e5", null ],
+    [ "c_plgcompression", "plplot_8h.html#abfc3c648a0b567d4f559c91881df9dcd", null ],
+    [ "c_plgdev", "plplot_8h.html#ac0a6d5bc5326bc6701c7d7eb84dd19ff", null ],
+    [ "c_plgdidev", "plplot_8h.html#a6ceac24eef18fd53571f0dec736d365d", null ],
+    [ "c_plgdiori", "plplot_8h.html#a8fa675f7f6fa7d2bb18948a007ec19d7", null ],
+    [ "c_plgdiplt", "plplot_8h.html#a857b0f6c556e29af73291eb0f5e5294d", null ],
     [ "c_plgdrawmode", "plplot_8h.html#af320bdd8254937cf5f5fff6379e366ad", null ],
-    [ "c_plgfam", "plplot_8h.html#a5fbc82655bdaa77d0983eb4fa2e738d4", null ],
-    [ "c_plgfci", "plplot_8h.html#a1c212bf6b83b4a7171a9a90dc7348b70", null ],
-    [ "c_plgfnam", "plplot_8h.html#a5fa15c697b899966bfbd8587a70f5296", null ],
-    [ "c_plgfont", "plplot_8h.html#ad12c98127135c4d1c4479e4a07a350f0", null ],
-    [ "c_plglevel", "plplot_8h.html#a018a9a116388d72e857009e874462d65", null ],
-    [ "c_plgpage", "plplot_8h.html#a8ade125e6a2f739eb0710f1f24f6ed96", null ],
+    [ "c_plgfam", "plplot_8h.html#a2c79d5ca4664afe7cf69b6c571b649ea", null ],
+    [ "c_plgfci", "plplot_8h.html#ad34ded6547508ef7ef7b5cdb07bb74d3", null ],
+    [ "c_plgfnam", "plplot_8h.html#a6423bbc4892a58f8cb4b8b630a6ac130", null ],
+    [ "c_plgfont", "plplot_8h.html#af7a245bb044daa21faa18b0d4c014c2c", null ],
+    [ "c_plglevel", "plplot_8h.html#a0efd37df7fc5f5f2b5c0a8a8c1fb5baf", null ],
+    [ "c_plgpage", "plplot_8h.html#af02d7e496e73b1f705841448257d28e4", null ],
     [ "c_plgra", "plplot_8h.html#a20f4029e24d5d3299dd3d2136afc572b", null ],
-    [ "c_plgradient", "plplot_8h.html#a3e1325fa507566d1cb4dc33907710f7a", null ],
-    [ "c_plgriddata", "plplot_8h.html#a387cce59d30085fe69a8687e463143d3", null ],
-    [ "c_plgspa", "plplot_8h.html#affaa89bc162c978596113da648b7d2c6", null ],
-    [ "c_plgstrm", "plplot_8h.html#afdc85148e6a8778038c0ab1c44dae0a9", null ],
-    [ "c_plgver", "plplot_8h.html#a80cf7995d221d6a4a08dfa6f74d5e5c1", null ],
-    [ "c_plgvpd", "plplot_8h.html#a0fb65308985fb0eb897556236ff01b3c", null ],
-    [ "c_plgvpw", "plplot_8h.html#a6e1c6d382c47753860eee10186c12cae", null ],
-    [ "c_plgxax", "plplot_8h.html#a03cb3367262ac01f01743bd4490ac3f4", null ],
-    [ "c_plgyax", "plplot_8h.html#a834c1a87a0663c412e12e17104f1c13d", null ],
-    [ "c_plgzax", "plplot_8h.html#aaca6b435455750c229db7c4a2deb1eda", null ],
-    [ "c_plhist", "plplot_8h.html#a26925a9320f8c3a0f665a714b47812e9", null ],
-    [ "c_plhlsrgb", "plplot_8h.html#a041bb9d5bcab9d063e7353875d89380c", null ],
-    [ "c_plimage", "plplot_8h.html#af578d63c522e8cd1ded1915a0cb59656", null ],
-    [ "c_plimagefr", "plplot_8h.html#a1aad80d9375a8660287d91fd2cdb31fc", null ],
+    [ "c_plgradient", "plplot_8h.html#a063367be3ffe4299a3ac8db371eb0fef", null ],
+    [ "c_plgriddata", "plplot_8h.html#a7aeb5aae19a7d81fb2b75b3bdbd469f2", null ],
+    [ "c_plgspa", "plplot_8h.html#afea94c13d8f0f4bd8b2153fa28f080b1", null ],
+    [ "c_plgstrm", "plplot_8h.html#a1d9430a0b423d181e06d67da386664aa", null ],
+    [ "c_plgver", "plplot_8h.html#a4fe427e206890cdcae910c34a75c3794", null ],
+    [ "c_plgvpd", "plplot_8h.html#a6b1c6e7fc2d4d988f94eba0ac2ca45e2", null ],
+    [ "c_plgvpw", "plplot_8h.html#a64ef22b435f6d6bc21ef4552e6765b98", null ],
+    [ "c_plgxax", "plplot_8h.html#a62ad5fe400e5364017663feda6d4341d", null ],
+    [ "c_plgyax", "plplot_8h.html#a949c1a3b75363b541294ebed21b0e26c", null ],
+    [ "c_plgzax", "plplot_8h.html#ab8b6270a88d9d8b737bf2dfac895cc04", null ],
+    [ "c_plhist", "plplot_8h.html#a7b89fa38b97399d9dcd2758a47bcf906", null ],
+    [ "c_plhlsrgb", "plplot_8h.html#a9e9560a0fddc381de37802b7d14ec1e1", null ],
+    [ "c_plimage", "plplot_8h.html#a8e4c28058e6347f092502d71de4537de", null ],
+    [ "c_plimagefr", "plplot_8h.html#a06279ee83cd77e1bc299300b79e7dd4c", null ],
     [ "c_plinit", "plplot_8h.html#a16ca877b784c3f1afa2157e7b01c9f09", null ],
     [ "c_pljoin", "plplot_8h.html#ae41b66e619fb441dae94b8fe9c7de1e7", null ],
-    [ "c_pllab", "plplot_8h.html#a5e1594eab38eb9ecb9ae8b9ec2e4bff6", null ],
-    [ "c_pllegend", "plplot_8h.html#a2fd1c8071a2f6b3631cea49cf6233bdd", null ],
+    [ "c_pllab", "plplot_8h.html#a2d786426e8f623cbd69b2b2c214cb2c9", null ],
+    [ "c_pllegend", "plplot_8h.html#a981ec3dc0aa9b0f285d8547aea82d23d", null ],
     [ "c_pllightsource", "plplot_8h.html#a64222d2e573b3f5e467cbbc55f16d3f6", null ],
-    [ "c_plline", "plplot_8h.html#a02f8dd9569ed70fca023e7a6dc9b5620", null ],
-    [ "c_plline3", "plplot_8h.html#aaac706424e86b2f7e58afda2d5e41910", null ],
+    [ "c_plline", "plplot_8h.html#a17c82e570f86b8f81c5542b786946da3", null ],
+    [ "c_plline3", "plplot_8h.html#aaf02d5c98fddf91faab1b481e5de3686", null ],
     [ "c_pllsty", "plplot_8h.html#a317c00e1dc4960ac3aa3181ffce231a6", null ],
-    [ "c_plmap", "plplot_8h.html#a9391038c1678595134892ff48cbb151e", null ],
-    [ "c_plmapfill", "plplot_8h.html#a38b398f721fea3e44a59a8fa6bb51e6f", null ],
-    [ "c_plmapline", "plplot_8h.html#aae0c48c339d13839fbbb9da7200a30cc", null ],
-    [ "c_plmapstring", "plplot_8h.html#a1dc91678b27b6a92e2c20053324025e6", null ],
-    [ "c_plmaptex", "plplot_8h.html#a0c62c3dab9c7d5e1d277a9ef116fa255", null ],
-    [ "c_plmeridians", "plplot_8h.html#a6ada49386576a255cb1d7e27a152e111", null ],
-    [ "c_plmesh", "plplot_8h.html#a618d08727a1d07ebccca591e3201181e", null ],
-    [ "c_plmeshc", "plplot_8h.html#a2969d7142ae7ef0ec919382c5bd192c9", null ],
-    [ "c_plmkstrm", "plplot_8h.html#a7b72daf54749d4fc50530bd0078bd647", null ],
-    [ "c_plmtex", "plplot_8h.html#abff0987d28ded2f6b07854ba340fb36c", null ],
-    [ "c_plmtex3", "plplot_8h.html#ad0f7988e3ef74e1e6c0645ad838d6f44", null ],
-    [ "c_plot3d", "plplot_8h.html#ad6079813e6c40aa46404846b5ccc3369", null ],
-    [ "c_plot3dc", "plplot_8h.html#a9c13aae387009efe5b46b46e3a3e78b8", null ],
-    [ "c_plot3dcl", "plplot_8h.html#a2082412edea213da94500672b925ce5c", null ],
-    [ "c_plparseopts", "plplot_8h.html#a62289eba72af9d3d186007d4b03da3f1", null ],
-    [ "c_plpat", "plplot_8h.html#af4e038bb94bb29f091fbe36b2326bd2a", null ],
+    [ "c_plmap", "plplot_8h.html#ad62f515e45976081ce8a9f7bac1f5fbe", null ],
+    [ "c_plmapfill", "plplot_8h.html#a30c236fa79bdfa1660dd9f118943d837", null ],
+    [ "c_plmapline", "plplot_8h.html#a43bd3bdada218a375a746473476ec81b", null ],
+    [ "c_plmapstring", "plplot_8h.html#aa6f4fa0f8caa352ea1f189e0a5bc602b", null ],
+    [ "c_plmaptex", "plplot_8h.html#a82bfabf7d9063d7dd24b55c536102b33", null ],
+    [ "c_plmeridians", "plplot_8h.html#a03da9456b0d3e6e189495f2b7f07cd21", null ],
+    [ "c_plmesh", "plplot_8h.html#a478ab14993898d98430ddff1ecb40e42", null ],
+    [ "c_plmeshc", "plplot_8h.html#a200a123ec2394a19f7f85041216670fb", null ],
+    [ "c_plmkstrm", "plplot_8h.html#a4a61b2952989661dfeba25255e5b69cd", null ],
+    [ "c_plmtex", "plplot_8h.html#a18af12e84fb7c6dfe48560934dd7dc95", null ],
+    [ "c_plmtex3", "plplot_8h.html#ae285c7b126ace3cd54ef99e4aec476ec", null ],
+    [ "c_plot3d", "plplot_8h.html#ae8d88d4d369fe4bd451a3a49879d8031", null ],
+    [ "c_plot3dc", "plplot_8h.html#aa1810e4a628715ed5ffadc6136f48398", null ],
+    [ "c_plot3dcl", "plplot_8h.html#a44def6e9fea6c1176924d79fcf261de9", null ],
+    [ "c_plparseopts", "plplot_8h.html#a38e55cb777827fb20f2232a15ae4173a", null ],
+    [ "c_plpat", "plplot_8h.html#ab0aa536197dc1d89ff052966526aca11", null ],
     [ "c_plpath", "plplot_8h.html#ac947f42e00e129aacc9f4ff3c327cc19", null ],
-    [ "c_plpoin", "plplot_8h.html#aee7ffbc6ec6b65acd6549ce85efa00d8", null ],
-    [ "c_plpoin3", "plplot_8h.html#a5db14b5420774721a58791df0d2c2d26", null ],
-    [ "c_plpoly3", "plplot_8h.html#a81848f61f2dc21d3fa87d2fbe7393418", null ],
+    [ "c_plpoin", "plplot_8h.html#a40101c62e44753e0fbb53bca3dda4e3d", null ],
+    [ "c_plpoin3", "plplot_8h.html#aa85d524791c998cf7879a674d29c4a02", null ],
+    [ "c_plpoly3", "plplot_8h.html#a711dcee320aa37b3c05c5de09a186aaa", null ],
     [ "c_plprec", "plplot_8h.html#ab6b43004c739e263fe61d819e6891c8a", null ],
     [ "c_plpsty", "plplot_8h.html#a743018ee685c7586c37d0b9102ed0d39", null ],
-    [ "c_plptex", "plplot_8h.html#a9c4f52922e3e2a9bb84947fdd6c2781e", null ],
-    [ "c_plptex3", "plplot_8h.html#a3e4747e742bbbf1f5581a7e9d3461035", null ],
+    [ "c_plptex", "plplot_8h.html#ab296b8b58169050677b720ff7564356b", null ],
+    [ "c_plptex3", "plplot_8h.html#a308b222be7f960448b9e3b59378e746c", null ],
     [ "c_plrandd", "plplot_8h.html#acf3655ca771545e49a3d28edcef394f0", null ],
     [ "c_plreplot", "plplot_8h.html#a54683e3343102a1ea4cf61fcaef13a8f", null ],
-    [ "c_plrgbhls", "plplot_8h.html#a032c66c4cca2e7124baacd3ce912781c", null ],
+    [ "c_plrgbhls", "plplot_8h.html#abb841ff8f757fca685d092cc64e2a200", null ],
     [ "c_plschr", "plplot_8h.html#a906b2f2e72c885b9783bbc6342b7c4da", null ],
-    [ "c_plscmap0", "plplot_8h.html#a4f8326016609e4686cb339c714116af3", null ],
-    [ "c_plscmap0a", "plplot_8h.html#a5dbf015b428b050f37f37ba88fcbeaef", null ],
+    [ "c_plscmap0", "plplot_8h.html#a04391c14259555227350b0262399243a", null ],
+    [ "c_plscmap0a", "plplot_8h.html#ae7b4b017186c1463ab674d4781014100", null ],
     [ "c_plscmap0n", "plplot_8h.html#a06233e8a8024f3fe8079de7f607ea73f", null ],
-    [ "c_plscmap1", "plplot_8h.html#ac5bd5366e2504980f3da8672d001a2c2", null ],
+    [ "c_plscmap1", "plplot_8h.html#ae72a5fe915a81f711cfbefc59496d4ae", null ],
     [ "c_plscmap1_range", "plplot_8h.html#a15a484127420306e6d1f1c478cf51d59", null ],
-    [ "c_plscmap1a", "plplot_8h.html#a9c8a9519937f2c3e7bcbc3c237f68c4a", null ],
-    [ "c_plscmap1l", "plplot_8h.html#a03f8c884922878526ded8befd65bb5d4", null ],
-    [ "c_plscmap1la", "plplot_8h.html#aad52d3709a1c3ce637d690a15b0932a6", null ],
+    [ "c_plscmap1a", "plplot_8h.html#ab63cd2760e54ba4122ba4a50232667c6", null ],
+    [ "c_plscmap1l", "plplot_8h.html#ab3313d8d86ee93e055b34ef38efdaadb", null ],
+    [ "c_plscmap1la", "plplot_8h.html#a2e188ae3b30c9ed3292d917b8318d288", null ],
     [ "c_plscmap1n", "plplot_8h.html#a93963a081b30143656abd1ad77b1e7bc", null ],
     [ "c_plscol0", "plplot_8h.html#a4d5ea8fd667658ed26a7d70ce0fc5264", null ],
     [ "c_plscol0a", "plplot_8h.html#af75af09a57c17101f4b7b5225862b7ae", null ],
@@ -478,7 +516,7 @@ var plplot_8h =
     [ "c_plscolbga", "plplot_8h.html#afa72d07cae36a1535bf8af837aaad4ea", null ],
     [ "c_plscolor", "plplot_8h.html#a5e26e69ae11fc868f67768e88909c3e7", null ],
     [ "c_plscompression", "plplot_8h.html#a9104ebbbc78bdd17139db834e82c832b", null ],
-    [ "c_plsdev", "plplot_8h.html#a5427b7d8ceeb6f43def8bf3fc5c40212", null ],
+    [ "c_plsdev", "plplot_8h.html#a63dcd0d0b1a3c1f54b6a8277217eb917", null ],
     [ "c_plsdidev", "plplot_8h.html#ae403c84fd74141a2e18396d6a325495a", null ],
     [ "c_plsdimap", "plplot_8h.html#afed985f4d2553562eb32cf1399b61aa5", null ],
     [ "c_plsdiori", "plplot_8h.html#ad2cb5ae88431579cc0f900549613692f", null ],
@@ -487,113 +525,113 @@ var plplot_8h =
     [ "c_plsdrawmode", "plplot_8h.html#a00bf7735eb2174bc163fdf623ac7ea16", null ],
     [ "c_plseed", "plplot_8h.html#a1e607017d84ca2ba0425c77ca7aeb87b", null ],
     [ "c_plsesc", "plplot_8h.html#a2ce235ed573c83efff9f02a696a555ee", null ],
-    [ "c_plsetopt", "plplot_8h.html#a8147a66b10fe9c3a80206bad403fd442", null ],
+    [ "c_plsetopt", "plplot_8h.html#a487e1b4557470c8d2a364ecc1b9d79e0", null ],
     [ "c_plsfam", "plplot_8h.html#ab3d16a3db91caab121bcb9ce80546fba", null ],
     [ "c_plsfci", "plplot_8h.html#a074ce37141f38208e2d25ce5bb3a785b", null ],
-    [ "c_plsfnam", "plplot_8h.html#afa8e0eb91366606acea7efda5c5d1b58", null ],
+    [ "c_plsfnam", "plplot_8h.html#a5337f550e9667396f3ebf85dd8508e65", null ],
     [ "c_plsfont", "plplot_8h.html#a6393d02708ce42194302ccf3b94edf47", null ],
-    [ "c_plshade", "plplot_8h.html#a681c832685b8bb75faf9e58f37fdf394", null ],
-    [ "c_plshade1", "plplot_8h.html#aef38afccf5f7904554bd7c3cb60f3787", null ],
-    [ "c_plshades", "plplot_8h.html#a3404cc5e4f32706913920ff6caa8b345", null ],
-    [ "c_plslabelfunc", "plplot_8h.html#a3f1f502a0174f82c0308ef96e915281c", null ],
+    [ "c_plshade", "plplot_8h.html#abb98f54306b240493ac9031342e2df04", null ],
+    [ "c_plshade1", "plplot_8h.html#a41c572aa37f14e6ee3861e135784458f", null ],
+    [ "c_plshades", "plplot_8h.html#ab4b7bb654479745c52febe90d0bd802c", null ],
+    [ "c_plslabelfunc", "plplot_8h.html#ab29b59ea8d08227dd770d7165db236fb", null ],
     [ "c_plsmaj", "plplot_8h.html#a1c011f9eeab7ca11a5de4f2afdc2b501", null ],
-    [ "c_plsmem", "plplot_8h.html#a60dac657e19f687d66d83ce4c2f9b16c", null ],
-    [ "c_plsmema", "plplot_8h.html#a4abe74bf62df2002dc2f6a2c3b6e4306", null ],
+    [ "c_plsmem", "plplot_8h.html#a0614f09ef44ed5cffc694a972a057968", null ],
+    [ "c_plsmema", "plplot_8h.html#a06ad1c316055aaaa74f9ba2eb9daf605", null ],
     [ "c_plsmin", "plplot_8h.html#afaa43df242c2a6166072b2cc3cf1d1a2", null ],
     [ "c_plsori", "plplot_8h.html#ae92f904189306eb1dc8f1b6641bd3c6b", null ],
     [ "c_plspage", "plplot_8h.html#a993d2bc54f3dd8d7432fe9e2d8ce1b09", null ],
-    [ "c_plspal0", "plplot_8h.html#ab61c4c1b39b7e088ddd2a18de8148629", null ],
-    [ "c_plspal1", "plplot_8h.html#aa43280e5f4cf5321dd7f552320c82b32", null ],
+    [ "c_plspal0", "plplot_8h.html#a6992097a97fa026f4db8515bcba58470", null ],
+    [ "c_plspal1", "plplot_8h.html#a0f29de7505c496be50efa2d191d5de09", null ],
     [ "c_plspause", "plplot_8h.html#aedc6099dad1ae3e4f444b76a28e06b9a", null ],
     [ "c_plsstrm", "plplot_8h.html#a3cae7c0e783e917bd5d2c25adfdce6fd", null ],
     [ "c_plssub", "plplot_8h.html#ab23fbc49ed42a65bc6d9f51321d2497d", null ],
     [ "c_plssym", "plplot_8h.html#a940a97b378a847bd9699d0e18162d57e", null ],
     [ "c_plstar", "plplot_8h.html#a1690af1bfe3d5c00784fdb9e68d830f9", null ],
-    [ "c_plstart", "plplot_8h.html#ae16e0aaab9234c5795aa15744af4ace8", null ],
-    [ "c_plstransform", "plplot_8h.html#a4deb0eb1857f5d518851ec1f41528d36", null ],
-    [ "c_plstring", "plplot_8h.html#ad187ebae694794eb493a251794f1b70d", null ],
-    [ "c_plstring3", "plplot_8h.html#a449b09356e2565fc88b2be19bef4fe03", null ],
+    [ "c_plstart", "plplot_8h.html#acf171cdde28a0ee9c413c912d359420c", null ],
+    [ "c_plstransform", "plplot_8h.html#ad6ebe304a1955f9a50f4fdee36a0a749", null ],
+    [ "c_plstring", "plplot_8h.html#a8422af8d77d66646808e57f0585934a5", null ],
+    [ "c_plstring3", "plplot_8h.html#ac8a61d7c6fae85234acbe7ca5983e94c", null ],
     [ "c_plstripa", "plplot_8h.html#a7635fe351043aa7138a17a7d4b7ba2a4", null ],
-    [ "c_plstripc", "plplot_8h.html#aad03d002cf1ebb356af1c784964eff0d", null ],
+    [ "c_plstripc", "plplot_8h.html#a9b0db1d8eda5c3e71f371b78fcc92be3", null ],
     [ "c_plstripd", "plplot_8h.html#a46d05136dd3eafedef0aab7012cfaacb", null ],
-    [ "c_plstyl", "plplot_8h.html#ab8a6f4438be256864247f5e6fe3dfdeb", null ],
-    [ "c_plsurf3d", "plplot_8h.html#a0566ff5bf7f1e6aecc25caf69d022c7f", null ],
-    [ "c_plsurf3dl", "plplot_8h.html#a63be92c6f128b3b6300822742ea57767", null ],
-    [ "c_plsvect", "plplot_8h.html#a4e4072e40ff8a7127801a00b3a9aa281", null ],
+    [ "c_plstyl", "plplot_8h.html#a21db391b65d6c42f34008e74e3d4f68c", null ],
+    [ "c_plsurf3d", "plplot_8h.html#a7e0dd6508f192868256b850d8c2fe803", null ],
+    [ "c_plsurf3dl", "plplot_8h.html#af1790e938f7b92c6b698f3dae6d06060", null ],
+    [ "c_plsvect", "plplot_8h.html#a3a9507e916cfa4dbd4a146ec71082003", null ],
     [ "c_plsvpa", "plplot_8h.html#a56d8a17aa2d0a673c802ea948abcdc1c", null ],
     [ "c_plsxax", "plplot_8h.html#a6dcf30171cd60db19a3dbf5bc78e3aae", null ],
     [ "c_plsyax", "plplot_8h.html#a3603d38d28846b15c54a114afdfb28c1", null ],
-    [ "c_plsym", "plplot_8h.html#ac6b4b7fdbd26ae0db26f8f656e534680", null ],
+    [ "c_plsym", "plplot_8h.html#ac001d9cf28e7b3160b62f787fec91a10", null ],
     [ "c_plszax", "plplot_8h.html#ae4e2f908751b0a68b5bc599a2e8d50a4", null ],
     [ "c_pltext", "plplot_8h.html#a94c1af262a2855684ddeeea0d13e3fa5", null ],
-    [ "c_pltimefmt", "plplot_8h.html#a3e11f5860e12ba7e52f23c9e6eb4c987", null ],
+    [ "c_pltimefmt", "plplot_8h.html#aff9a3a7ee09c2c1c4076058aa07cc4eb", null ],
     [ "c_plvasp", "plplot_8h.html#a6d0c2a4be40790e91824ad0b7bac0bec", null ],
-    [ "c_plvect", "plplot_8h.html#a8c3439b34e0df4088dfc38819b20e17c", null ],
+    [ "c_plvect", "plplot_8h.html#a2835835831901d228e1cfbf152afc9c6", null ],
     [ "c_plvpas", "plplot_8h.html#abd8a7e0ae9bb0da76807e7e0bf93e3a4", null ],
     [ "c_plvpor", "plplot_8h.html#a5fd547420fef9e958c4026bc2e9c4898", null ],
     [ "c_plvsta", "plplot_8h.html#ad6443e9ab2395017d048b8efb06e2ee2", null ],
     [ "c_plw3d", "plplot_8h.html#a44e37b421e4b094322c520057dcd317d", null ],
     [ "c_plwidth", "plplot_8h.html#a35b056d50ccc18dab5832a99268e04ef", null ],
     [ "c_plwind", "plplot_8h.html#a02525a7edb3a826dc05004ed517263b9", null ],
-    [ "c_plxormod", "plplot_8h.html#acc9adb6ab2f3b1b60db01825dc038a31", null ],
-    [ "pl_cmd", "plplot_8h.html#a1a7540d4d12635cf9f3b1fad73dff8ab", null ],
-    [ "plAlloc2dGrid", "plplot_8h.html#a6ac3f4f3085b37a0fed89c01cdfe401e", null ],
+    [ "c_plxormod", "plplot_8h.html#a253a53d4c29ddbc1060d36b0ebc55a0e", null ],
+    [ "pl_cmd", "plplot_8h.html#afde2494e5fc0946e7e3ec484a42f6c5b", null ],
+    [ "plAlloc2dGrid", "plplot_8h.html#ae34a90e13d05e97d36e99d26866b8889", null ],
     [ "plClearOpts", "plplot_8h.html#a136e9a1081cda371c3fcc2bb59696a3d", null ],
-    [ "pldid2pc", "plplot_8h.html#a29189728d7148b7071ce1417aecd0aa7", null ],
-    [ "pldip2dc", "plplot_8h.html#af9475e5f7938a3f6ee55eda7cee8dc19", null ],
-    [ "plf2eval", "plplot_8h.html#a15c0460c84d3ca43849040b982d8d69e", null ],
-    [ "plf2eval1", "plplot_8h.html#a097a30050fd2bddf928fcec1ec2672a6", null ],
-    [ "plf2eval2", "plplot_8h.html#a1c1fe17eb91fd166f952947bcef664c0", null ],
-    [ "plf2evalr", "plplot_8h.html#a13b48a9789c737d4a5486e4105df1de8", null ],
+    [ "pldid2pc", "plplot_8h.html#a18cf7f7f18d34359fcd9ddd8b7da54f2", null ],
+    [ "pldip2dc", "plplot_8h.html#a26878676152ea08d33681e6667e0c7d7", null ],
+    [ "plf2eval", "plplot_8h.html#a1bdbd0d28cb9865fdcd97b65c1273d42", null ],
+    [ "plf2eval1", "plplot_8h.html#a35c44eae7b5d3ef564e3b172666e3c3b", null ],
+    [ "plf2eval2", "plplot_8h.html#a05cbf15546d9e19cedad9f8bb097ba2e", null ],
+    [ "plf2evalr", "plplot_8h.html#ae8de92d19b30c95125748f5fb5549695", null ],
     [ "plf2ops_c", "plplot_8h.html#a817448e6ec06fc4af7468c0d0a08883d", null ],
     [ "plf2ops_grid_c", "plplot_8h.html#af3e49f0ef356aa28b7f44037f26bd119", null ],
     [ "plf2ops_grid_col_major", "plplot_8h.html#a104755ff623ecf34afc6948186c67177", null ],
     [ "plf2ops_grid_row_major", "plplot_8h.html#a7f85022be841ae07b70b1da84b41b1aa", null ],
-    [ "plfcont", "plplot_8h.html#a9f5755bdd03adc20203ddf0bfa90ce1d", null ],
-    [ "plfgriddata", "plplot_8h.html#ab7f9123b793fc96897eede04f7688666", null ],
-    [ "plfimage", "plplot_8h.html#a5ad593174d50795f89c68316e4ad8479", null ],
-    [ "plfimagefr", "plplot_8h.html#a7a97f69b45ccae543005319519da7de0", null ],
-    [ "plFindCommand", "plplot_8h.html#a73a6f8a34991958fdaba0daf37255539", null ],
-    [ "plFindName", "plplot_8h.html#a6dade9d7cc005d1657ab9c81e531693f", null ],
-    [ "plfmesh", "plplot_8h.html#afc236a6a9e6109548e113d6a28b3f736", null ],
-    [ "plfmeshc", "plplot_8h.html#a81c72cc5974bb3c06f2468ee0b8e237f", null ],
-    [ "plfplot3d", "plplot_8h.html#acb7508ead6179710c4920bdd0aecc20f", null ],
-    [ "plfplot3dc", "plplot_8h.html#ae677a6bdc264ed845ffd7a6ad0f6671d", null ],
-    [ "plfplot3dcl", "plplot_8h.html#ab7c167736733a885e45cafeb65aac20c", null ],
-    [ "plFree2dGrid", "plplot_8h.html#aba3acf43ed3265d44f5bb143903fd5a3", null ],
-    [ "plfshade", "plplot_8h.html#ad60ac7db40a535d44761f54179e64ded", null ],
-    [ "plfshade1", "plplot_8h.html#a3adf25c17be25ccd0c37b40cc7b5885e", null ],
-    [ "plfshades", "plplot_8h.html#a7d33338a8c89fce1f3b3523698af5cb3", null ],
-    [ "plfsurf3d", "plplot_8h.html#a416c721a5d6a03161dd17bbff81a8f82", null ],
-    [ "plfsurf3dl", "plplot_8h.html#ad268cfa7d32a2e3805deb17d40ea9f15", null ],
-    [ "plfvect", "plplot_8h.html#a97acf37f26fe4f4241571bf965fcfdae", null ],
-    [ "plgDevs", "plplot_8h.html#aeec376a18355192b3b7909d8bdc50cac", null ],
-    [ "plgesc", "plplot_8h.html#a1fddf1a9e60a0374fe84efadb061af10", null ],
-    [ "plGetCursor", "plplot_8h.html#a772eea12e90f545a177742aa24fbe365", null ],
-    [ "plGetFlt", "plplot_8h.html#ac29c7216ca3031257cdc7af435074652", null ],
-    [ "plGetInt", "plplot_8h.html#a33d0354f30ddae270f5858d9c26e7ac8", null ],
-    [ "plGetName", "plplot_8h.html#a65b9c9550b66ee563703d3c5f51c4583", null ],
+    [ "plfcont", "plplot_8h.html#a0d99402bf2d5985503261c3abe415e54", null ],
+    [ "plfgriddata", "plplot_8h.html#ae635fd86b4d7a87c820fa7611c967d28", null ],
+    [ "plfimage", "plplot_8h.html#a737367d56150371efa98f1b576699495", null ],
+    [ "plfimagefr", "plplot_8h.html#ac7dd0bf1906fc448531bbd5ff5c389c3", null ],
+    [ "plFindCommand", "plplot_8h.html#a39350e9c96870c88fe88321864d895c2", null ],
+    [ "plFindName", "plplot_8h.html#acc1a0e08ebbd0b9ac69102d1ce56b879", null ],
+    [ "plfmesh", "plplot_8h.html#a2a2f7a34836f8737255d305a599ae040", null ],
+    [ "plfmeshc", "plplot_8h.html#a69ea36b3a21de18fdd574cdf8208f748", null ],
+    [ "plfplot3d", "plplot_8h.html#ad4b5b771ada87ae9d14024d83d4dbdbb", null ],
+    [ "plfplot3dc", "plplot_8h.html#a498d23ac599224e9ca15e37a2a199c6a", null ],
+    [ "plfplot3dcl", "plplot_8h.html#a02e8c6d3ffde1f35e55d96bfc8c214bf", null ],
+    [ "plFree2dGrid", "plplot_8h.html#aca891997511a679167b464a454354d0d", null ],
+    [ "plfshade", "plplot_8h.html#ae41ffc303c25061b52774bf4ad386504", null ],
+    [ "plfshade1", "plplot_8h.html#a76198e2c42ded73773947b46915729e3", null ],
+    [ "plfshades", "plplot_8h.html#a753d0e608869dd5edf7fae293923f8cb", null ],
+    [ "plfsurf3d", "plplot_8h.html#a18fa104ece24f2fd44a3af9a151b6996", null ],
+    [ "plfsurf3dl", "plplot_8h.html#a464eb1afc893afa660d578d441598e08", null ],
+    [ "plfvect", "plplot_8h.html#abd8c0dfbb6c3c0df428330992212a1a5", null ],
+    [ "plgDevs", "plplot_8h.html#af40a0562482b6590bc3160c3c9e0666c", null ],
+    [ "plgesc", "plplot_8h.html#a74224d66129333084337c01d5f75c917", null ],
+    [ "plGetCursor", "plplot_8h.html#ad5d2480241702eb90cf09f478bced094", null ],
+    [ "plGetFlt", "plplot_8h.html#ac853d46c1eab53234355e8ee1be3518d", null ],
+    [ "plGetInt", "plplot_8h.html#a1dfbfb4d6249035083220f8c1d5b803f", null ],
+    [ "plGetName", "plplot_8h.html#ac1d169da4dcca32782f9772187d89bbc", null ],
     [ "plgfile", "plplot_8h.html#a98dfabaac9b75da165aa6e7ade475a0f", null ],
-    [ "plgFileDevs", "plplot_8h.html#ade57037e4a215706ee10c7d1c6590be2", null ],
-    [ "plMergeOpts", "plplot_8h.html#a93bd88e8828e503ba95cc1a3bdc5a10d", null ],
-    [ "plMinMax2dGrid", "plplot_8h.html#a12393157b4b24181df64b346a8708f83", null ],
+    [ "plgFileDevs", "plplot_8h.html#a2990383fed3cedbcfa75d97c8e70bcd9", null ],
+    [ "plMergeOpts", "plplot_8h.html#aa8b678605e8f1d98d31df851ff759f78", null ],
+    [ "plMinMax2dGrid", "plplot_8h.html#aeea6340e4cec56db00f56a3d91d33c9f", null ],
     [ "plOptUsage", "plplot_8h.html#a828ea4bab5bf4b35cb5866e188b81f17", null ],
     [ "plResetOpts", "plplot_8h.html#ad3d858d5c80ab466be7e1993c8d2ee97", null ],
-    [ "plsabort", "plplot_8h.html#a6a12df023027d32b69d013754708ebf0", null ],
-    [ "plsbopH", "plplot_8h.html#a88ee33a7618aff463079633ccb145e49", null ],
-    [ "plsButtonEH", "plplot_8h.html#a361966768bbacf56a799abf06992f7d1", null ],
-    [ "plsdevdata", "plplot_8h.html#aac8ab1a019b61633c58c7f5fe9713357", null ],
-    [ "plseopH", "plplot_8h.html#a6b6320904fa7f9a952a4c61bbadcf88a", null ],
-    [ "plsError", "plplot_8h.html#a07b4540e3e0ceb45b5ce57ebe4f74fc1", null ],
-    [ "plSetUsage", "plplot_8h.html#ac0b71244be8e595726b4edf79f8a5580", null ],
-    [ "plsexit", "plplot_8h.html#af4aa5b303f4601ff4627a2169202ff84", null ],
+    [ "plsabort", "plplot_8h.html#a2a2a9be608c596b60fe0b8661ffcae44", null ],
+    [ "plsbopH", "plplot_8h.html#a34152b0c01746d6bb67720cf6a832a57", null ],
+    [ "plsButtonEH", "plplot_8h.html#a26aeab2b92b1fc478b898757892746a4", null ],
+    [ "plsdevdata", "plplot_8h.html#a1a6d4cd8de4a45c9911f033ace02c05c", null ],
+    [ "plseopH", "plplot_8h.html#a99c76ee631f8dc8418d26e554ca49460", null ],
+    [ "plsError", "plplot_8h.html#a878868ea2e8559bd61d83c9f0d2d090c", null ],
+    [ "plSetUsage", "plplot_8h.html#a1d4ae141dae53eedf36b4442a548068a", null ],
+    [ "plsexit", "plplot_8h.html#a4acf650df862d0ba0374764b9a56fa1f", null ],
     [ "plsfile", "plplot_8h.html#aae38b5a886be8e742373cfa183f0b2a9", null ],
-    [ "plsKeyEH", "plplot_8h.html#a11329f8b9214b69d4801de70b41b3740", null ],
+    [ "plsKeyEH", "plplot_8h.html#a34736fd976c5d6b53ec8e8eb9f568b5d", null ],
     [ "plsxwin", "plplot_8h.html#a41c180a8e3968cb12015b682d40e56d4", null ],
-    [ "pltr0", "plplot_8h.html#a8f436e32d8006975f3ca871d2fa9e4f6", null ],
-    [ "pltr1", "plplot_8h.html#ae86b2a01d3e79d70c593a2b4d0f1ecae", null ],
-    [ "pltr2", "plplot_8h.html#ac18acb9a33e538e602829a532c137933", null ],
-    [ "pltr2f", "plplot_8h.html#a89241537360ca41366c0a9504e08e982", null ],
-    [ "pltr2p", "plplot_8h.html#a762a1334f97320ac54e95c71da7e49b3", null ],
-    [ "plTranslateCursor", "plplot_8h.html#a0a524ebf86467423a7af52e3f86b4d85", null ]
+    [ "pltr0", "plplot_8h.html#ac2b4367b728c525d9a385b96f616b8ba", null ],
+    [ "pltr1", "plplot_8h.html#aa6dc13d8161e787d0861b5664700f247", null ],
+    [ "pltr2", "plplot_8h.html#aa2e1cb3a665654326ada144be7b133f7", null ],
+    [ "pltr2f", "plplot_8h.html#a21b92052be167ba3498345768a8dd232", null ],
+    [ "pltr2p", "plplot_8h.html#ab8c0877372e672dc1743a5e951d209c8", null ],
+    [ "plTranslateCursor", "plplot_8h.html#af4ef867c650293c7b14e9c39cee10a2c", null ]
 ];
\ No newline at end of file
