@@ -263,6 +263,19 @@ var plplotc_8py =
     [ "PL_LEGEND_ROW_MAJOR", "plplotc_8py.html#ae7dffb9a57c39e4ac16aa729c2917221", null ],
     [ "PL_LEGEND_SYMBOL", "plplotc_8py.html#ad845ed17a7e9050c76c224b3562bbd57", null ],
     [ "PL_LEGEND_TEXT_LEFT", "plplotc_8py.html#a5bc571eac419099c60599e939ad4d714", null ],
+    [ "PL_MASK_ALT", "plplotc_8py.html#a5c16c6a5e0164163319948ff43eff3a5", null ],
+    [ "PL_MASK_ALTGR", "plplotc_8py.html#ae72856a78a24e3ff88778afec3af8f52", null ],
+    [ "PL_MASK_BUTTON1", "plplotc_8py.html#aad9600deea050067c611857c2d95a2dc", null ],
+    [ "PL_MASK_BUTTON2", "plplotc_8py.html#a6e47f218452efb91990ab2f5808a0227", null ],
+    [ "PL_MASK_BUTTON3", "plplotc_8py.html#a593727341168e39a2b49996ffc7e7647", null ],
+    [ "PL_MASK_BUTTON4", "plplotc_8py.html#a36bd4cd410445f73e8f073282c0737fe", null ],
+    [ "PL_MASK_BUTTON5", "plplotc_8py.html#a8fb116984553291d09d9aaf944fbbdec", null ],
+    [ "PL_MASK_CAPS", "plplotc_8py.html#a61ef8c220c8ed12f4ebcadd3dda7d8fa", null ],
+    [ "PL_MASK_CONTROL", "plplotc_8py.html#aa4b34c5be475287b91d74781d333cab8", null ],
+    [ "PL_MASK_NUM", "plplotc_8py.html#addd78380df048a1096b1207b2cd2f9d3", null ],
+    [ "PL_MASK_SCROLL", "plplotc_8py.html#ae66c6f83cee574dd53b9fe9d53bd6357", null ],
+    [ "PL_MASK_SHIFT", "plplotc_8py.html#ab1b848a62c75c8f0e27275b06138042c", null ],
+    [ "PL_MASK_WIN", "plplotc_8py.html#a2d4cb90ec57ddb83976f382290420c31", null ],
     [ "PL_MAXKEY", "plplotc_8py.html#aee4112232cec089f90d4f7d92b4f0d86", null ],
     [ "PL_MAXWINDOWS", "plplotc_8py.html#a779a1499d3588bc9c76e568ba2df3c32", null ],
     [ "PL_NOTSET", "plplotc_8py.html#aed76bc0c511df9cd6716ca28cbffe1a9", null ],
@@ -341,7 +354,6 @@ var plplotc_8py =
     [ "PLESC_TEXT", "plplotc_8py.html#ab412042d6d3501a95aeb452b1bc34ffb", null ],
     [ "PLESC_TEXT_CHAR", "plplotc_8py.html#a78f3b4c904b70f3c49f9ccb9bf79083b", null ],
     [ "PLESC_XORMOD", "plplotc_8py.html#a32d1e35e35329b80334d9c61dc442f52", null ],
-    [ "plGetCursor", "plplotc_8py.html#a113311917620d161413e7706a83975da", null ],
     [ "PLGraphicsIn_swigregister", "plplotc_8py.html#a2ed140e1dae13d8870800c18255c50f5", null ],
     [ "plMinMax2dGrid", "plplotc_8py.html#a02d5cc5e9830406ed04d933dc91b5f34", null ],
     [ "plOptUsage", "plplotc_8py.html#a91a52af2917540a0f9fa00c3c55c2dd2", null ],
