@@ -24,6 +24,7 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "PyDescr_NAME", "plplotcmodulePYTHON__wrap_8c.html#a7b007021fc924eb74eccb0bb05d99ad1", null ],
     [ "PyDescr_TYPE", "plplotcmodulePYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc", null ],
     [ "PyExc_StopIteration", "plplotcmodulePYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4", null ],
+    [ "PyInt_FromSize_t", "plplotcmodulePYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b", null ],
     [ "PyObject_Del", "plplotcmodulePYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82", null ],
     [ "PyObject_DEL", "plplotcmodulePYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4", null ],
     [ "PyObject_GenericGetAttr", "plplotcmodulePYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2", null ],
@@ -33,7 +34,7 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "PySequence_Size", "plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796", null ],
     [ "PyString_AsStringAndSize", "plplotcmodulePYTHON__wrap_8c.html#afdc43df5cb9472c0f13c86d8e01aea31", null ],
     [ "SWIG_AcquirePtr", "plplotcmodulePYTHON__wrap_8c.html#aef3a3f2d1e735f02817fb26d61c8ee3d", null ],
-    [ "SWIG_AddCast", "plplotcmodulePYTHON__wrap_8c.html#ad69473581dbf2292673b61e56b35d893", null ],
+    [ "SWIG_AddCast", "plplotcmodulePYTHON__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f", null ],
     [ "SWIG_AddNewMask", "plplotcmodulePYTHON__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853", null ],
     [ "SWIG_AddTmpMask", "plplotcmodulePYTHON__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3", null ],
     [ "SWIG_addvarlink", "plplotcmodulePYTHON__wrap_8c.html#a49a542a5f7eb7a97541accc2cde0eed9", null ],
@@ -457,7 +458,7 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "SWIG_Python_ErrorType", "plplotcmodulePYTHON__wrap_8c.html#a538bcfd0ca57105e5dea178a302b7f89", null ],
     [ "SWIG_Python_ExceptionType", "plplotcmodulePYTHON__wrap_8c.html#a153f638306c56e8204656c79dce8cf2e", null ],
     [ "SWIG_Python_FixMethods", "plplotcmodulePYTHON__wrap_8c.html#addfee1cf672308dcdd030d489f804b5f", null ],
-    [ "SWIG_Python_GetModule", "plplotcmodulePYTHON__wrap_8c.html#af4931317560425925f44a6911adf2937", null ],
+    [ "SWIG_Python_GetModule", "plplotcmodulePYTHON__wrap_8c.html#ac85fea1d3188d4ee0517aa685d7bcde3", null ],
     [ "SWIG_Python_GetSwigThis", "plplotcmodulePYTHON__wrap_8c.html#a9160b127bcb2cef38bc6432c28b533c2", null ],
     [ "SWIG_Python_InitShadowInstance", "plplotcmodulePYTHON__wrap_8c.html#a77d3a8e01e24edf05e663b16f914e947", null ],
     [ "SWIG_Python_InstallConstants", "plplotcmodulePYTHON__wrap_8c.html#a26d87efa9c8072a9092913538ab5090c", null ],
@@ -482,7 +483,7 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "SWIG_TypeCheck", "plplotcmodulePYTHON__wrap_8c.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
     [ "SWIG_TypeCheckStruct", "plplotcmodulePYTHON__wrap_8c.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
     [ "SWIG_TypeClientData", "plplotcmodulePYTHON__wrap_8c.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
-    [ "SWIG_TypeCompare", "plplotcmodulePYTHON__wrap_8c.html#adc0e91b1eac793ed183ae989c62d33fb", null ],
+    [ "SWIG_TypeCmp", "plplotcmodulePYTHON__wrap_8c.html#a73131c439c907ed987c34da85b95a597", null ],
     [ "SWIG_TypeDynamicCast", "plplotcmodulePYTHON__wrap_8c.html#add8cb1a47628b36915ffa37d61452b1e", null ],
     [ "SWIG_TypeEquiv", "plplotcmodulePYTHON__wrap_8c.html#a23ecf039d651082ffc7582c4f50af780", null ],
     [ "SWIG_TypeName", "plplotcmodulePYTHON__wrap_8c.html#a68560e0bf641c9691704d6d05bac4358", null ],
@@ -517,10 +518,8 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "SwigPyObject_next", "plplotcmodulePYTHON__wrap_8c.html#a598fccf9f94eedbb7de3432be6f21bbe", null ],
     [ "SwigPyObject_oct", "plplotcmodulePYTHON__wrap_8c.html#ac19d035c2f2617b773fb7b3bea5a26b3", null ],
     [ "SwigPyObject_own", "plplotcmodulePYTHON__wrap_8c.html#a4a9e73ab689dd1de8182907b582194aa", null ],
-    [ "SwigPyObject_print", "plplotcmodulePYTHON__wrap_8c.html#aa66fca4982f15113938d9d4435079a87", null ],
     [ "SwigPyObject_repr", "plplotcmodulePYTHON__wrap_8c.html#a72e362e1099bd1b9a1d124c11a101a81", null ],
     [ "SwigPyObject_richcompare", "plplotcmodulePYTHON__wrap_8c.html#ae977913145e8a243228c8e90fbe5f2ca", null ],
-    [ "SwigPyObject_str", "plplotcmodulePYTHON__wrap_8c.html#ae699fa8a32a6f093e4b1cceba4b64a32", null ],
     [ "SwigPyObject_type", "plplotcmodulePYTHON__wrap_8c.html#a70268be3151a2c800628b561be2b3d6d", null ],
     [ "SwigPyObject_TypeOnce", "plplotcmodulePYTHON__wrap_8c.html#aea7d4126c1b77d06d8fcdf22619e9d77", null ],
     [ "SwigPyPacked_Check", "plplotcmodulePYTHON__wrap_8c.html#a6fea38d61cc362fd7b67a9fa56b33307", null ],
