@@ -1,10 +1,13 @@
 var wxwidgets_8h =
 [
+    [ "Font", "classFont.html", "classFont" ],
     [ "FontGrabber", "classFontGrabber.html", "classFontGrabber" ],
+    [ "PlDevice", "classPlDevice.html", "classPlDevice" ],
     [ "wxPLDevice", "classwxPLDevice.html", "classwxPLDevice" ],
     [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
     [ "Log_Debug", "wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b", null ],
     [ "Log_Verbose", "wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15", null ],
+    [ "operator==", "wxwidgets_8h.html#a1cc916f725de04817aeb2ae4aea4a14d", null ],
     [ "plD_bop_wxwidgets", "wxwidgets_8h.html#ad74eeaa5e1922ea1fab185786c172be0", null ],
     [ "plD_eop_wxwidgets", "wxwidgets_8h.html#a28455e43dfd0a1ed3c5f70f5954ee4e0", null ],
     [ "plD_esc_wxwidgets", "wxwidgets_8h.html#a2df717037e3fd4ca9084c6cd1fd72229", null ],
