@@ -30,28 +30,83 @@
 // some special wxWidgets headers
 #include <wx/wx.h>
 #include <wx/spinctrl.h>
-#ifdef wxUSE_GRAPHICS_CONTEXT
 #include <wx/dcgraph.h>
-#endif
 
 class wxPLplotFrame;
 
+// A font class which encapsulates the PlPlot font metrics and
+// a wxFont object. Importantly however the creation of the
+// wxFont is delayed until it is actually requested. This is
+// useful because on Linux in wxWidgets 3.0 creation of a wxFont
+// in a console mode application caused a crash.
+class Font
+{
+public:
+    Font();
+    Font( PLUNICODE fci, PLFLT size, bool underlined, bool createFontOnConstruction = false );
+    wxFont getWxFont();
+    PLUNICODE getFci() const { return m_fci; }
+    PLFLT getSize() const { return m_size; }
+    bool getUnderlined() const { return m_underlined; }
+private:
+    void createFont();
+    wxFont    m_font;
+    PLUNICODE m_fci;
+    PLFLT     m_size;
+    bool      m_underlined;
+    bool      m_hasFont;
+};
+//check equivalence of two fonts. Note that a font created
+//with the default constructor always campares false to any
+//other font and that whether the wxFont has been created is
+//not included in the test.
+bool operator ==( const Font &lhs, const Font &rhs );
+
 class FontGrabber
 {
 public:
     FontGrabber();
-    wxFont GetFont( PLUNICODE fci, PLFLT scaledFontSize, bool underlined );
+    Font GetFont( PLUNICODE fci, PLFLT scaledFontSize, bool underlined );
     bool lastWasCached( ){ return m_lastWasCached; }
 private:
-    wxFont    m_prevFont;
+    Font m_prevFont;
+    bool m_lastWasCached;
+};
+
+class PlDevice
+{
+public:
+    virtual ~PlDevice() {}
+    virtual void DrawLine( short x1a, short y1a, short x2a, short y2a ) {}
+    virtual void DrawPolyline( short *xa, short *ya, PLINT npts ){}
+    virtual void ClearBackground( PLStream* pls, PLINT x1 = -1, PLINT y1 = -1, PLINT x2 = -1, PLINT y2 = -1 ){}
+    virtual void FillPolygon( PLStream *pls ){}
+    virtual void SetWidth( PLStream *pls ){}
+    virtual void SetColor( PLStream *pls ){}
+    virtual void SetDC( PLStream *pls, wxDC* dc ){}
+    virtual void EndPage( PLStream* pls ){}
+    virtual void BeginPage( PLStream* pls ){}
+    virtual void SetSize( PLStream* pls, int width, int height ){}
+    virtual void FixAspectRatio( bool fix ){}
+    virtual void Locate( PLStream* pls, PLGraphicsIn *graphicsIn ){}
+    virtual void Flush( PLStream* pls ){}
+    virtual void PreDestructorTidy( PLStream *pls ){}
+
+    void drawText( PLStream* pls, EscText* args );
+private:
+    void DrawTextLine( PLUNICODE* ucs4, int ucs4Len, wxCoord xOrigin, wxCoord yOrigin, wxCoord x, wxCoord y, PLFLT *transform, PLFLT baseFontSize, bool drawText, PLINT &superscriptLevel, PLFLT &superscriptScale, PLFLT &superscriptOffset, bool &underlined, PLUNICODE &fci, unsigned char red, unsigned char green, unsigned char blue, PLFLT alpha, wxCoord &textWidth, wxCoord &textHeight, wxCoord &textDepth );
+    virtual void DrawTextSection( wxString section, wxCoord xOrigin, wxCoord yOrigin, wxCoord x, wxCoord y, PLFLT *transform, PLFLT scaledFontSize, bool drawText, bool underlined, PLUNICODE fci, unsigned char red, unsigned char green, unsigned char blue, PLFLT alpha, wxCoord &sectionWidth, wxCoord &sectionHeight, wxCoord &sectionDepth ) {}
+
+    PLUNICODE m_prevSymbol;
+    PLFLT     m_prevBaseFontSize;
+    PLINT     m_prevSuperscriptLevel;
     PLUNICODE m_prevFci;
-    PLFLT     m_prevScaledFontSize;
-    bool      m_prevUnderlined;
-    bool      m_lastWasCached;
+    wxCoord   m_prevSymbolWidth;
+    wxCoord   m_prevSymbolHeight;
 };
 
 // base device class
-class wxPLDevice
+class wxPLDevice : public PlDevice
 {
 public:
     wxPLDevice( PLStream *pls, char * mfo, PLINT text, PLINT hrshsym );
@@ -67,15 +122,13 @@ public:
     void EndPage( PLStream* pls );
     void BeginPage( PLStream* pls );
     void SetSize( PLStream* pls, int width, int height );
-    void ProcessString( PLStream* pls, EscText* args );
     void FixAspectRatio( bool fix );
     void Locate( PLStream* pls, PLGraphicsIn *graphicsIn );
     void Flush( PLStream* pls );
     void PreDestructorTidy( PLStream *pls );
 
 private:
-    void DrawTextLine( PLUNICODE* ucs4, int ucs4Len, PLFLT baseFontSize, bool drawText, PLINT &superscriptLevel, bool &underlined );
-    void DrawTextSection( char* utf8_string, PLFLT baseFontSize, PLFLT yOffset, bool underlined, bool drawText );
+    void DrawTextSection( wxString section, wxCoord xOrigin, wxCoord yOrigin, wxCoord x, wxCoord y, PLFLT *transform, PLFLT scaledFontSize, bool drawText, bool underlined, PLUNICODE fci, unsigned char red, unsigned char green, unsigned char blue, PLFLT alpha, wxCoord &sectionWidth, wxCoord &sectionHeight, wxCoord &sectionDepth );
     void TransmitBuffer( PLStream* pls, unsigned char transmissionType );
     void SetupMemoryMap();
     wxRegion GetClipRegion();
@@ -89,6 +142,11 @@ private:
     wxPen             m_pen;
     wxBrush           m_brush;
 
+    //A device context specifically for checking the size of text for use with
+    //the interactive viewer.
+    wxImage m_interactiveTextImage;
+    wxGCDC  *m_interactiveTextGcdc;
+
     //Size and Scale
     //As far as plplot is concerned the size of the window is SHRT_MAX by
     //SHRT_MAX which gives us the best resolution.
@@ -106,22 +164,23 @@ private:
     static const int m_max_string_length = 500;
     //bool m_underlined;
     FontGrabber      m_fontGrabber;
-    wxCoord          m_textWidth, m_textHeight, m_textDescent, m_textLeading;
-    PLUNICODE        m_fci;
+    //wxCoord          m_textWidth, m_textHeight, m_textDescent, m_textLeading;
+    //PLUNICODE        m_fci;
 
     //memory of previous single character string (likely plot point)
-    PLUNICODE m_prevSingleCharString;
-    PLINT     m_prevSingleCharStringWidth;
-    PLINT     m_prevSingleCharStringHeight;
+    wxChar m_prevSingleCharString;
+    PLINT  m_prevSingleCharStringWidth;
+    PLINT  m_prevSingleCharStringHeight;
+    PLINT  m_prevSingleCharStringDepth;
 
     //Text positioning related variables
-    wxCoord m_superscriptHeight;          //distance between superscript top and baseline
-    wxCoord m_subscriptDepth;             //distance between subscript base and baseline
-    PLFLT   m_lineSpacing;
+    //wxCoord m_superscriptHeight;          //distance between superscript top and baseline
+    //wxCoord m_subscriptDepth;             //distance between subscript base and baseline
+    PLFLT m_lineSpacing;
     //PLFLT   m_yOffset;
-    PLINT   m_posX;
-    PLINT   m_posY;
-    PLFLT   m_rotation;
+    //PLINT   m_posX;
+    //PLINT   m_posY;
+    //PLFLT   m_rotation;
 
     //variables for dealing with sending/receiving commands
     //via a memory map
