@@ -1,5 +1,3 @@
-## $Id: x20c.m 11391 2010-12-27 02:00:22Z airwin $
-##
 ##	plimage demo
 ##
 ##
@@ -17,14 +15,6 @@ function ix20c
   ydim = 220;
 
 
-  ## Bugs in plimage():
-  ##  -at high magnifications, the left and right edge are ragged, try
-  ##  ./x20c -dev xwin -wplt 0.3,0.3,0.6,0.6 -ori 0.5
-  ##   
-  ## Bugs in x20c.c:
-  ##  -if the window is resized after a selection is made on "lena", when
-  ##   making a new selection the old one will re-appear.
-
   ## Parse and process command line arguments
 
   ##  plMergeOpts(options, "x20c options", NULL);
@@ -37,14 +27,14 @@ function ix20c
   ## view image border pixels
   if (exist("dbg","var"))
     plenv(1., xdim, 1., ydim, 1, 1);  ## no plot box
-    
+
     ## build a one pixel square border, for diagnostics
     z = zeros(xdim,ydim);
     z(:,ydim) = 1;  ## right
     z(:,1) = 1;     ## left
     z(0,:) = 1;     ## top
     z(xdim,:) = 1;  ## bottom
-  
+
     pllab("...around a blue square."," ","A red border should appear...");
 
     pplimage(z, 1.0, xdim, 1.0, ydim, 0.0, 0.0, 1.0, xdim, 1.0, ydim);
@@ -67,7 +57,7 @@ function ix20c
 
     pllab("No, an amplitude clipped \"sombrero\"", "", "Saturn?");
     plptex(2., 2., 3., 4., 0., "Transparent image");
-    pplimage(z, 0., 2.*pi, 0, 3.*pi, 0.05, 1., 0., 2.*pi, 0, 3.*pi); 
+    pplimage(z, 0., 2.*pi, 0, 3.*pi, 0.05, 1., 0., 2.*pi, 0, 3.*pi);
 
     ## save the plot
     if (exist("f_name","var"))
@@ -75,11 +65,11 @@ function ix20c
     endif
   endif
 
-  ## read Lena image
-  if (exist("lena.pgm","file"))
-    [ret, img, width, height, num_col] = read_img("lena.pgm");
-  elseif (exist("../lena.pgm","file"))
-    [ret, img, width, height, num_col] = read_img("../lena.pgm");
+  ## read Chloe image
+  if (exist("Chloe.pgm","file"))
+    [ret, img, width, height, num_col] = read_img("Chloe.pgm");
+  elseif (exist("../Chloe.pgm","file"))
+    [ret, img, width, height, num_col] = read_img("../Chloe.pgm");
   else
     printf("Error: No such file\n");
     plend1;
@@ -89,15 +79,15 @@ function ix20c
   ## set gray colormap
   gray_cmap(num_col);
 
-  ## display Lena
+  ## display Chloe
   plenv(1., width, 1., height, 1, -1);
 
   if (!exist("nointeractive","var"))
-    pllab("Set and drag Button 1 to (re)set selection, Button 2 to finish."," ","Lena...");
+    pllab("Set and drag Button 1 to (re)set selection, Button 2 to finish."," ","Chloe...");
   else
-    pllab(""," ","Lena...");
+    pllab(""," ","Chloe...");
   endif
-  
+
   pplimage(img, 1.0, width, 1.0, height, 0.0, 0.0, 1.0, width, 1.0, height);
 
   ## selection/expansion demo
@@ -107,8 +97,8 @@ function ix20c
 	plend1;
 	return;
       endif
-  
-    ## 
+
+    ##
     ## I'm unable to continue, clearing the plot and advancing to the next
     ## one, without hiting the enter key, or pressing the button... help!
     ##
@@ -116,12 +106,12 @@ function ix20c
     ## xhairs (in GetCursorCmd()) solves some problems, but I still have
     ## to press the enter key or press Button-2 to go to next plot, even
     ## if a pladv() is not present!  Using plbop() solves the problem, but
-    ## it shouldn't be needed! 
+    ## it shouldn't be needed!
     ##
 
     ## plbop();
 
-    ## 
+    ##
     ## plspause(0), pladv(0), plspause(1), also works,
     ## but the above question remains.
     ## With this approach, the previous pause state is lost,
@@ -139,19 +129,19 @@ function ix20c
     ## zoom in selection
     plenv(xi, xe, ye, yi, 1, -1);
     pplimage(img, 1.0, width, 1.0, height, 0.0, 0.0, xi, xe, ye, yi);
-  endif  
+  endif
 
   ## Base the dynamic range on the image contents.
 
   img_max = max(max(img));
   img_min = min(min(img));
-      
+
   plcol0(2)
   plenv(0., width, 0., height, 1, -1)
   pllab("", "", "Reduced dynamic range image example")
   plimagefr(img, 0., width, 0., height, 0., 0., img_min + img_max * 0.25, img_max - img_max * 0.25)
 
-  ## Draw a distorted version of the original image, showing its 
+  ## Draw a distorted version of the original image, showing its
   ## full dynamic range.
   plenv(0., width, 0., height, 1, -1)
   pllab("", "", "Distorted image example")
@@ -219,11 +209,11 @@ endfunction
 
 
 ## save plot
-function save_plot(fname)   
+function save_plot(fname)
 
   cur_strm = plgstrm;   ## get current stream
   new_strm = plmkstrm;  ## create a new one
-    
+
   plsdev("psc"); ## new device type. Use a known existing driver
   plsfnam(fname); ## file name
 
@@ -242,18 +232,18 @@ function [ret, xi, xe, yi, ye] = get_clip
   sy = zeros(5,1);
   st = plxormod(1); ## enter xor mode to draw a selection rectangle
 
-  xi = 200.; xe = 330.;
-  yi = 280.; ye = 220.;
+  xi = 25.; xe = 130.;
+  yi = 235.; ye = 125.;
 
   keysym = 0;
 
   if (st)  ## driver has xormod capability, continue
-    while(1) 
+    while(1)
       st = plxormod(0);
       [retval, state, keysym, button, string, pX, pY, dX, dY, wX, wY, subwin]  = plGetCursor();
       st = plxormod(1);
 
-      if (button == 1) 
+      if (button == 1)
 	xi = wX; yi = wY;
 	if (start)
 	  plline(sx, sy); ## clear previous rectangle
@@ -264,8 +254,8 @@ function [ret, xi, xe, yi, ye] = get_clip
 	sx(1) = xi; sy(1) = yi;
 	sx(5) = xi; sy(5) = yi;
       endif
-      
-      if (state && 0x100) 
+
+      if (state && 0x100)
 	xe = wX; ye = wY;
 	if (start)
 	  plline(sx, sy); ## clear previous rectangle
@@ -279,19 +269,19 @@ function [ret, xi, xe, yi, ye] = get_clip
 	plline(sx, sy); ## draw new rectangle
       endif
 
-      ## Can't use PLK_Return here since PLK_ constant are not 
+      ## Can't use PLK_Return here since PLK_ constant are not
       ## currently defined for the octave bindings
       if (button == 3 || keysym == 0x0D || keysym == 'Q')
 	if (start)
 	  plline(sx, sy); ## clear previous rectangle
 	endif
 	break;
-      endif      
+      endif
     endwhile
     st = plxormod(0); ## leave xor mod
   endif
 
-  if (xe < xi) 
+  if (xe < xi)
     t=xi; xi=xe; xe=t;
   endif
 
@@ -307,7 +297,7 @@ function gray_cmap(num_col)
 
   r(1) = g(1) = b(1) = 0.0;
   r(2) = g(2) = b(2) = 1.0;
-    
+
   pos(1) = 0.0;
   pos(2) = 1.0;
 
