@@ -1,6 +1,4 @@
-## -*- coding: utf-8; -*-
-## $Id: x33c.m 12353 2013-06-02 20:07:07Z andrewross $
-##  Copyright (C) 2010 Alan W. Irwin
+##  Copyright (C) 2010-2014 Alan W. Irwin
 ##
 ##  Demonstrate most pllegend capability including unicode symbols.
 ##
@@ -29,7 +27,7 @@
 
 1;
 
-global position_options special_symbols colorbar_option_kinds colorbar_option_kind_labels colorbar_position_options colorbar_position_option_labels colorbar_label_options colorbar_label_option_labels colorbar_cap_options colorbar_cap_option_labels 
+global position_options special_symbols colorbar_option_kinds colorbar_option_kind_labels colorbar_position_options colorbar_position_option_labels colorbar_label_options colorbar_label_option_labels colorbar_cap_options colorbar_cap_option_labels
 global COLORBAR_KINDS COLORBAR_POSITIONS COLORBAR_LABELS COLORBAR_CAPS
 
 position_options = [
@@ -127,14 +125,14 @@ colorbar_cap_option_labels = {
 };
 
 function plcolorbar_example_page( kind_i, label_i, cap_i, cont_color, cont_width, values )
-  
+
     global COLORBAR_POSITIONS colorbar_option_kinds colorbar_option_kind_labels colorbar_position_options colorbar_position_option_labels colorbar_label_options colorbar_label_option_labels colorbar_cap_options colorbar_cap_option_labels
     global PL_POSITION_LEFT PL_POSITION_RIGHT PL_POSITION_BOTTOM PL_COLORBAR_BOUNDING_BOX PL_COLORBAR_BACKGROUND
 
     label_opts = zeros(1,1);
     ticks = zeros(1,1);
     sub_ticks = zeros(1,1);
-  
+
     n_values_array(1,:) = length(values);
     values_array(1,:)   = values;
 
@@ -147,7 +145,7 @@ function plcolorbar_example_page( kind_i, label_i, cap_i, cont_color, cont_width
     # Draw one colorbar relative to each side of the page
     for position_i = 1:COLORBAR_POSITIONS
         position = colorbar_position_options(position_i);
-        opt      = bitor( 
+        opt      = bitor(
             colorbar_option_kinds(kind_i), bitor(
             colorbar_label_options(label_i),
             colorbar_cap_options(cap_i) ) );
@@ -167,7 +165,7 @@ function plcolorbar_example_page( kind_i, label_i, cap_i, cont_color, cont_width
             x_length = 0.5;
             y_length = 0.05;
 	endif
-	  
+	
         # Set appropriate labelling options.
         if ( ifn )
             if ( cont_color == 0 || cont_width == 0. )
@@ -195,12 +193,12 @@ function plcolorbar_example_page( kind_i, label_i, cap_i, cont_color, cont_width
         plwind( 0.0, 1.0, 0.0, 1.0 );
         # Set interesting background colour.
         plscol0a( 15, 0, 0, 0, 0.20 );
-        [colorbar_width, colorbar_height] = plcolorbar( \
-            bitor(opt, bitor(PL_COLORBAR_BOUNDING_BOX, PL_COLORBAR_BACKGROUND)), \
-            position, x, y, x_length, y_length, \
-            15, 1, 1, low_cap_color, high_cap_color, \
-            cont_color, cont_width, label_opts, label, \
-            axis_opts, ticks, sub_ticks, \
+        [colorbar_width, colorbar_height] = plcolorbar(
+            bitor(opt, bitor(PL_COLORBAR_BOUNDING_BOX, PL_COLORBAR_BACKGROUND)),
+            position, x, y, x_length, y_length,
+            15, 1, 1, low_cap_color, high_cap_color,
+            cont_color, cont_width, label_opts, label,
+            axis_opts, ticks, sub_ticks,
             n_values_array, values_array );
 
         # Reset text and tick sizes
@@ -237,10 +235,10 @@ function ix33c()
   ## Parse and process command line arguments
 
   ## (void) plparseopts(&argc, argv, PL_PARSE_FULL);
-  
+
   ## Initialize plplot
   ## set global attributes for PLplot variables used in this function.
-  global PL_FCI_SANS PL_FCI_MONO PL_LEGEND_NONE PL_LEGEND_COLOR_BOX PL_LEGEND_LINE PL_LEGEND_SYMBOL PL_LEGEND_TEXT_LEFT PL_LEGEND_BACKGROUND PL_LEGEND_BOUNDING_BOX PL_LEGEND_ROW_MAJOR 
+  global PL_FCI_SANS PL_FCI_MONO PL_LEGEND_NONE PL_LEGEND_COLOR_BOX PL_LEGEND_LINE PL_LEGEND_SYMBOL PL_LEGEND_TEXT_LEFT PL_LEGEND_BACKGROUND PL_LEGEND_BOUNDING_BOX PL_LEGEND_ROW_MAJOR
   global PL_POSITION_LEFT PL_POSITION_RIGHT PL_POSITION_TOP PL_POSITION_BOTTOM PL_POSITION_INSIDE PL_POSITION_OUTSIDE PL_POSITION_SUBPAGE
   global PL_COLORBAR_IMAGE PL_COLORBAR_SHADE PL_COLORBAR_GRADIENT PL_COLORBAR_SHADE_LABEL
   global position_options special_symbols
@@ -298,7 +296,7 @@ function ix33c()
   line_styles(1) = 1;
   line_widths(1) = 1.;
   symbol_scales(1) = 1.;  symbol_numbers(1) = 4;
-  symbols(1,1:length("*")) = "*";
+  symbols(1,1:length("#(728)")) = "#(728)";
 
   ## Use monotype fonts so that all legends are the same size.
   plsfont( PL_FCI_MONO , -1, -1);
@@ -313,7 +311,7 @@ function ix33c()
     line_colors(1) = 1 + mod(k, 8);
     symbol_colors(1) = 1 + mod(k, 8);
 
-    [legend_width, legend_height] = \
+    [legend_width, legend_height] = ...
 	pllegend( opt, position, 0.05, 0.05,
 		 0.1, 15, 1, 1, 0, 0, opt_array, 1.0, 1.0, 2.0,
 		 1., text_colors, text,
@@ -375,7 +373,7 @@ function ix33c()
     line_widths(k+1) = 1.;
     symbol_scales(k+1) = 1.;
     symbol_numbers(k+1) = 2;
-    symbols(k+1,1:length("*")) = "*";
+    symbols(k+1,1:length("#(728)")) = "#(728)";
     string = sprintf("%2.2d",k);
     text(k+1,1:length(string)) = string;
     text_colors(k+1) = 1 + mod(k,8);
@@ -393,7 +391,7 @@ function ix33c()
   y = 0.1;
   nrow = 1;
   ncolumn = nlegend;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -407,7 +405,7 @@ function ix33c()
   y = 0.1;
   nrow = 1;
   ncolumn = nlegend;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -415,14 +413,14 @@ function ix33c()
 	       line_colors, line_styles, line_widths,
 	       symbol_colors, symbol_scales, symbol_numbers, symbols );
 
-    
+
   position = bitor(PL_POSITION_LEFT, PL_POSITION_OUTSIDE);
   opt = opt_base;
   x = 0.1;
   y = 0.;
   nrow = nlegend;
   ncolumn = 1;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -436,7 +434,7 @@ function ix33c()
   y = 0.;
   nrow = nlegend;
   ncolumn = 1;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -450,7 +448,7 @@ function ix33c()
   y = 0.;
   nrow = 6;
   ncolumn = 2;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -464,7 +462,7 @@ function ix33c()
   y = 0.;
   nrow = 6;
   ncolumn = 2;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -478,7 +476,7 @@ function ix33c()
   y = 0.;
   nrow = 3;
   ncolumn = 3;
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.05, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 2.0,
 	       1., text_colors, text,
@@ -553,7 +551,7 @@ function ix33c()
       line_widths(k+1) = 1.;
       symbol_scales(k+1) = 1.;
       symbol_numbers(k+1) = 2;
-      symbols(k+1,1:length("*")) = "*";
+      symbols(k+1,1:length("#(728)")) = "#(728)";
       string = sprintf("%2.2d",k);
       text(k+1,1:length(string)) = string;
       text_colors(k+1) = 1 + mod(k,8);
@@ -568,7 +566,7 @@ function ix33c()
     nrow = min(3, nlegend);
     ncolumn = 0;
 
-    [legend_width, legend_height] = \
+    [legend_width, legend_height] = ...
         pllegend( opt, position, x, y,
                  0.025, 15, 1, 1, nrow, ncolumn, opt_array, 1.0, 1.0, 1.5,
                  1., text_colors, text,
@@ -685,7 +683,7 @@ function ix33c()
 
   opt = opt_base;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text,
@@ -716,7 +714,7 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
 	       0., text_colors, text,
@@ -747,7 +745,7 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
 	       0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
 	       0., text_colors, text,
@@ -781,7 +779,7 @@ function ix33c()
   y += max_height;
   max_height = 0.;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text,
@@ -812,7 +810,7 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text,
@@ -843,7 +841,7 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text,
@@ -878,11 +876,11 @@ function ix33c()
   y += max_height;
   max_height = 0.;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text',
-	       [], [], [], [], 
+	       [], [], [], [],
                line_colors, line_styles, line_widths,
 	       [], [], [], [] );
   max_height = max(max_height, legend_height);
@@ -905,11 +903,11 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text',
-	       [], [], [], [], 
+	       [], [], [], [],
                line_colors, line_styles, line_widths,
 	       [], [], [], [] );
   max_height = max(max_height, legend_height);
@@ -933,19 +931,19 @@ function ix33c()
   opt = opt_base;
   x += legend_width;
   plscol0a( 15, 32, 32, 32, 0.70 );
-  [legend_width, legend_height] = \
+  [legend_width, legend_height] = ...
       pllegend( opt, position, x, y,
                0.1, 15, 1, 1, 0, 0, opt_array, 1.0, text_scale, 2.0,
                0., text_colors, text',
-	       [], [], [], [], 
+	       [], [], [], [],
                line_colors, line_styles, line_widths,
 	       [], [], [], [] );
   max_height = max(max_height, legend_height);
 
   # Color bar examples
-  values_small  = [ -1.0e-200, 1.0e-200 ];
-  values_uneven = [ -1.0e-200, 2.0e-200, 2.6e-200, 3.4e-200, 6.0e-200, 7.0e-200, 8.0e-200, 9.0e-200, 10.0e-200 ];
-  values_even   = [ -2.0e-200, -1.0e-200, 0.0e-200, 1.0e-200, 2.0e-200, 3.0e-200, 4.0e-200, 5.0e-200, 6.0e-200 ];
+  values_small  = [ -1.0e-20, 1.0e-20 ];
+  values_uneven = [ -1.0e-20, 2.0e-20, 2.6e-20, 3.4e-20, 6.0e-20, 7.0e-20, 8.0e-20, 9.0e-20, 10.0e-20 ];
+  values_even   = [ -2.0e-20, -1.0e-20, 0.0e-20, 1.0e-20, 2.0e-20, 3.0e-20, 4.0e-20, 5.0e-20, 6.0e-20 ];
 
   # Use unsaturated green background colour to contrast with black caps.
   plscolbg( 70, 185, 70 );
