@@ -3,15 +3,15 @@
 # Complete tests of PLplot for the three generic build types which
 # consist of shared+dynamic, shared+nondynamic, and
 # static+nondynamic.  These complete tests that are run for each build
-# type are (I) ctest, test_noninteractive, and test_interactive in
+# type are (I) test_noninteractive, test_interactive, and ctest in the
 # build tree; (II) traditional [Makefile+pkg-config]
 # test_noninteractive and test_interactive of installed examples; and
 # (III) CMake-based test_noninteractive and test_interactive of
 # installed examples.
 
 usage () {
-  local prog=`basename $0`
-  echo "Usage: $prog [OPTIONS]
+    local prog=`basename $0`
+    echo "Usage: $prog [OPTIONS]
 OPTIONS:
   The next option specifies the directory prefix which controls where
   all files produced by this script are located.
@@ -35,34 +35,39 @@ OPTIONS:
   option).
   [--do_clean_as_you_go (yes/no, defaults to yes)]
 
-  The next four control how the builds and tests are done.
+  The next six options control the tools used for the configurations, builds, and tests.
+  [--cmake_command (defaults to cmake)]
   [--generator_string (defaults to 'Unix Makefiles')]
-  [--ctest_command (defaults to 'ctest -j4')]
-  [--build_command (defaults to 'make -j4')]
-
-  The next four control what kind of builds and tests are done.
   [--cmake_added_options (defaults to none, but can be used to specify any
                           combination of white-space-separated cmake options
                           to, e.g., refine what parts of the PLplot software are
                           built and tested)]
+  [--build_command (defaults to 'make -j4')]
+  [--ctest_command (defaults to 'ctest -j4')]
+  [--do_submit_dashboard (yes/no defaults to no,  but if set to yes, the -D Experimental option
+                      will be added to the ctest command, i.e., a dashboard of the ctest results
+                      will be sent to <http://my.cdash.org/index.php?project=PLplot_git> where
+                      they will be publicly displayed.]
+
+  The next three options control which of the three principal PLplot configurations are tested.
   [--do_shared (yes/no, defaults to yes)]
   [--do_nondynamic (yes/no, defaults to yes)]
   [--do_static (yes/no, defaults to yes)]
 
   The next six control which of seven kinds of tests are done for
   each kind of build.
-  [--do_ctest (yes/no, defaults to yes)]
-  [--do_test_noninteractive (yes/no, defaults to yes)]
   [--do_test_interactive (yes/no, defaults to yes)]
+  [--do_test_noninteractive (yes/no, defaults to yes)]
+  [--do_ctest (yes/no, defaults to yes)]
   [--do_test_build_tree (yes/no, defaults to yes)]
   [--do_test_install_tree (yes/no, defaults to yes)]
   [--do_test_traditional_install_tree (yes/no, defaults to yes)]
 
   [--help] Show this message.
 "
-  if [ $1 -ne 0 ]; then
-      exit $1
-  fi
+    if [ $1 -ne 0 ]; then
+	exit $1
+    fi
 }
 
 collect_exit() {
@@ -90,7 +95,7 @@ collect_exit() {
 	tar rf $TARBALL $RELATIVE_ENVIRONMENT_LOG
     fi
 
-    for directory in shared nondynamic static ; do
+    for directory in shared/interactive shared/noninteractive nondynamic/interactive nondynamic/noninteractive static/interactive static/noninteractive ; do
 	if [ -d $directory/output_tree ] ; then
 	    tar rf $TARBALL $directory/output_tree
 	fi
@@ -102,7 +107,7 @@ collect_exit() {
 	fi
     done
 
-# Collect listing of every file generated by the script
+    # Collect listing of every file generated by the script
     find . -type f |xargs ls -l >| comprehensive_test_listing.out
     tar rf $TARBALL comprehensive_test_listing.out
 
@@ -112,18 +117,20 @@ collect_exit() {
 }
 
 echo_tee() {
-# N.B. only useful after this script defines $COMPREHENSIVE_TEST_LOG
-echo "$@" |tee -a $COMPREHENSIVE_TEST_LOG
+    # N.B. only useful after this script defines $COMPREHENSIVE_TEST_LOG
+    echo "$@" |tee -a $COMPREHENSIVE_TEST_LOG
 }
 
 comprehensive_test () {
     CMAKE_BUILD_TYPE_OPTION=$1
+    TEST_TYPE=$2
     echo_tee "
 Running comprehensive_test function with the following variables set:
 
 The variables below are key CMake options which determine the entire
 kind of build that will be tested.
 CMAKE_BUILD_TYPE_OPTION = $CMAKE_BUILD_TYPE_OPTION
+TEST_TYPE = ${TEST_TYPE}
 
 The location below is where all the important *.out files will be found.
 OUTPUT_TREE = $OUTPUT_TREE
@@ -138,26 +145,23 @@ The location below is the top-level directory of the build tree used
 for the CMake-based build and test of the installed examples.
 INSTALL_BUILD_TREE = $INSTALL_BUILD_TREE"
 
-    # Use OSTYPE variable to discover if it is a Windows platform or not.
-    if [[ "$OSTYPE" =~ ^cygwin ]]; then
-	ANY_WINDOWS_PLATFORM="true"
-    elif [[ "$OSTYPE" =~ ^msys ]]; then
-	ANY_WINDOWS_PLATFORM="true"
-    elif [[ "$OSTYPE" =~ ^win ]]; then
-	ANY_WINDOWS_PLATFORM="true"
-    else
-	ANY_WINDOWS_PLATFORM="false"
-    fi
     echo_tee "
 This variable specifies whether any windows platform has been detected
-ANY_WINDOWS_PLATFORM=$ANY_WINDOWS_PLATFORM
+ANY_WINDOWS_PLATFORM=$ANY_WINDOWS_PLATFORM"
 
+    echo_tee "
 Each of the steps in this comprehensive test may take a while...."
 
     PATH_SAVE=$PATH
     mkdir -p "$OUTPUT_TREE"
+    # Clean start with nonexistent install tree and empty build tree(s).
+    rm -rf "$INSTALL_TREE"
     rm -rf "$BUILD_TREE"
     mkdir -p "$BUILD_TREE"
+    if [ "$do_test_install_tree" = "yes" ] ; then
+	rm -rf "$INSTALL_BUILD_TREE"
+	mkdir -p "$INSTALL_BUILD_TREE"
+    fi
     cd "$BUILD_TREE"
     if [ "$do_ctest" = "yes" -o "$do_test_build_tree" = "yes" ] ; then
 	BUILD_TEST_OPTION="-DBUILD_TEST=ON"
@@ -172,20 +176,38 @@ Each of the steps in this comprehensive test may take a while...."
 	PATH=$BUILD_TREE/dll:$PATH_SAVE
     fi
 
-    # Process $cmake_added_options into $* to be used on the cmake command
+    # Process $cmake_added_options into $* to be used on the ${cmake_command} command
     # line below.
     set -- $cmake_added_options
-    echo_tee "cmake in the build tree"
-    cmake "-DCMAKE_INSTALL_PREFIX=$INSTALL_TREE" $BUILD_TEST_OPTION \
-	$* $CMAKE_BUILD_TYPE_OPTION -G "$generator_string" \
-        "$SOURCE_TREE" >& "$output"
+    echo_tee "${cmake_command} in the build tree"
+    ${cmake_command} "-DCMAKE_INSTALL_PREFIX=$INSTALL_TREE" $BUILD_TEST_OPTION \
+		     $* $CMAKE_BUILD_TYPE_OPTION -G "$generator_string" \
+		     "$DASHBOARD_LABEL_OPTION" "$SOURCE_TREE" >& "$output"
     cmake_rc=$?
     if [ "$cmake_rc" -ne 0 ] ; then
-	echo_tee "ERROR: cmake in the build tree failed"
+	echo_tee "ERROR: ${cmake_command} in the build tree failed"
 	collect_exit 1
     fi
 
-    if [ "$do_ctest" = "yes" ] ; then
+    # Prepare TEST_TYPE variables.
+    if [ "$TEST_TYPE" = "noninteractive" ] ; then
+	do_test_type=$do_test_noninteractive
+    else
+	do_test_type=$do_test_interactive
+    fi
+    if [ "$do_test_build_tree" = "yes" -a "$do_test_type" = "yes" ] ; then
+	output="${OUTPUT_TREE}/make_${TEST_TYPE}.out"
+	rm -f "$output"
+	echo_tee "$build_command VERBOSE=1 test_${TEST_TYPE} in the build tree"
+	$build_command VERBOSE=1 test_${TEST_TYPE} >& "$output"
+	make_test_type_rc=$?
+	if [ "$make_test_type_rc" -ne 0 ] ; then
+	    echo_tee "ERROR: $build_command VERBOSE=1 test_${TEST_TYPE} failed in the build tree"
+	    collect_exit 1
+	fi
+    fi
+
+    if [ "$do_ctest" = "yes" -a "$TEST_TYPE" = "noninteractive" ] ; then
 	output="$OUTPUT_TREE"/make.out
 	rm -f "$output"
 	echo_tee "$build_command VERBOSE=1 in the build tree"
@@ -194,8 +216,8 @@ Each of the steps in this comprehensive test may take a while...."
 	if [ "$make_rc" -eq 0 ] ; then
 	    output="$OUTPUT_TREE"/ctest.out
 	    rm -f "$output"
-	    echo_tee "$ctest_command --extra-verbose in the build tree"
-	    $ctest_command --extra-verbose >& "$output"
+	    echo_tee "$ctest_command --extra-verbose ${dashboard_option}in the build tree"
+	    $ctest_command --extra-verbose ${dashboard_option}>& "$output"
 	    ctest_rc=$?
 	    if [ "$ctest_rc" -eq 0 ] ; then
 		if [ "$do_clean_as_you_go" = "yes" ] ; then
@@ -210,7 +232,7 @@ Each of the steps in this comprehensive test may take a while...."
 		    fi
 		fi
 	    else
-		echo_tee "ERROR: $ctest_command --extra-verbose failed in the build tree"
+		echo_tee "ERROR: $ctest_command --extra-verbose ${dashboard_option}failed in the build tree"
 		collect_exit 1
 	    fi
 	else
@@ -219,20 +241,7 @@ Each of the steps in this comprehensive test may take a while...."
 	fi
     fi
 
-    if [ "$do_test_build_tree" = "yes" -a  "$do_test_noninteractive" = "yes" ] ; then
-	output="$OUTPUT_TREE"/make_noninteractive.out
-	rm -f "$output"
-	echo_tee "$build_command VERBOSE=1 test_noninteractive in the build tree"
-	$build_command VERBOSE=1 test_noninteractive >& "$output"
-	make_test_noninteractive_rc=$?
-	if [ "$make_test_noninteractive_rc" -ne 0 ] ; then
-	    echo_tee "ERROR: $build_command VERBOSE=1 test_noninteractive failed in the build tree"
-	    collect_exit 1
-	fi
-    fi
-
-    if [ "$do_test_install_tree" = "yes" -o \
-	"$do_test_traditional_install_tree" = "yes" ] ; then
+    if [ "$do_test_install_tree" = "yes" -o "$do_test_traditional_install_tree" = "yes" ] ; then
 	rm -rf "$INSTALL_TREE"
 	output="$OUTPUT_TREE"/make_install.out
 	rm -f "$output"
@@ -243,12 +252,42 @@ Each of the steps in this comprehensive test may take a while...."
 	    echo_tee "ERROR: $build_command VERBOSE=1 install failed in the build tree"
 	    collect_exit 1
 	fi
+
+	if [[ "$OSTYPE" =~ ^linux && "$CMAKE_BUILD_TYPE_OPTION" != "-DBUILD_SHARED_LIBS=OFF" ]]; then
+	    # The above install and the above "if" assure there are
+	    # *.so files in both the build and install trees for the
+	    # linux case that can be analyzed with ldd -r.
+	    # N.B. we deliberately drop dllplplot_stubs.so from the
+	    # reports because there is no known way to set the rpath
+	    # for that ocamlmklib-generated shared object at the
+	    # moment.  See plplot-devel mailing discusion on
+	    # 2016-12-09 with the subject line
+	    # "Setting rpath for dllplplot_stubs.so appears not to be possible".
+	    output="$OUTPUT_TREE"/build_tree_ldd.out
+	    rm -f "$output"
+	    echo_tee "find \"$BUILD_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' |xargs ldd -r in the build tree just after the install for TEST_TYPE = ${TEST_TYPE})"
+	    find "$BUILD_TREE" -name "*.so" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r >& "$output"
+	    ldd_rc=$?
+	    if [ "$ldd_rc" -ne 0 ] ; then
+		echo_tee "ERROR: find \"$BUILD_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r failed in the build tree"
+		collect_exit 1
+	    fi
+	    output="$OUTPUT_TREE"/install_tree_ldd.out
+	    rm -f "$output"
+	    echo_tee "find \"$INSTALL_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r in the install tree just after the install for TEST_TYPE = ${TEST_TYPE})"
+	    find "$INSTALL_TREE" -name "*.so" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r >& "$output"
+	    ldd_rc=$?
+	    if [ "$ldd_rc" -ne 0 ] ; then
+		echo_tee "ERROR: find \"$INSTALL_TREE\" -name \"*.so\" | grep -v 'dllplplot_stubs\.so' | xargs ldd -r failed in the install tree"
+		collect_exit 1
+	    fi
+	fi
     fi
 
     if [ "$do_clean_as_you_go" = "yes" ] ; then
 	output="$OUTPUT_TREE"/clean.out
 	rm -f "$output"
-	echo_tee "$build_command VERBOSE=1 clean in the build tree (since we are done with it at least for the non-interactive test case)"
+	echo_tee "$build_command VERBOSE=1 clean in the build tree (since we are done with it for TEST_TYPE = ${TEST_TYPE})"
 	$build_command VERBOSE=1 clean >& "$output"
 	make_rc=$?
 	if [ "$make_rc" -ne 0 ] ; then
@@ -257,8 +296,7 @@ Each of the steps in this comprehensive test may take a while...."
 	fi
     fi
 
-    if [ "$do_test_install_tree" = "yes" -o \
-	"$do_test_traditional_install_tree" = "yes" ] ; then
+    if [ "$do_test_install_tree" = "yes" -o "$do_test_traditional_install_tree" = "yes" ] ; then
 	echo_tee "Prepend $INSTALL_TREE/bin to the original PATH"
 	PATH="$INSTALL_TREE/bin":$PATH_SAVE
 
@@ -273,32 +311,30 @@ Each of the steps in this comprehensive test may take a while...."
 	fi
 
 	if [ "$do_test_install_tree" = "yes" ] ; then
-	    rm -rf "$INSTALL_BUILD_TREE"
-	    mkdir -p "$INSTALL_BUILD_TREE"
 	    cd "$INSTALL_BUILD_TREE"
 	    output="$OUTPUT_TREE"/installed_cmake.out
 	    rm -f "$output"
-	    echo_tee "cmake in the installed examples build tree"
-	    cmake -G "$generator_string" "$INSTALL_TREE"/share/plplot[0-9].[0-9]*.[0-9]*/examples >& "$output"
+	    echo_tee "${cmake_command} in the installed examples build tree"
+	    ${cmake_command} -G "$generator_string" "$INSTALL_TREE"/share/plplot[0-9].[0-9]*.[0-9]*/examples >& "$output"
 	    cmake_rc=$?
 	    if [ "$cmake_rc" -ne 0 ] ; then
-		echo_tee "ERROR: cmake in the installed examples build tree failed"
+		echo_tee "ERROR: ${cmake_command} in the installed examples build tree failed"
 		collect_exit 1
 	    fi
-	    if [ "$do_test_noninteractive" = "yes" ] ; then
-		output="$OUTPUT_TREE"/installed_make_noninteractive.out
+	    if [ "$do_test_type" = "yes" ] ; then
+		output="${OUTPUT_TREE}/installed_make_${TEST_TYPE}.out"
 		rm -f "$output"
-		echo_tee "$build_command VERBOSE=1 test_noninteractive in the installed examples build tree"
-		$build_command VERBOSE=1 test_noninteractive >& "$output"
+		echo_tee "$build_command VERBOSE=1 test_${TEST_TYPE} in the installed examples build tree"
+		$build_command VERBOSE=1 test_${TEST_TYPE} >& "$output"
 		make_rc=$?
 		if [ "$make_rc" -ne 0 ] ; then
-		    echo_tee "ERROR: $build_command VERBOSE=1 test_noninteractive failed in the installed examples build tree"
+		    echo_tee "ERROR: $build_command VERBOSE=1 test_${TEST_TYPE} failed in the installed examples build tree"
 		    collect_exit 1
 		fi
 		if [ "$do_clean_as_you_go" = "yes" ] ; then
 		    output="$OUTPUT_TREE"/installed_clean.out
 		    rm -f "$output"
-		    echo_tee "$build_command VERBOSE=1 clean in the installed examples build tree (since we are done with it at least for the non-interactive test case)"
+		    echo_tee "$build_command VERBOSE=1 clean in the installed examples build tree (since we are done with it for TEST_TYPE = ${TEST_TYPE})"
 		    $build_command VERBOSE=1 clean >& "$output"
 		    make_rc=$?
 		    if [ "$make_rc" -ne 0 ] ; then
@@ -309,21 +345,21 @@ Each of the steps in this comprehensive test may take a while...."
 	    fi
 	fi
 
-	if [ "$do_test_traditional_install_tree" = "yes" -a "$do_test_noninteractive" = "yes" ] ; then
+	if [ "$do_test_traditional_install_tree" = "yes" -a "$do_test_type" = "yes" ] ; then
 	    cd "$INSTALL_TREE"/share/plplot[0-9].[0-9]*.[0-9]*/examples
-	    output="$OUTPUT_TREE"/traditional_make_noninteractive.out
+	    output="${OUTPUT_TREE}/traditional_make_${TEST_TYPE}.out"
 	    rm -f "$output"
-	    echo_tee "Traditional $traditional_build_command test_noninteractive in the installed examples tree"
-	    $traditional_build_command test_noninteractive >& "$output"
+	    echo_tee "Traditional $traditional_build_command test_${TEST_TYPE} in the installed examples tree"
+	    $traditional_build_command test_${TEST_TYPE} >& "$output"
 	    make_rc=$?
 	    if [ "$make_rc" -ne 0 ] ; then
-		echo_tee "ERROR: Traditional $traditional_build_command test_noninteractive failed in the installed examples tree"
+		echo_tee "ERROR: Traditional $traditional_build_command test_${TEST_TYPE} failed in the installed examples tree"
 		collect_exit 1
 	    fi
 	    if [ "$do_clean_as_you_go" = "yes" ] ; then
 		output="$OUTPUT_TREE"/traditional_clean.out
 		rm -f "$output"
-		echo_tee "Traditional $traditional_build_command clean in the installed examples tree (since we are done with it at least for the non-interactive test case)"
+		echo_tee "Traditional $traditional_build_command clean in the installed examples tree (since we are done with it for TEST_TYPE = ${TEST_TYPE})"
 		$traditional_build_command clean >& "$output"
 		make_rc=$?
 		if [ "$make_rc" -ne 0 ] ; then
@@ -333,97 +369,7 @@ Each of the steps in this comprehensive test may take a while...."
 	    fi
 	fi
     fi
-
-    if [ "$do_test_interactive" = "yes" ] ; then
-	if [ "$do_test_build_tree" = "yes" ] ; then
-	    if [ "$CMAKE_BUILD_TYPE_OPTION" != "-DBUILD_SHARED_LIBS=OFF" -a "$ANY_WINDOWS_PLATFORM" = "true" ] ; then
-		echo_tee "Prepend $BUILD_TREE/dll to the original PATH"
-		PATH=$BUILD_TREE/dll:$PATH_SAVE
-	    fi
-
-	    cd "$BUILD_TREE"
-	    output="$OUTPUT_TREE"/make_interactive.out
-	    rm -f "$output"
-	    echo_tee "$build_command VERBOSE=1 test_interactive in the build tree"
-	    $build_command VERBOSE=1 test_interactive >& "$output"
-	    make_rc=$?
-	    if [ "$make_rc" -ne 0 ] ; then
-		echo_tee "ERROR: $build_command VERBOSE=1 test_interactive failed in the build tree"
-		collect_exit 1
-	    fi
-	fi
-	if [ "$do_clean_as_you_go" = "yes" ] ; then
-	    output="$OUTPUT_TREE"/clean.out
-	    rm -f "$output"
-	    echo_tee "$build_command VERBOSE=1 clean in the build tree (since we are done with it)"
-	    $build_command VERBOSE=1 clean >& "$output"
-	    make_rc=$?
-	    if [ "$make_rc" -ne 0 ] ; then
-		echo_tee "ERROR: $build_command VERBOSE=1 clean failed in the build tree"
-		collect_exit 1
-	    fi
-	fi
-	echo_tee "Prepend $INSTALL_TREE/bin to the original PATH"
-	PATH="$INSTALL_TREE/bin":$PATH_SAVE
-
-	if [ "$CMAKE_BUILD_TYPE_OPTION" = "-DBUILD_SHARED_LIBS=ON" -a "$ANY_WINDOWS_PLATFORM" = "true" ] ; then
-	    # Use this logic to be as version-independent as possible.
-	    current_dir=$(pwd)
-	    # Wild cards must not be inside quotes.
-	    cd "$INSTALL_TREE"/lib/plplot[0-9].[0-9]*.[0-9]*/drivers*
-	    echo_tee "Prepend $(pwd) to the current PATH"
-	    PATH="$(pwd):$PATH"
-	    cd $current_dir
-	fi
-
-	if [ "$do_test_install_tree" = "yes" ] ; then
-	    cd "$INSTALL_BUILD_TREE"
-	    output="$OUTPUT_TREE"/installed_make_interactive.out
-	    rm -f "$output"
-	    echo_tee "$build_command VERBOSE=1 test_interactive in the installed examples build tree"
-	    $build_command VERBOSE=1 test_interactive >& "$output"
-	    make_rc=$?
-	    if [ "$make_rc" -ne 0 ] ; then
-		echo_tee "ERROR: $build_command VERBOSE=1 test_interactive failed in the installed examples build tree"
-		collect_exit 1
-	    fi
-	    if [ "$do_clean_as_you_go" = "yes" ] ; then
-		output="$OUTPUT_TREE"/installed_clean.out
-		rm -f "$output"
-		echo_tee "$build_command VERBOSE=1 clean in the installed examples build tree (since we are done with it)"
-		$build_command VERBOSE=1 clean >& "$output"
-		make_rc=$?
-		if [ "$make_rc" -ne 0 ] ; then
-		    echo_tee "ERROR: $build_command VERBOSE=1 clean failed in the installed examples build tree"
-		    collect_exit 1
-		fi
-	    fi
-	fi
-	if [ "$do_test_traditional_install_tree" = "yes" ] ; then
-	    cd "$INSTALL_TREE"/share/plplot[0-9].[0-9]*.[0-9]*/examples
-	    output="$OUTPUT_TREE"/traditional_make_interactive.out
-	    rm -f "$output"
-	    echo_tee "Traditional $traditional_build_command test_interactive in the installed examples tree"
-	    $traditional_build_command test_interactive >& "$output"
-	    make_rc=$?
-	    if [ "$make_rc" -ne 0 ] ; then
-		echo_tee "ERROR: Traditional $traditional_build_command test_interactive failed in the installed examples tree"
-		collect_exit 1
-	    fi
-	    if [ "$do_clean_as_you_go" = "yes" ] ; then
-		output="$OUTPUT_TREE"/traditional_clean.out
-		rm -f "$output"
-		echo_tee "Traditional $traditional_build_command clean in the installed examples tree (since we are done with it)"
-		$traditional_build_command clean >& "$output"
-		make_rc=$?
-		if [ "$make_rc" -ne 0 ] ; then
-		    echo_tee "ERROR: Traditional $traditional_build_command clean failed in the installed examples tree"
-		    collect_exit 1
-		fi
-	    fi
-	fi
-    fi
-    echo_tee "Restore PATH to the original PATH"
+    echo_tee "Restore PATH to its original form"
     PATH=$PATH_SAVE
 }
 
@@ -448,20 +394,23 @@ SOURCE_TREE="$(dirname ${SCRIPT_PATH})"
 prefix="${SOURCE_TREE}/../comprehensive_test_disposeable"
 
 do_clean_first=yes
+
 do_clean_as_you_go=yes
 
+cmake_command="cmake"
 generator_string="Unix Makefiles"
-ctest_command="ctest -j4"
-build_command="make -j4"
-
 cmake_added_options=
+build_command="make -j4"
+ctest_command="ctest -j4"
+do_submit_dashboard=no
+
 do_shared=yes
 do_nondynamic=yes
 do_static=yes
 
-do_ctest=yes
-do_test_noninteractive=yes
 do_test_interactive=yes
+do_test_noninteractive=yes
+do_ctest=yes
 do_test_build_tree=yes
 do_test_install_tree=yes
 do_test_traditional_install_tree=yes
@@ -499,22 +448,38 @@ while test $# -gt 0; do
 		    ;;
 	    esac
 	    ;;
+        --cmake_command)
+	    cmake_command=$2
+	    shift
+	    ;;
         --generator_string)
 	    generator_string=$2
 	    shift
 	    ;;
-        --ctest_command)
-	    ctest_command=$2
-	    shift
-	    ;;
-        --build_command)
-	    build_command=$2
-	    shift
-	    ;;
         --cmake_added_options)
 	    cmake_added_options=$2
             shift
             ;;
+        --build_command)
+	    build_command=$2
+	    shift
+	    ;;
+        --ctest_command)
+	    ctest_command=$2
+	    shift
+	    ;;
+	--do_submit_dashboard)
+	    case $2 in
+		yes|no)
+		    do_submit_dashboard=$2
+		    shift
+		    ;;
+		
+		*)
+		    usage 1 1>&2
+		    ;;
+	    esac
+	    ;;
 	--do_shared)
 	    case $2 in
 		yes|no)
@@ -549,10 +514,10 @@ while test $# -gt 0; do
 		    ;;
 	    esac
 	    ;;
-	--do_ctest)
+	--do_test_interactive)
 	    case $2 in
 		yes|no)
-		    do_ctest=$2
+		    do_test_interactive=$2
 		    shift
 		    ;;
 		*)
@@ -571,10 +536,10 @@ while test $# -gt 0; do
 		    ;;
 	    esac
 	    ;;
-	--do_test_interactive)
+	--do_ctest)
 	    case $2 in
 		yes|no)
-		    do_test_interactive=$2
+		    do_ctest=$2
 		    shift
 		    ;;
 		*)
@@ -659,7 +624,7 @@ hash git
 hash_rc=$?
 
 if [ "$hash_rc" -ne 0 ] ; then
-    echo_tee "WARNING: git not on PATH so cannot determine if SOURCE_TREE = 
+    echo_tee "WARNING: git not on PATH so cannot determine if SOURCE_TREE =
 $SOURCE_TREE is a git repository or not"
 else
     cd $SOURCE_TREE
@@ -701,22 +666,25 @@ echo_tee "Summary of options used for these tests
 
 --prefix \"$prefix\"
 
+--do_clean_first $do_clean_first
+
 --do_clean_as_you_go $do_clean_as_you_go
 
---generator_string \"$generator_string"\"
-echo_tee "
---ctest_command \"$ctest_command\"
---build_command \"$build_command\"
---traditional_build_command \"$traditional_build_command\"
-
+--cmake_command \"$cmake_command\"
+--generator_string \"$generator_string\"
 --cmake_added_options \"$cmake_added_options\"
+--build_command \"$build_command\"
+  (derived) traditional_build_command \"$traditional_build_command\"
+--ctest_command \"$ctest_command\"
+--do_submit_dashboard $do_submit_dashboard
+
 --do_shared $do_shared
 --do_nondynamic $do_nondynamic
 --do_static $do_static
 
---do_ctest $do_ctest
---do_test_noninteractive $do_test_noninteractive
 --do_test_interactive $do_test_interactive
+--do_test_noninteractive $do_test_noninteractive
+--do_ctest $do_ctest
 --do_test_build_tree $do_test_build_tree
 --do_test_install_tree $do_test_install_tree
 --do_test_traditional_install_tree $do_test_traditional_install_tree
@@ -727,8 +695,19 @@ the high-water mark of disk usage can still be as high as 4GB so be
 sure you have enough free disk space to run this test!
 "
 
+# N.B. dashboard_option must always have a trailing blank
+if [ "$do_submit_dashboard" = "yes" ] ; then
+    echo_tee "WARNING: Because you have specified \"do_submit_dashboard $do_submit_dashboard\" above, all details concerning each
+of your ctest results will be published at <http://my.cdash.org/index.php?project=PLplot_git>
+"
+    dashboard_option="-D Experimental "
+else
+    dashboard_option=" "
+fi
+
+
 if [ "$do_clean_first" = "yes" ] ; then
-    echo_tee "WARNING: The shared, nondynamic, and static subdirectory trees of 
+    echo_tee "WARNING: The shared, nondynamic, and static subdirectory trees of
 $prefix
 are about to be removed!
 "
@@ -753,45 +732,95 @@ if [ "$do_clean_first" = "yes" ] ; then
     rm -rf $prefix/shared $prefix/nondynamic $prefix/static
 fi
 
+# Discover if it is a Windows platform or not.
+if [[ "$OSTYPE" =~ ^cygwin ]]; then
+    ANY_WINDOWS_PLATFORM="true"
+elif [[ "$OSTYPE" =~ ^msys ]]; then
+    ANY_WINDOWS_PLATFORM="true"
+elif [[ "$OSTYPE" =~ ^win ]]; then
+    ANY_WINDOWS_PLATFORM="true"
+else
+    ANY_WINDOWS_PLATFORM="false"
+fi
+
+# Discover if it is a Mac OS X platform or not.
+if [[ "$OSTYPE" =~ ^darwin ]]; then
+    ANY_MAC_OSX_PLATFORM="true"
+else
+    ANY_MAC_OSX_PLATFORM="false"
+fi
+
 hash printenv
 hash_rc=$?
 if [ "$hash_rc" -ne 0 ] ; then
-    echo_tee "WARNING: printenv not on PATH so not collecting environment variables in $ENVIRONMENT_LOG"
-    rm -f $ENVIRONMENT_LOG
+    HAS_PRINTENV=false
 else
+    HAS_PRINTENV=true
+fi
+
 # Collect selected important environment variable results prior to testing.
-    echo "PATH=$PATH" >| $ENVIRONMENT_LOG
-    echo "CC=$CC" >> $ENVIRONMENT_LOG
-    echo "CXX=$CXX" >> $ENVIRONMENT_LOG
-    echo "FC=$FC" >> $ENVIRONMENT_LOG
-    printenv |grep -E 'CMAKE_.*PATH|FLAGS|PKG_CONFIG_PATH|LD_LIBRARY_PATH' >> $ENVIRONMENT_LOG
+rm -f $ENVIRONMENT_LOG
+echo "PATH=$PATH" > $ENVIRONMENT_LOG
+echo "CC=$CC" >> $ENVIRONMENT_LOG
+echo "CXX=$CXX" >> $ENVIRONMENT_LOG
+echo "FC=$FC" >> $ENVIRONMENT_LOG
+if [ "$HAS_PRINTENV" = "false" ] ; then
+    echo_tee "WARNING: printenv not on PATH so cannot collect certain important environment variables in $ENVIRONMENT_LOG"
+else
+    printenv |grep -E '^CMAKE_.*PATH=|^.*FLAGS=|^PKG_CONFIG_PATH=|^LD_LIBRARY_PATH=|PLPLOT' >> $ENVIRONMENT_LOG
 fi
 
-# Shared + dynamic
-if [ "$do_shared" = "yes" ] ; then
-    OUTPUT_TREE="$prefix/shared/output_tree"
-    BUILD_TREE="$prefix/shared/build_tree"
-    INSTALL_TREE="$prefix/shared/install_tree"
-    INSTALL_BUILD_TREE="$prefix/shared/install_build_tree"
-    comprehensive_test "-DBUILD_SHARED_LIBS=ON"
+test_types=
+if [ "$do_test_interactive" = "yes" ] ; then
+    test_types="${test_types} interactive"
 fi
 
-# Shared + nondynamic
-if [ "$do_nondynamic" = "yes" ] ; then
-    OUTPUT_TREE="$prefix/nondynamic/output_tree"
-    BUILD_TREE="$prefix/nondynamic/build_tree"
-    INSTALL_TREE="$prefix/nondynamic/install_tree"
-    INSTALL_BUILD_TREE="$prefix/nondynamic/install_build_tree"
-    comprehensive_test "-DBUILD_SHARED_LIBS=ON -DENABLE_DYNDRIVERS=OFF"
+if [ "$do_test_noninteractive" = "yes" -o "$do_ctest" = "yes" ] ; then
+    test_types="${test_types} noninteractive"
 fi
 
-if [ "$do_static" = "yes" ] ; then
-# Static + nondynamic
-    OUTPUT_TREE="$prefix/static/output_tree"
-    BUILD_TREE="$prefix/static/build_tree"
-    INSTALL_TREE="$prefix/static/install_tree"
-    INSTALL_BUILD_TREE="$prefix/static/install_build_tree"
-    comprehensive_test "-DBUILD_SHARED_LIBS=OFF"
-fi
+for test_type in ${test_types} ; do
+    # Shared + dynamic
+    if [ "$do_shared" = "yes" ] ; then
+	OUTPUT_TREE="$prefix/shared/$test_type/output_tree"
+	BUILD_TREE="$prefix/shared/$test_type/build_tree"
+	INSTALL_TREE="$prefix/shared/$test_type/install_tree"
+	INSTALL_BUILD_TREE="$prefix/shared/$test_type/install_build_tree"
+	if [ "$do_submit_dashboard" = "yes" ] ; then
+	    DASHBOARD_LABEL_OPTION="-DPLPLOT_BUILDNAME_SUFFIX:STRING=-(shared library + dynamic devices)"
+	else
+	    DASHBOARD_LABEL_OPTION=
+	fi
+	comprehensive_test "-DBUILD_SHARED_LIBS=ON" $test_type
+    fi
+
+    # Shared + nondynamic
+    if [ "$do_nondynamic" = "yes" ] ; then
+	OUTPUT_TREE="$prefix/nondynamic/$test_type/output_tree"
+	BUILD_TREE="$prefix/nondynamic/$test_type/build_tree"
+	INSTALL_TREE="$prefix/nondynamic/$test_type/install_tree"
+	INSTALL_BUILD_TREE="$prefix/nondynamic/$test_type/install_build_tree"
+	if [ "$do_submit_dashboard" = "yes" ] ; then
+	    DASHBOARD_LABEL_OPTION="-DPLPLOT_BUILDNAME_SUFFIX:STRING=-(shared library + nondynamic devices)"
+	else
+	    DASHBOARD_LABEL_OPTION=
+	fi
+	comprehensive_test "-DBUILD_SHARED_LIBS=ON -DENABLE_DYNDRIVERS=OFF" $test_type
+    fi
+
+    # Static + nondynamic
+    if [ "$do_static" = "yes" ] ; then
+	OUTPUT_TREE="$prefix/static/$test_type/output_tree"
+	BUILD_TREE="$prefix/static/$test_type/build_tree"
+	INSTALL_TREE="$prefix/static/$test_type/install_tree"
+	INSTALL_BUILD_TREE="$prefix/static/$test_type/install_build_tree"
+	if [ "$do_submit_dashboard" = "yes" ] ; then
+	    DASHBOARD_LABEL_OPTION="-DPLPLOT_BUILDNAME_SUFFIX:STRING=-(static library + nondynamic devices)"
+	else
+	    DASHBOARD_LABEL_OPTION=
+	fi
+	comprehensive_test "-DBUILD_SHARED_LIBS=OFF" $test_type
+    fi
+done
 
 collect_exit 0
