@@ -31,22 +31,18 @@
 // Static function prototypes.
 
 static void
-plcntr( PLFLT ( *plf2eval )( PLINT, PLINT, PLPointer ),
-        PLPointer plf2eval_data,
+plcntr( PLF2EVAL_callback plf2eval, PLPointer plf2eval_data,
         PLINT nx, PLINT ny, PLINT kx, PLINT lx,
         PLINT ky, PLINT ly, PLFLT flev, PLINT **ipts,
-        void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-        PLPointer pltr_data );
+        PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 static void
-pldrawcn( PLFLT ( *plf2eval )( PLINT, PLINT, PLPointer ),
-          PLPointer plf2eval_data,
+pldrawcn( PLF2EVAL_callback plf2eval, PLPointer plf2eval_data,
           PLINT nx, PLINT ny, PLINT kx, PLINT lx,
           PLINT ky, PLINT ly, PLFLT flev, char *flabel, PLINT kcol, PLINT krow,
           PLFLT lastx, PLFLT lasty, PLINT startedge,
           PLINT **ipts, PLFLT *distance, PLINT *lastindex,
-          void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-          PLPointer pltr_data );
+          PLTRANSFORM_callback pltr, PLPointer pltr_data );
 
 static void
 plfloatlabel( PLFLT value, char *string, PLINT len );
@@ -487,10 +483,9 @@ plf2evalr( PLINT ix, PLINT iy, PLPointer plf2eval_data )
 //--------------------------------------------------------------------------
 
 void
-cont_store( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
-            PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
-            void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-            PLPointer pltr_data,
+cont_store( PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+            PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel,
+            PLTRANSFORM_callback pltr, PLPointer pltr_data,
             CONT_LEVEL **contour )
 {
     cont3d = 1;
@@ -510,18 +505,10 @@ cont_store( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
 //--------------------------------------------------------------------------
 
 void
-c_plcont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
-          PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
-          void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-          PLPointer pltr_data )
+c_plcont( PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
+          PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel,
+          PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
-    if ( pltr == NULL )
-    {
-        // If pltr is undefined, abort with an error.
-        plabort( "plcont: The pltr callback must be defined" );
-        return;
-    }
-
     plfcont( plf2eval1, (PLPointer) f,
         nx, ny, kx, lx, ky, ly, clevel, nlevel,
         pltr, pltr_data );
@@ -545,15 +532,20 @@ c_plcont( const PLFLT * const *f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
 //--------------------------------------------------------------------------
 
 void
-plfcont( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-         PLPointer f2eval_data,
+plfcont( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
          PLINT nx, PLINT ny, PLINT kx, PLINT lx,
-         PLINT ky, PLINT ly, const PLFLT *clevel, PLINT nlevel,
-         void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-         PLPointer pltr_data )
+         PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel,
+         PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLINT i, **ipts;
 
+    if ( pltr == NULL )
+    {
+        // If pltr is undefined, abort with an error.
+        plabort( "plfcont: The pltr callback must be defined" );
+        return;
+    }
+
     if ( kx < 1 || kx >= lx )
     {
         plabort( "plfcont: indices must satisfy  1 <= kx <= lx <= nx" );
@@ -607,12 +599,10 @@ done:
 //--------------------------------------------------------------------------
 
 static void
-plcntr( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-        PLPointer f2eval_data,
+plcntr( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
         PLINT nx, PLINT ny, PLINT kx, PLINT lx,
         PLINT ky, PLINT ly, PLFLT flev, PLINT **ipts,
-        void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-        PLPointer pltr_data )
+        PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLINT kcol, krow, lastindex;
     PLFLT distance;
@@ -665,14 +655,12 @@ plcntr( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 //--------------------------------------------------------------------------
 
 static void
-pldrawcn( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-          PLPointer f2eval_data,
+pldrawcn( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
           PLINT nx, PLINT ny, PLINT kx, PLINT lx,
           PLINT ky, PLINT ly, PLFLT flev, char *flabel, PLINT kcol, PLINT krow,
           PLFLT lastx, PLFLT lasty, PLINT startedge, PLINT **ipts,
           PLFLT *distance, PLINT *lastindex,
-          void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-          PLPointer pltr_data )
+          PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLFLT f[4];
     PLFLT px[4], py[4], locx[4], locy[4];
