@@ -1,10 +1,8 @@
-// $Id: plshade.c 12312 2013-05-01 01:11:41Z hezekiahcarty $
-//
 //      Functions to shade regions on the basis of value.
 //      Can be used to shade contour plots or alone.
 //      Copyright 1993 Wesley Ebisuzaki
 //
-// Copyright (C) 2004  Alan W. Irwin
+// Copyright (C) 2004-2014 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -150,14 +148,12 @@ static int
 find_interval( PLFLT a0, PLFLT a1, PLINT c0, PLINT c1, PLFLT *x );
 
 static void
-selected_polygon( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
-                  PLINT ( *defined )( PLFLT, PLFLT ),
-                  const PLFLT *x, const PLFLT *y, PLINT v1, PLINT v2, PLINT v3, PLINT v4 );
+selected_polygon( PLFILL_callback fill, PLDEFINED_callback defined,
+                  PLFLT_VECTOR x, PLFLT_VECTOR y, PLINT v1, PLINT v2, PLINT v3, PLINT v4 );
 
 static void
-exfill( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
-        PLINT ( *defined )( PLFLT, PLFLT ),
-        int n, const PLFLT *x, const PLFLT *y );
+exfill( PLFILL_callback fill, PLDEFINED_callback defined,
+        int n, PLFLT_VECTOR x, PLFLT_VECTOR y );
 
 static void
 big_recl( int *cond_code, register int ny, int dx, int dy,
@@ -174,20 +170,35 @@ plctestez( PLFLT *a, PLINT nx, PLINT ny, PLINT ix,
            PLINT iy, PLFLT level );
 
 static void
-plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-             PLPointer f2eval_data,
-             PLFLT ( *c2eval )( PLINT, PLINT, PLPointer ),
-             PLPointer c2eval_data,
-             PLINT ( *defined )( PLFLT, PLFLT ),
+plshade_int( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
+             PLF2EVAL_callback c2eval, PLPointer c2eval_data,
+             PLDEFINED_callback defined,
              PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
              PLFLT shade_min, PLFLT shade_max,
              PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
              PLINT min_color, PLFLT min_width,
              PLINT max_color, PLFLT max_width,
-             void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-             PLPointer pltr_data );
+             PLFILL_callback fill, PLINT rectangular,
+             PLTRANSFORM_callback pltr, PLPointer pltr_data );
+
+// N.B. This routine only needed by the Fortran interface to distinguish
+// the case where pltr and pltr_data are NULL.  So don't put declaration in
+// header which might encourage others to use this in some other context.
+PLDLLIMPEXP void
+plshades_null( PLFLT_MATRIX a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
+               PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
+               PLFLT_VECTOR clevel, PLINT nlevel, PLFLT fill_width,
+               PLINT cont_color, PLFLT cont_width,
+               PLFILL_callback fill, PLINT rectangular )
+{
+    plfshades( plf2ops_c(), (PLPointer) a, nx, ny, defined,
+        xmin, xmax, ymin, ymax,
+        clevel, nlevel, fill_width,
+        cont_color, cont_width,
+        fill, rectangular,
+        NULL, NULL );
+}
 
 //--------------------------------------------------------------------------
 // plshades()
@@ -202,13 +213,12 @@ plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 // (if cont_color <= 0 or cont_width <=0, no such contours are drawn).
 //--------------------------------------------------------------------------
 
-void c_plshades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+void c_plshades( PLFLT_MATRIX a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-                 const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+                 PLFLT_VECTOR clevel, PLINT nlevel, PLFLT fill_width,
                  PLINT cont_color, PLFLT cont_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data )
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     plfshades( plf2ops_c(), (PLPointer) a, nx, ny, defined,
         xmin, xmax, ymin, ymax,
@@ -233,13 +243,12 @@ void c_plshades( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )(
 
 void
 plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
-           PLINT ( *defined )( PLFLT, PLFLT ),
+           PLDEFINED_callback defined,
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
-           const PLFLT *clevel, PLINT nlevel, PLFLT fill_width,
+           PLFLT_VECTOR clevel, PLINT nlevel, PLFLT fill_width,
            PLINT cont_color, PLFLT cont_width,
-           void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-           PLPointer pltr_data )
+           PLFILL_callback fill, PLINT rectangular,
+           PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLFLT shade_min, shade_max, shade_color;
     PLINT i, init_color;
@@ -310,6 +319,28 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
     }
 }
 
+// N.B. This routine only needed by the Fortran interface to distinguish
+// the case where pltr and pltr_data are NULL.  So don't put declaration in
+// header which might encourage others to use this in some other context.
+PLDLLIMPEXP void
+plshade_null( PLFLT_MATRIX a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
+              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
+              PLFLT shade_min, PLFLT shade_max,
+              PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
+              PLINT min_color, PLFLT min_width,
+              PLINT max_color, PLFLT max_width,
+              PLFILL_callback fill, PLINT rectangular )
+{
+    plshade_int( plf2eval1, (PLPointer) a,
+        NULL, NULL,
+//	     plc2eval, (PLPointer) &cgrid,
+        defined, nx, ny, xmin,
+        xmax, ymin, ymax, shade_min, shade_max,
+        sh_cmap, sh_color, sh_width,
+        min_color, min_width, max_color, max_width,
+        fill, rectangular, NULL, NULL );
+}
+
 //--------------------------------------------------------------------------
 // plshade()
 //
@@ -318,15 +349,14 @@ plfshades( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
 // via a (PLFLT **), and is column-dominant (normal C ordering).
 //--------------------------------------------------------------------------
 
-void c_plshade( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+void c_plshade( PLFLT_MATRIX a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
                 PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                 PLFLT shade_min, PLFLT shade_max,
                 PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                 PLINT min_color, PLFLT min_width,
                 PLINT max_color, PLFLT max_width,
-                void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                PLPointer pltr_data )
+                PLFILL_callback fill, PLINT rectangular,
+                PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     plshade_int( plf2eval1, (PLPointer) a,
         NULL, NULL,
@@ -346,15 +376,14 @@ void c_plshade( const PLFLT * const *a, PLINT nx, PLINT ny, PLINT ( *defined )(
 // via a (PLFLT *), and is column-dominant (normal C ordering).
 //--------------------------------------------------------------------------
 
-void c_plshade1( const PLFLT *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT, PLFLT ),
+void c_plshade1( PLFLT_VECTOR a, PLINT nx, PLINT ny, PLDEFINED_callback defined,
                  PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
                  PLFLT shade_min, PLFLT shade_max,
                  PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
                  PLINT min_color, PLFLT min_width,
                  PLINT max_color, PLFLT max_width,
-                 void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-                 void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-                 PLPointer pltr_data )
+                 PLFILL_callback fill, PLINT rectangular,
+                 PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLfGrid grid;
 
@@ -380,19 +409,16 @@ void c_plshade1( const PLFLT *a, PLINT nx, PLINT ny, PLINT ( *defined )( PLFLT,
 //--------------------------------------------------------------------------
 
 void
-plfshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-          PLPointer f2eval_data,
-          PLFLT ( *c2eval )( PLINT, PLINT, PLPointer ),
-          PLPointer c2eval_data,
+plfshade( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
+          PLF2EVAL_callback c2eval, PLPointer c2eval_data,
           PLINT nx, PLINT ny,
           PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
           PLFLT shade_min, PLFLT shade_max,
           PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
           PLINT min_color, PLFLT min_width,
           PLINT max_color, PLFLT max_width,
-          void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-          void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-          PLPointer pltr_data )
+          PLFILL_callback fill, PLINT rectangular,
+          PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     plshade_int( f2eval, f2eval_data, c2eval, c2eval_data,
         NULL,
@@ -415,15 +441,14 @@ plfshade( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
 
 void
 plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
-           PLINT ( *defined )( PLFLT, PLFLT ),
+           PLDEFINED_callback defined,
            PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
            PLFLT shade_min, PLFLT shade_max,
            PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
            PLINT min_color, PLFLT min_width,
            PLINT max_color, PLFLT max_width,
-           void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-           void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-           PLPointer pltr_data )
+           PLFILL_callback fill, PLINT rectangular,
+           PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     plshade_int( zops->f2eval, zp,
         NULL, NULL,
@@ -466,20 +491,17 @@ plfshade1( PLF2OPS zops, PLPointer zp, PLINT nx, PLINT ny,
 //--------------------------------------------------------------------------
 
 static void
-plshade_int( PLFLT ( *f2eval )( PLINT, PLINT, PLPointer ),
-             PLPointer f2eval_data,
-             PLFLT ( * c2eval )( PLINT, PLINT, PLPointer ), // unused, but macro doesn't work
-             PLPointer PL_UNUSED( c2eval_data ),
-             PLINT ( *defined )( PLFLT, PLFLT ),
+plshade_int( PLF2EVAL_callback f2eval, PLPointer f2eval_data,
+             PLF2EVAL_callback c2eval, PLPointer PL_UNUSED( c2eval_data ), //c2eval is unused.
+             PLDEFINED_callback defined,
              PLINT nx, PLINT ny,
              PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax,
              PLFLT shade_min, PLFLT shade_max,
              PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width,
              PLINT min_color, PLFLT min_width,
              PLINT max_color, PLFLT max_width,
-             void ( *fill )( PLINT, const PLFLT *, const PLFLT * ), PLINT rectangular,
-             void ( *pltr )( PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer ),
-             PLPointer pltr_data )
+             PLFILL_callback fill, PLINT rectangular,
+             PLTRANSFORM_callback pltr, PLPointer pltr_data )
 {
     PLINT n, slope = 0, ix, iy;
     int   count, i, j, nxny;
@@ -892,9 +914,8 @@ find_interval( PLFLT a0, PLFLT a1, PLINT c0, PLINT c1, PLFLT *x )
 //--------------------------------------------------------------------------
 
 static void
-selected_polygon( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
-                  PLINT ( *defined )( PLFLT, PLFLT ),
-                  const PLFLT *x, const PLFLT *y, PLINT v1, PLINT v2, PLINT v3, PLINT v4 )
+selected_polygon( PLFILL_callback fill, PLDEFINED_callback defined,
+                  PLFLT_VECTOR x, PLFLT_VECTOR y, PLINT v1, PLINT v2, PLINT v3, PLINT v4 )
 {
     register PLINT n = 0;
     PLFLT          xx[4], yy[4];
@@ -933,7 +954,7 @@ selected_polygon( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
 //--------------------------------------------------------------------------
 
 static void
-bisect( PLINT ( *defined )( PLFLT, PLFLT ), PLINT niter,
+bisect( PLDEFINED_callback defined, PLINT niter,
         PLFLT x1, PLFLT y1, PLFLT x2, PLFLT y2, PLFLT* xb, PLFLT* yb )
 {
     PLFLT xm;
@@ -970,9 +991,8 @@ bisect( PLINT ( *defined )( PLFLT, PLFLT ), PLINT niter,
 //--------------------------------------------------------------------------
 
 static void
-exfill( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
-        PLINT ( *defined )( PLFLT, PLFLT ),
-        int n, const PLFLT *x, const PLFLT *y )
+exfill( PLFILL_callback fill, PLDEFINED_callback defined,
+        int n, PLFLT_VECTOR x, PLFLT_VECTOR y )
 {
     if ( n < 3 )
     {
@@ -1040,7 +1060,7 @@ exfill( void ( *fill )( PLINT, const PLFLT *, const PLFLT * ),
         }
 
         if ( count >= 3 )
-            ( *fill )( count, (const PLFLT *) xx, (const PLFLT *) yy );
+            ( *fill )( count, (PLFLT_VECTOR) xx, (PLFLT_VECTOR) yy );
 
         free( xx );
         free( yy );
