@@ -166,8 +166,8 @@ filled).
 		<p>Select language to see the source code</p>
 		<form class="codeform" action="examples.php" method="get">
 		<input type="hidden" name="demo" value="$demo_str" />
-		<input type="submit" name="lbind" value="Ada(thick)" />
-		<input type="submit" name="lbind" value="Ada(thin)" />
+		<input type="submit" name="lbind" value="Ada(Standard)" />
+		<input type="submit" name="lbind" value="Ada(Traditional)" />
 		<input type="submit" name="lbind" value="C" />
 		<input type="submit" name="lbind" value="C++" />
 		<input type="submit" name="lbind" value="D" />
@@ -182,8 +182,8 @@ filled).
 END;
 
 	  switch($lbind) {
-	  case ("Ada(thick)"):    $fname = "xthick" . $demo_str . "a.adb.txt"; break;
-	  case ("Ada(thin)"):    $fname = "x" . $demo_str . "a.adb.txt"; break;
+	  case ("Ada(Standard)"):    $fname = "xstandard" . $demo_str . "a.adb.txt"; break;
+	  case ("Ada(Traditional)"):    $fname = "xtraditional" . $demo_str . "a.adb.txt"; break;
 	  case ("C"):      $fname = "x" . $demo_str . "c.c.txt"; break;
 	  case ("C++"):$fname = "x" . $demo_str . ".cc.txt"; break;
 	  case ("D"):$fname = "x" . $demo_str . "d.d.txt"; break;
@@ -192,7 +192,7 @@ END;
 	  case ("Lua"):    $fname = "x" . $demo_str . ".lua.txt"; break;
 	  case ("Ocaml"):  $fname = "x" . $demo_str . ".ml.txt"; break;
 	  case ("Octave"): $fname = "x" . $demo_str . "c.m.txt"; break;
-	  case ("Python"): $fname = "xw" . $demo_str . ".py.txt"; break;
+	  case ("Python"): $fname = "x" . $demo_str . ".py.txt"; break;
 	  case ("Tcl"):    $fname = "x" . $demo_str . ".tcl.txt";  break;
 	  default:         $fname = "x" . $demo_str . "c.c.txt";
 	  }
@@ -234,7 +234,7 @@ END;
 		echo <<<END
 			<h3>Examples</h3>
 			<p>These examples were generated with the pngcairo device and
-				 reflect the status of PLplot-5.11.1.</p>
+				 reflect the status of PLplot-5.12.0.</p>
 			<p>Select a thumbnail to view full-size image and source code.</p>
 			<p>
 END;
